# openapi-java-client

Lichess.org API reference
- API version: 2.0.0
  - Build date: 2021-12-01T01:33:45.712176+01:00[Europe/Vienna]

# Introduction
Welcome to the reference for the Lichess API! Lichess is free/libre,
open-source chess server powered by volunteers and donations.
- Get help in the [Lichess Discord channel](https://discord.gg/lichess)
- [Contribute to this documentation on Github](https://github.com/lichess-org/api)
- Check out [Lichess widgets to embed in your website](https://lichess.org/developers)
- [Download all Lichess rated games](https://database.lichess.org/)
- [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)

## Endpoint
All requests go to `https://lichess.org` (unless otherwise specified).

## Clients
- [Python general API](https://github.com/ZackClements/berserk)
- [MicroPython general API](https://github.com/mkomon/uberserk)
- [Python general API - async](https://pypi.org/project/async-lichess-sdk)
- [Python Lichess Bot](https://github.com/careless25/lichess-bot)
- [Python Board API for Certabo](https://github.com/haklein/certabo-lichess)
- [Java general API](https://github.com/tors42/chariot)

## Rate limiting
All requests are rate limited using various strategies,
to ensure the API remains responsive for everyone.
Only make one request at a time.
If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429),
please wait a full minute before resuming API usage.

## Streaming with ND-JSON
Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.

Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses.



*Automatically generated by the [OpenAPI Generator](https://openapi-generator.tech)*


## Requirements

Building the API client library requires:
1. Java 1.7+
2. Maven/Gradle

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn clean install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn clean deploy
```

Refer to the [OSSRH Guide](http://central.sonatype.org/pages/ossrh-guide.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
  <groupId>org.openapitools</groupId>
  <artifactId>openapi-java-client</artifactId>
  <version>2.0.0</version>
  <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "org.openapitools:openapi-java-client:2.0.0"
```

### Others

At first generate the JAR by executing:

```shell
mvn clean package
```

Then manually install the following JARs:

* `target/openapi-java-client-2.0.0.jar`
* `target/lib/*.jar`

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.AccountApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    AccountApi apiInstance = new AccountApi(defaultClient);
    try {
      Object result = apiInstance.account();
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling AccountApi#account");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://lichess.org*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountApi* | [**account**](docs/AccountApi.md#account) | **GET** /api/account/preferences | Get my preferences
*AccountApi* | [**accountEmail**](docs/AccountApi.md#accountEmail) | **GET** /api/account/email | Get my email address
*AccountApi* | [**accountKid**](docs/AccountApi.md#accountKid) | **GET** /api/account/kid | Get my kid mode status
*AccountApi* | [**accountKidPost**](docs/AccountApi.md#accountKidPost) | **POST** /api/account/kid | Set my kid mode status
*AccountApi* | [**accountMe**](docs/AccountApi.md#accountMe) | **GET** /api/account | Get my profile
*AnalysisApi* | [**apiCloudEval**](docs/AnalysisApi.md#apiCloudEval) | **GET** /api/cloud-eval | Get cloud evaluation of a position.
*ArenaTournamentsApi* | [**apiTeamArena**](docs/ArenaTournamentsApi.md#apiTeamArena) | **GET** /api/team/{teamId}/arena | Get team Arena tournaments
*ArenaTournamentsApi* | [**apiTournament**](docs/ArenaTournamentsApi.md#apiTournament) | **GET** /api/tournament | Get current tournaments
*ArenaTournamentsApi* | [**apiTournamentJoin**](docs/ArenaTournamentsApi.md#apiTournamentJoin) | **POST** /api/tournament/{id}/join | Join an Arena tournament
*ArenaTournamentsApi* | [**apiTournamentPost**](docs/ArenaTournamentsApi.md#apiTournamentPost) | **POST** /api/tournament | Create a new Arena tournament
*ArenaTournamentsApi* | [**apiTournamentTeamBattlePost**](docs/ArenaTournamentsApi.md#apiTournamentTeamBattlePost) | **POST** /api/tournament/team-battle/{id} | Update a team battle
*ArenaTournamentsApi* | [**apiTournamentTerminate**](docs/ArenaTournamentsApi.md#apiTournamentTerminate) | **POST** /api/tournament/{id}/terminate | Terminate an Arena tournament
*ArenaTournamentsApi* | [**apiTournamentUpdate**](docs/ArenaTournamentsApi.md#apiTournamentUpdate) | **POST** /api/tournament/{id} | Update an Arena tournament
*ArenaTournamentsApi* | [**apiTournamentWithdraw**](docs/ArenaTournamentsApi.md#apiTournamentWithdraw) | **POST** /api/tournament/{id}/withdraw | Pause of leave an Arena tournament
*ArenaTournamentsApi* | [**apiUserNameTournamentCreated**](docs/ArenaTournamentsApi.md#apiUserNameTournamentCreated) | **GET** /api/user/{username}/tournament/created | Get tournaments created by a user
*ArenaTournamentsApi* | [**gamesByTournament**](docs/ArenaTournamentsApi.md#gamesByTournament) | **GET** /api/tournament/{id}/games | Export games of an Arena tournament
*ArenaTournamentsApi* | [**resultsByTournament**](docs/ArenaTournamentsApi.md#resultsByTournament) | **GET** /api/tournament/{id}/results | Get results of an Arena tournament
*ArenaTournamentsApi* | [**teamsByTournament**](docs/ArenaTournamentsApi.md#teamsByTournament) | **GET** /api/tournament/{id}/teams | Get team standing of a team battle
*ArenaTournamentsApi* | [**tournament**](docs/ArenaTournamentsApi.md#tournament) | **GET** /api/tournament/{id} | Get info about an Arena tournament
*BoardApi* | [**apiBoardSeek**](docs/BoardApi.md#apiBoardSeek) | **POST** /api/board/seek | Create a seek
*BoardApi* | [**apiStreamEvent**](docs/BoardApi.md#apiStreamEvent) | **GET** /api/stream/event | Stream incoming events
*BoardApi* | [**boardGameAbort**](docs/BoardApi.md#boardGameAbort) | **POST** /api/board/game/{gameId}/abort | Abort a game
*BoardApi* | [**boardGameChatGet**](docs/BoardApi.md#boardGameChatGet) | **GET** /api/board/game/{gameId}/chat | Fetch the game chat
*BoardApi* | [**boardGameChatPost**](docs/BoardApi.md#boardGameChatPost) | **POST** /api/board/game/{gameId}/chat | Write in the chat
*BoardApi* | [**boardGameClaimVictory**](docs/BoardApi.md#boardGameClaimVictory) | **POST** /api/board/game/{gameId}/claim-victory | Claim victory of a game
*BoardApi* | [**boardGameDraw**](docs/BoardApi.md#boardGameDraw) | **POST** /api/board/game/{gameId}/draw/{accept} | Handle draw offers
*BoardApi* | [**boardGameMove**](docs/BoardApi.md#boardGameMove) | **POST** /api/board/game/{gameId}/move/{move} | Make a Board move
*BoardApi* | [**boardGameResign**](docs/BoardApi.md#boardGameResign) | **POST** /api/board/game/{gameId}/resign | Resign a game
*BoardApi* | [**boardGameStream**](docs/BoardApi.md#boardGameStream) | **GET** /api/board/game/stream/{gameId} | Stream Board game state
*BoardApi* | [**boardGameTakeback**](docs/BoardApi.md#boardGameTakeback) | **POST** /api/board/game/{gameId}/takeback/{accept} | Handle takeback offers
*BotApi* | [**apiBotOnline**](docs/BotApi.md#apiBotOnline) | **GET** /api/bot/online | Get online bots
*BotApi* | [**apiStreamEvent**](docs/BotApi.md#apiStreamEvent) | **GET** /api/stream/event | Stream incoming events
*BotApi* | [**botAccountUpgrade**](docs/BotApi.md#botAccountUpgrade) | **POST** /api/bot/account/upgrade | Upgrade to Bot account
*BotApi* | [**botGameAbort**](docs/BotApi.md#botGameAbort) | **POST** /api/bot/game/{gameId}/abort | Abort a game
*BotApi* | [**botGameChat**](docs/BotApi.md#botGameChat) | **POST** /api/bot/game/{gameId}/chat | Write in the chat
*BotApi* | [**botGameMove**](docs/BotApi.md#botGameMove) | **POST** /api/bot/game/{gameId}/move/{move} | Make a Bot move
*BotApi* | [**botGameResign**](docs/BotApi.md#botGameResign) | **POST** /api/bot/game/{gameId}/resign | Resign a game
*BotApi* | [**botGameStream**](docs/BotApi.md#botGameStream) | **GET** /api/bot/game/stream/{gameId} | Stream Bot game state
*BroadcastsApi* | [**broadcastAllRoundsPgn**](docs/BroadcastsApi.md#broadcastAllRoundsPgn) | **GET** /api/broadcast/{broadcastTournamentId}.pgn | Export all rounds as PGN
*BroadcastsApi* | [**broadcastIndex**](docs/BroadcastsApi.md#broadcastIndex) | **GET** /api/broadcast | Get official broadcasts
*BroadcastsApi* | [**broadcastPush**](docs/BroadcastsApi.md#broadcastPush) | **POST** /broadcast/round/{broadcastRoundId}/push | Push PGN to your broadcast round
*BroadcastsApi* | [**broadcastRoundCreate**](docs/BroadcastsApi.md#broadcastRoundCreate) | **POST** /broadcast/{broadcastTournamentId}/new | Create a broadcast round
*BroadcastsApi* | [**broadcastRoundGet**](docs/BroadcastsApi.md#broadcastRoundGet) | **GET** /broadcast/{broadcastTournamentSlug}/{broadcastRoundSlug}/{broadcastRoundId} | Get your broadcast round
*BroadcastsApi* | [**broadcastRoundPgn**](docs/BroadcastsApi.md#broadcastRoundPgn) | **GET** /api/broadcast/round/{broadcastRoundId}.pgn | Export one round as PGN
*BroadcastsApi* | [**broadcastRoundUpdate**](docs/BroadcastsApi.md#broadcastRoundUpdate) | **POST** /broadcast/round/{broadcastRoundId}/edit | Update your broadcast round
*BroadcastsApi* | [**broadcastStreamRoundPgn**](docs/BroadcastsApi.md#broadcastStreamRoundPgn) | **GET** /api/stream/broadcast/round/{broadcastRoundId}.pgn | Stream an ongoing broadcast tournament as PGN
*BroadcastsApi* | [**broadcastTourCreate**](docs/BroadcastsApi.md#broadcastTourCreate) | **POST** /broadcast/new | Create a broadcast tournament
*BroadcastsApi* | [**broadcastTourGet**](docs/BroadcastsApi.md#broadcastTourGet) | **GET** /broadcast/{slug}/{broadcastTournamentId} | Get your broadcast tournament
*BroadcastsApi* | [**broadcastTourUpdate**](docs/BroadcastsApi.md#broadcastTourUpdate) | **POST** /broadcast/{broadcastTournamentId}/edit | Update your broadcast tournament
*BulkPairingsApi* | [**bulkPairingCreate**](docs/BulkPairingsApi.md#bulkPairingCreate) | **POST** /api/bulk-pairing | Create a bulk pairing
*BulkPairingsApi* | [**bulkPairingDelete**](docs/BulkPairingsApi.md#bulkPairingDelete) | **DELETE** /api/bulk-pairing/{id} | Cancel a bulk pairing
*BulkPairingsApi* | [**bulkPairingGet**](docs/BulkPairingsApi.md#bulkPairingGet) | **GET** /api/bulk-pairing | View upcoming bulk pairings
*BulkPairingsApi* | [**bulkPairingStartClocks**](docs/BulkPairingsApi.md#bulkPairingStartClocks) | **POST** /api/bulk-pairing/{id}/start-clocks | Manually start clocks
*ChallengesApi* | [**adminChallengeTokens**](docs/ChallengesApi.md#adminChallengeTokens) | **POST** /api/token/admin-challenge | Admin challenge tokens
*ChallengesApi* | [**challengeAccept**](docs/ChallengesApi.md#challengeAccept) | **POST** /api/challenge/{challengeId}/accept | Accept a challenge
*ChallengesApi* | [**challengeAi**](docs/ChallengesApi.md#challengeAi) | **POST** /api/challenge/ai | Challenge the AI
*ChallengesApi* | [**challengeCancel**](docs/ChallengesApi.md#challengeCancel) | **POST** /api/challenge/{challengeId}/cancel | Cancel a challenge
*ChallengesApi* | [**challengeCreate**](docs/ChallengesApi.md#challengeCreate) | **POST** /api/challenge/{username} | Create a challenge
*ChallengesApi* | [**challengeDecline**](docs/ChallengesApi.md#challengeDecline) | **POST** /api/challenge/{challengeId}/decline | Decline a challenge
*ChallengesApi* | [**challengeList**](docs/ChallengesApi.md#challengeList) | **GET** /api/challenge | List your challenges
*ChallengesApi* | [**challengeOpen**](docs/ChallengesApi.md#challengeOpen) | **POST** /api/challenge/open | Open-ended challenge
*ChallengesApi* | [**challengeStartClocks**](docs/ChallengesApi.md#challengeStartClocks) | **POST** /api/challenge/{gameId}/start-clocks | Start clocks of a game
*ChallengesApi* | [**roundAddTime**](docs/ChallengesApi.md#roundAddTime) | **POST** /api/round/{gameId}/add-time/{seconds} | Add time to the opponent clock
*GamesApi* | [**apiAccountPlaying**](docs/GamesApi.md#apiAccountPlaying) | **GET** /api/account/playing | Get my ongoing games
*GamesApi* | [**apiGamesUser**](docs/GamesApi.md#apiGamesUser) | **GET** /api/games/user/{username} | Export games of a user
*GamesApi* | [**apiUserCurrentGame**](docs/GamesApi.md#apiUserCurrentGame) | **GET** /api/user/{username}/current-game | Export ongoing game of a user
*GamesApi* | [**gameImport**](docs/GamesApi.md#gameImport) | **POST** /api/import | Import one game
*GamesApi* | [**gamePgn**](docs/GamesApi.md#gamePgn) | **GET** /game/export/{gameId} | Export one game
*GamesApi* | [**gamesByUsers**](docs/GamesApi.md#gamesByUsers) | **POST** /api/stream/games-by-users | Stream games of users
*GamesApi* | [**gamesExportIds**](docs/GamesApi.md#gamesExportIds) | **POST** /games/export/_ids | Export games by IDs
*GamesApi* | [**streamGame**](docs/GamesApi.md#streamGame) | **GET** /api/stream/game/{id} | Stream moves of a game
*MessagingApi* | [**inboxUsername**](docs/MessagingApi.md#inboxUsername) | **POST** /inbox/{username} | Send a private message
*OAuthApi* | [**apiToken**](docs/OAuthApi.md#apiToken) | **POST** /api/token | Obtain access token
*OAuthApi* | [**apiTokenDelete**](docs/OAuthApi.md#apiTokenDelete) | **DELETE** /api/token | Revoke access token
*OAuthApi* | [**oauth**](docs/OAuthApi.md#oauth) | **GET** /oauth | Request authorization code
*OpeningExplorerApi* | [**openingExplorerLichess**](docs/OpeningExplorerApi.md#openingExplorerLichess) | **GET** /lichess | Lichess games
*OpeningExplorerApi* | [**openingExplorerMaster**](docs/OpeningExplorerApi.md#openingExplorerMaster) | **GET** /masters | Masters database
*OpeningExplorerApi* | [**openingExplorerMasterGame**](docs/OpeningExplorerApi.md#openingExplorerMasterGame) | **GET** /master/pgn/{gameId} | OTB master game
*OpeningExplorerApi* | [**openingExplorerPlayer**](docs/OpeningExplorerApi.md#openingExplorerPlayer) | **GET** /player? | Player games
*PuzzlesApi* | [**apiPuzzleActivity**](docs/PuzzlesApi.md#apiPuzzleActivity) | **GET** /api/puzzle/activity | Get your puzzle activity
*PuzzlesApi* | [**apiPuzzleDaily**](docs/PuzzlesApi.md#apiPuzzleDaily) | **GET** /api/puzzle/daily | Get the daily puzzle
*PuzzlesApi* | [**apiPuzzleDashboard**](docs/PuzzlesApi.md#apiPuzzleDashboard) | **GET** /api/puzzle/dashboard/{days} | Get your puzzle dashboard
*PuzzlesApi* | [**apiStormDashboard**](docs/PuzzlesApi.md#apiStormDashboard) | **GET** /api/storm/dashboard/{username} | Get the storm dashboard of a player
*RelationsApi* | [**apiUserFollowing**](docs/RelationsApi.md#apiUserFollowing) | **GET** /api/rel/following | Get users followed the logged in user
*RelationsApi* | [**followUser**](docs/RelationsApi.md#followUser) | **POST** /api/rel/follow/{username} | Follow a player
*RelationsApi* | [**unfollowUser**](docs/RelationsApi.md#unfollowUser) | **POST** /api/rel/unfollow/{username} | Unfollow a player
*SimulsApi* | [**apiSimul**](docs/SimulsApi.md#apiSimul) | **GET** /api/simul | Get current simuls
*StudiesApi* | [**studyAllChaptersPgn**](docs/StudiesApi.md#studyAllChaptersPgn) | **GET** /api/study/{studyId}.pgn | Export all chapters
*StudiesApi* | [**studyChapterPgn**](docs/StudiesApi.md#studyChapterPgn) | **GET** /study/{studyId}/{chapterId}.pgn | Export one study chapter
*StudiesApi* | [**studyExportAllPgn**](docs/StudiesApi.md#studyExportAllPgn) | **GET** /study/by/{username}/export.pgn | Export all studies of a user
*SwissTournamentsApi* | [**apiSwissJoin**](docs/SwissTournamentsApi.md#apiSwissJoin) | **POST** /api/swiss/{id}/join | Join a Swiss tournament
*SwissTournamentsApi* | [**apiSwissNew**](docs/SwissTournamentsApi.md#apiSwissNew) | **POST** /api/swiss/new/{teamId} | Create a new Swiss tournament
*SwissTournamentsApi* | [**apiSwissTerminate**](docs/SwissTournamentsApi.md#apiSwissTerminate) | **POST** /api/swiss/{id}/terminate | Terminate a Swiss tournament
*SwissTournamentsApi* | [**apiSwissUpdate**](docs/SwissTournamentsApi.md#apiSwissUpdate) | **POST** /api/swiss/{id}/edit | Update a Swiss tournament.
*SwissTournamentsApi* | [**apiTeamSwiss**](docs/SwissTournamentsApi.md#apiTeamSwiss) | **GET** /api/team/{teamId}/swiss | Get team swiss tournaments
*SwissTournamentsApi* | [**gamesBySwiss**](docs/SwissTournamentsApi.md#gamesBySwiss) | **GET** /api/swiss/{id}/games | Export games of a Swiss tournament
*SwissTournamentsApi* | [**resultsBySwiss**](docs/SwissTournamentsApi.md#resultsBySwiss) | **GET** /api/swiss/{id}/results | Get results of a swiss tournament
*SwissTournamentsApi* | [**swissTrf**](docs/SwissTournamentsApi.md#swissTrf) | **GET** /swiss/{id}.trf | Export TRF of a Swiss tournament
*TablebaseApi* | [**antichessAtomic**](docs/TablebaseApi.md#antichessAtomic) | **GET** /antichess | Tablebase lookup for Antichess
*TablebaseApi* | [**tablebaseAtomic**](docs/TablebaseApi.md#tablebaseAtomic) | **GET** /atomic | Tablebase lookup for Atomic chess
*TablebaseApi* | [**tablebaseStandard**](docs/TablebaseApi.md#tablebaseStandard) | **GET** /standard | Tablebase lookup
*TeamsApi* | [**apiTeamArena**](docs/TeamsApi.md#apiTeamArena) | **GET** /api/team/{teamId}/arena | Get team Arena tournaments
*TeamsApi* | [**apiTeamSwiss**](docs/TeamsApi.md#apiTeamSwiss) | **GET** /api/team/{teamId}/swiss | Get team swiss tournaments
*TeamsApi* | [**teamAll**](docs/TeamsApi.md#teamAll) | **GET** /api/team/all | Get popular teams
*TeamsApi* | [**teamIdJoin**](docs/TeamsApi.md#teamIdJoin) | **POST** /team/{teamId}/join | Join a team
*TeamsApi* | [**teamIdKickUserId**](docs/TeamsApi.md#teamIdKickUserId) | **POST** /team/{teamId}/kick/{userId} | Kick a user from your team
*TeamsApi* | [**teamIdPmAll**](docs/TeamsApi.md#teamIdPmAll) | **POST** /team/{teamId}/pm-all | Message all members
*TeamsApi* | [**teamIdQuit**](docs/TeamsApi.md#teamIdQuit) | **POST** /team/{teamId}/quit | Leave a team
*TeamsApi* | [**teamIdUsers**](docs/TeamsApi.md#teamIdUsers) | **GET** /api/team/{teamId}/users | Get members of a team
*TeamsApi* | [**teamOfUsername**](docs/TeamsApi.md#teamOfUsername) | **GET** /api/team/of/{username} | Teams of a player
*TeamsApi* | [**teamSearch**](docs/TeamsApi.md#teamSearch) | **GET** /api/team/search | Search teams
*TeamsApi* | [**teamShow**](docs/TeamsApi.md#teamShow) | **GET** /api/team/{teamId} | Get a single team
*TvApi* | [**tvChannelGames**](docs/TvApi.md#tvChannelGames) | **GET** /api/tv/{channel} | Get best ongoing games of a TV channel
*TvApi* | [**tvChannels**](docs/TvApi.md#tvChannels) | **GET** /api/tv/channels | Get current TV games
*TvApi* | [**tvFeed**](docs/TvApi.md#tvFeed) | **GET** /api/tv/feed | Stream current TV game
*UsersApi* | [**apiCrosstable**](docs/UsersApi.md#apiCrosstable) | **GET** /api/crosstable/{user1}/{user2} | Get crosstable
*UsersApi* | [**apiUser**](docs/UsersApi.md#apiUser) | **GET** /api/user/{username} | Get user public data
*UsersApi* | [**apiUserActivity**](docs/UsersApi.md#apiUserActivity) | **GET** /api/user/{username}/activity | Get user activity
*UsersApi* | [**apiUserPerf**](docs/UsersApi.md#apiUserPerf) | **GET** /api/user/{username}/perf/{perf} | Get performance statistics of a user
*UsersApi* | [**apiUserRatingHistory**](docs/UsersApi.md#apiUserRatingHistory) | **GET** /api/user/{username}/rating-history | Get rating history of a user
*UsersApi* | [**apiUsers**](docs/UsersApi.md#apiUsers) | **POST** /api/users | Get users by ID
*UsersApi* | [**apiUsersStatus**](docs/UsersApi.md#apiUsersStatus) | **GET** /api/users/status | Get real-time users status
*UsersApi* | [**player**](docs/UsersApi.md#player) | **GET** /player | Get all top 10
*UsersApi* | [**playerTopNbPerfType**](docs/UsersApi.md#playerTopNbPerfType) | **GET** /player/top/{nb}/{perfType} | Get one leaderboard
*UsersApi* | [**streamerLive**](docs/UsersApi.md#streamerLive) | **GET** /streamer/live | Get live streamers
*UsersApi* | [**teamIdUsers**](docs/UsersApi.md#teamIdUsers) | **GET** /api/team/{teamId}/users | Get members of a team


## Documentation for Models

 - [ApiStreamEvent](docs/ApiStreamEvent.md)
 - [ArenaTournaments](docs/ArenaTournaments.md)
 - [ChallengeCanceledEvent](docs/ChallengeCanceledEvent.md)
 - [ChallengeDeclinedEvent](docs/ChallengeDeclinedEvent.md)
 - [ChallengeEvent](docs/ChallengeEvent.md)
 - [ChallengeJson](docs/ChallengeJson.md)
 - [ChallengeJsonPerf](docs/ChallengeJsonPerf.md)
 - [ChallengeUser](docs/ChallengeUser.md)
 - [ChatLineEvent](docs/ChatLineEvent.md)
 - [Clock](docs/Clock.md)
 - [Count](docs/Count.md)
 - [Error](docs/Error.md)
 - [GameEventInfo](docs/GameEventInfo.md)
 - [GameEventInfoCompat](docs/GameEventInfoCompat.md)
 - [GameEventPlayer](docs/GameEventPlayer.md)
 - [GameFinishEvent](docs/GameFinishEvent.md)
 - [GameFullEvent](docs/GameFullEvent.md)
 - [GameFullEventPerf](docs/GameFullEventPerf.md)
 - [GameJson](docs/GameJson.md)
 - [GameJsonAnalysis](docs/GameJsonAnalysis.md)
 - [GameJsonClock](docs/GameJsonClock.md)
 - [GameJsonJudgment](docs/GameJsonJudgment.md)
 - [GameJsonOpening](docs/GameJsonOpening.md)
 - [GameJsonPlayers](docs/GameJsonPlayers.md)
 - [GameStartEvent](docs/GameStartEvent.md)
 - [GameStateEvent](docs/GameStateEvent.md)
 - [GameStatus](docs/GameStatus.md)
 - [GameStreamEvent](docs/GameStreamEvent.md)
 - [GameUser](docs/GameUser.md)
 - [GameUserAnalysis](docs/GameUserAnalysis.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse2001](docs/InlineResponse2001.md)
 - [InlineResponse2002](docs/InlineResponse2002.md)
 - [InlineResponse2003](docs/InlineResponse2003.md)
 - [LightUser](docs/LightUser.md)
 - [Move](docs/Move.md)
 - [NotFound](docs/NotFound.md)
 - [Ok](docs/Ok.md)
 - [Perf](docs/Perf.md)
 - [PerfType](docs/PerfType.md)
 - [Perfs](docs/Perfs.md)
 - [PlayTime](docs/PlayTime.md)
 - [Profile](docs/Profile.md)
 - [PuzzleRoundJson](docs/PuzzleRoundJson.md)
 - [Speed](docs/Speed.md)
 - [StormPerf](docs/StormPerf.md)
 - [SwissUnauthorisedEdit](docs/SwissUnauthorisedEdit.md)
 - [TablebaseJson](docs/TablebaseJson.md)
 - [Team](docs/Team.md)
 - [TimeControl](docs/TimeControl.md)
 - [TimeControlClock](docs/TimeControlClock.md)
 - [TimeControlClockAllOf](docs/TimeControlClockAllOf.md)
 - [TimeControlCorrespondence](docs/TimeControlCorrespondence.md)
 - [TimeControlCorrespondenceAllOf](docs/TimeControlCorrespondenceAllOf.md)
 - [TimeControlUnlimited](docs/TimeControlUnlimited.md)
 - [Title](docs/Title.md)
 - [User](docs/User.md)
 - [UserExtended](docs/UserExtended.md)
 - [UserExtendedAllOf](docs/UserExtendedAllOf.md)
 - [UserPreferences](docs/UserPreferences.md)
 - [Variant](docs/Variant.md)
 - [VariantKey](docs/VariantKey.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### OAuth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://lichess.org/oauth
- **Scopes**: 
  - preference:read: Read your preferences
  - preference:write: Write your preferences
  - email:read: Read your email address
  - challenge:read: Read incoming challenges
  - challenge:write: Create, accept, decline challenges
  - challenge:bulk: Create, delete, query bulk pairings
  - study:read: Read private studies and broadcasts
  - study:write: Create, update, delete studies and broadcasts
  - tournament:write: Create tournaments
  - puzzle:read: Read puzzle activity
  - team:read: Read private team information
  - team:write: Join, leave, and manage teams
  - follow:write: Follow and unfollow other players
  - msg:write: Send private messages to other players
  - board:play: Play with the Board API
  - bot:play: Play with the Bot API. Only for [Bot accounts](#operation/botAccountUpgrade)
  - web:mod: Use moderator tools (within the bounds of your permissions)


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author



