# ArenaTournamentsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiTeamArena**](ArenaTournamentsApi.md#apiTeamArena) | **GET** /api/team/{teamId}/arena | Get team Arena tournaments
[**apiTournament**](ArenaTournamentsApi.md#apiTournament) | **GET** /api/tournament | Get current tournaments
[**apiTournamentJoin**](ArenaTournamentsApi.md#apiTournamentJoin) | **POST** /api/tournament/{id}/join | Join an Arena tournament
[**apiTournamentPost**](ArenaTournamentsApi.md#apiTournamentPost) | **POST** /api/tournament | Create a new Arena tournament
[**apiTournamentTeamBattlePost**](ArenaTournamentsApi.md#apiTournamentTeamBattlePost) | **POST** /api/tournament/team-battle/{id} | Update a team battle
[**apiTournamentTerminate**](ArenaTournamentsApi.md#apiTournamentTerminate) | **POST** /api/tournament/{id}/terminate | Terminate an Arena tournament
[**apiTournamentUpdate**](ArenaTournamentsApi.md#apiTournamentUpdate) | **POST** /api/tournament/{id} | Update an Arena tournament
[**apiTournamentWithdraw**](ArenaTournamentsApi.md#apiTournamentWithdraw) | **POST** /api/tournament/{id}/withdraw | Pause of leave an Arena tournament
[**apiUserNameTournamentCreated**](ArenaTournamentsApi.md#apiUserNameTournamentCreated) | **GET** /api/user/{username}/tournament/created | Get tournaments created by a user
[**gamesByTournament**](ArenaTournamentsApi.md#gamesByTournament) | **GET** /api/tournament/{id}/games | Export games of an Arena tournament
[**resultsByTournament**](ArenaTournamentsApi.md#resultsByTournament) | **GET** /api/tournament/{id}/results | Get results of an Arena tournament
[**teamsByTournament**](ArenaTournamentsApi.md#teamsByTournament) | **GET** /api/tournament/{id}/teams | Get team standing of a team battle
[**tournament**](ArenaTournamentsApi.md#tournament) | **GET** /api/tournament/{id} | Get info about an Arena tournament


<a name="apiTeamArena"></a>
# **apiTeamArena**
> List&lt;Object&gt; apiTeamArena(teamId, max)

Get team Arena tournaments

Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ArenaTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    ArenaTournamentsApi apiInstance = new ArenaTournamentsApi(defaultClient);
    String teamId = "teamId_example"; // String | ID of the team
    Integer max = 100; // Integer | How many tournaments to download.
    try {
      List<Object> result = apiInstance.apiTeamArena(teamId, max);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ArenaTournamentsApi#apiTeamArena");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **String**| ID of the team |
 **max** | **Integer**| How many tournaments to download. | [optional] [default to 100]

### Return type

**List&lt;Object&gt;**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of Arena tournaments of a team. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiTournament"></a>
# **apiTournament**
> ArenaTournaments apiTournament()

Get current tournaments

Get recently finished, ongoing, and upcoming tournaments.  This API is used to display the [Lichess tournament schedule](https://lichess.org/tournament). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ArenaTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    ArenaTournamentsApi apiInstance = new ArenaTournamentsApi(defaultClient);
    try {
      ArenaTournaments result = apiInstance.apiTournament();
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ArenaTournamentsApi#apiTournament");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**ArenaTournaments**](ArenaTournaments.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of current tournaments. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiTournamentJoin"></a>
# **apiTournamentJoin**
> Ok apiTournamentJoin(id, password, team)

Join an Arena tournament

Join an Arena tournament, possibly with a password and/or a team. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ArenaTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ArenaTournamentsApi apiInstance = new ArenaTournamentsApi(defaultClient);
    String id = "hL7vMrFQ"; // String | The tournament ID.
    String password = "password_example"; // String | The tournament password, if one is required
    String team = "team_example"; // String | The team to join the tournament with, for team battle tournaments
    try {
      Ok result = apiInstance.apiTournamentJoin(id, password, team);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ArenaTournamentsApi#apiTournamentJoin");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID. |
 **password** | **String**| The tournament password, if one is required | [optional]
 **team** | **String**| The team to join the tournament with, for team battle tournaments | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The tournament was successfully joined. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Joining the tournament failed. |  -  |

<a name="apiTournamentPost"></a>
# **apiTournamentPost**
> Object apiTournamentPost(clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, teambBattleByTeam, conditionsTeamMemberTeamId, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb)

Create a new Arena tournament

Create a public or private Arena tournament.  This endpoint mirrors the form on &lt;https://lichess.org/tournament/new&gt;.  You can create up to 12 public tournaments per day, or 24 private tournaments.  A team battle can be created by specifying the &#x60;teambBattleByTeam&#x60; argument. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ArenaTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ArenaTournamentsApi apiInstance = new ArenaTournamentsApi(defaultClient);
    BigDecimal clockTime = new BigDecimal("0"); // BigDecimal | Clock initial time in minutes
    Integer clockIncrement = 56; // Integer | Clock increment in seconds
    Integer minutes = 56; // Integer | How long the tournament lasts, in minutes
    String name = "name_example"; // String | The tournament name. Leave empty to get a random Grandmaster name
    Integer waitMinutes = 5; // Integer | How long to wait before starting the tournament, from now, in minutes
    Integer startDate = 56; // Integer | Timestamp to start the tournament at a given date and time. Overrides the `waitMinutes` setting
    VariantKey variant = VariantKey.fromValue("standard"); // VariantKey | 
    Boolean rated = true; // Boolean | Games are rated and impact players ratings
    String position = "position_example"; // String | Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960).
    Boolean berserkable = true; // Boolean | Whether the players can use berserk
    Boolean streakable = true; // Boolean | After 2 wins, consecutive wins grant 4 points instead of 2.
    Boolean hasChat = true; // Boolean | Whether the players can discuss in a chat
    String description = "description_example"; // String | Anything you want to tell players about the tournament
    String password = "password_example"; // String | Make the tournament private, and restrict access with a password
    String teambBattleByTeam = "teambBattleByTeam_example"; // String | Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost). 
    String conditionsTeamMemberTeamId = "conditionsTeamMemberTeamId_example"; // String | Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. `https://lichess.org/team/coders` has teamId = `coders`.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use `teamBattleByTeam` instead. 
    Integer conditionsMinRatingRating = 56; // Integer | Minimum rating to join. Leave empty to let everyone join the tournament.
    Integer conditionsMaxRatingRating = 56; // Integer | Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament.
    Integer conditionsNbRatedGameNb = 56; // Integer | Minimum number of rated games required to join.
    try {
      Object result = apiInstance.apiTournamentPost(clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, teambBattleByTeam, conditionsTeamMemberTeamId, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ArenaTournamentsApi#apiTournamentPost");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **clockTime** | **BigDecimal**| Clock initial time in minutes | [enum: 0, 0.25, 0.5, 0.75, 1, 1.5, 2, 3, 4, 5, 6, 7, 10, 15, 20, 25, 30, 40, 50, 60]
 **clockIncrement** | **Integer**| Clock increment in seconds |
 **minutes** | **Integer**| How long the tournament lasts, in minutes |
 **name** | **String**| The tournament name. Leave empty to get a random Grandmaster name | [optional]
 **waitMinutes** | **Integer**| How long to wait before starting the tournament, from now, in minutes | [optional] [default to 5]
 **startDate** | **Integer**| Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting | [optional]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **rated** | **Boolean**| Games are rated and impact players ratings | [optional] [default to true]
 **position** | **String**| Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). | [optional]
 **berserkable** | **Boolean**| Whether the players can use berserk | [optional] [default to true]
 **streakable** | **Boolean**| After 2 wins, consecutive wins grant 4 points instead of 2. | [optional] [default to true]
 **hasChat** | **Boolean**| Whether the players can discuss in a chat | [optional] [default to true]
 **description** | **String**| Anything you want to tell players about the tournament | [optional]
 **password** | **String**| Make the tournament private, and restrict access with a password | [optional]
 **teambBattleByTeam** | **String**| Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost).  | [optional]
 **conditionsTeamMemberTeamId** | **String**| Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. &#x60;https://lichess.org/team/coders&#x60; has teamId &#x3D; &#x60;coders&#x60;.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use &#x60;teamBattleByTeam&#x60; instead.  | [optional]
 **conditionsMinRatingRating** | **Integer**| Minimum rating to join. Leave empty to let everyone join the tournament. | [optional]
 **conditionsMaxRatingRating** | **Integer**| Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. | [optional]
 **conditionsNbRatedGameNb** | **Integer**| Minimum number of rated games required to join. | [optional]

### Return type

**Object**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The Arena tournament has been successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the Arena tournament failed. |  -  |

<a name="apiTournamentTeamBattlePost"></a>
# **apiTournamentTeamBattlePost**
> Object apiTournamentTeamBattlePost(id, teams, nbLeaders)

Update a team battle

Set the teams and number of leaders of a team battle.  To update the other attributes of a team battle, use the [tournament update endpoint](#operation/apiTournamentUpdate). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ArenaTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ArenaTournamentsApi apiInstance = new ArenaTournamentsApi(defaultClient);
    String id = "id_example"; // String | The tournament ID (8 characters)..
    String teams = "teams_example"; // String | All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: `coders,zhigalko_sergei-fan-club,hhSwTKZv` 
    Integer nbLeaders = 56; // Integer | Number team leaders per team.
    try {
      Object result = apiInstance.apiTournamentTeamBattlePost(id, teams, nbLeaders);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ArenaTournamentsApi#apiTournamentTeamBattlePost");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID (8 characters).. |
 **teams** | **String**| All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: &#x60;coders,zhigalko_sergei-fan-club,hhSwTKZv&#x60;  |
 **nbLeaders** | **Integer**| Number team leaders per team. |

### Return type

**Object**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The team battle tournament was successfully updated. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The update of the team battle tournament failed. |  -  |

<a name="apiTournamentTerminate"></a>
# **apiTournamentTerminate**
> Ok apiTournamentTerminate(id)

Terminate an Arena tournament

Terminate an Arena tournament 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ArenaTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ArenaTournamentsApi apiInstance = new ArenaTournamentsApi(defaultClient);
    String id = "hL7vMrFQ"; // String | The tournament ID.
    try {
      Ok result = apiInstance.apiTournamentTerminate(id);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ArenaTournamentsApi#apiTournamentTerminate");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID. |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The tournament was successfully terminated. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Terminating the tournament failed. |  -  |

<a name="apiTournamentUpdate"></a>
# **apiTournamentUpdate**
> Object apiTournamentUpdate(id, clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb)

Update an Arena tournament

Update an Arena tournament.  Be mindful not to make important changes to ongoing tournaments.  Can be used to update a team battle. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ArenaTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ArenaTournamentsApi apiInstance = new ArenaTournamentsApi(defaultClient);
    String id = "id_example"; // String | The tournament ID.
    BigDecimal clockTime = new BigDecimal("0"); // BigDecimal | Clock initial time in minutes
    Integer clockIncrement = 56; // Integer | Clock increment in seconds
    Integer minutes = 56; // Integer | How long the tournament lasts, in minutes
    String name = "name_example"; // String | The tournament name. Leave empty to get a random Grandmaster name
    Integer waitMinutes = 5; // Integer | How long to wait before starting the tournament, from now, in minutes
    Integer startDate = 56; // Integer | Timestamp to start the tournament at a given date and time. Overrides the `waitMinutes` setting
    VariantKey variant = VariantKey.fromValue("standard"); // VariantKey | 
    Boolean rated = true; // Boolean | Games are rated and impact players ratings
    String position = "position_example"; // String | Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960).
    Boolean berserkable = true; // Boolean | Whether the players can use berserk
    Boolean streakable = true; // Boolean | After 2 wins, consecutive wins grant 4 points instead of 2.
    Boolean hasChat = true; // Boolean | Whether the players can discuss in a chat
    String description = "description_example"; // String | Anything you want to tell players about the tournament
    String password = "password_example"; // String | Make the tournament private, and restrict access with a password
    Integer conditionsMinRatingRating = 56; // Integer | Minimum rating to join. Leave empty to let everyone join the tournament.
    Integer conditionsMaxRatingRating = 56; // Integer | Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament.
    Integer conditionsNbRatedGameNb = 56; // Integer | Minimum number of rated games required to join.
    try {
      Object result = apiInstance.apiTournamentUpdate(id, clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ArenaTournamentsApi#apiTournamentUpdate");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID. |
 **clockTime** | **BigDecimal**| Clock initial time in minutes | [enum: 0, 0.25, 0.5, 0.75, 1, 1.5, 2, 3, 4, 5, 6, 7, 10, 15, 20, 25, 30, 40, 50, 60]
 **clockIncrement** | **Integer**| Clock increment in seconds |
 **minutes** | **Integer**| How long the tournament lasts, in minutes |
 **name** | **String**| The tournament name. Leave empty to get a random Grandmaster name | [optional]
 **waitMinutes** | **Integer**| How long to wait before starting the tournament, from now, in minutes | [optional] [default to 5]
 **startDate** | **Integer**| Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting | [optional]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.STANDARD] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **rated** | **Boolean**| Games are rated and impact players ratings | [optional] [default to true]
 **position** | **String**| Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). | [optional]
 **berserkable** | **Boolean**| Whether the players can use berserk | [optional] [default to true]
 **streakable** | **Boolean**| After 2 wins, consecutive wins grant 4 points instead of 2. | [optional] [default to true]
 **hasChat** | **Boolean**| Whether the players can discuss in a chat | [optional] [default to true]
 **description** | **String**| Anything you want to tell players about the tournament | [optional]
 **password** | **String**| Make the tournament private, and restrict access with a password | [optional]
 **conditionsMinRatingRating** | **Integer**| Minimum rating to join. Leave empty to let everyone join the tournament. | [optional]
 **conditionsMaxRatingRating** | **Integer**| Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. | [optional]
 **conditionsNbRatedGameNb** | **Integer**| Minimum number of rated games required to join. | [optional]

### Return type

**Object**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The Arena tournament was successfully updated. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The update of the Arena tournament failed. |  -  |

<a name="apiTournamentWithdraw"></a>
# **apiTournamentWithdraw**
> Ok apiTournamentWithdraw(id)

Pause of leave an Arena tournament

Leave a future Arena tournament, or take a break on an ongoing Arena tournament. It&#39;s possible to join again later. Points and streaks are preserved. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ArenaTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ArenaTournamentsApi apiInstance = new ArenaTournamentsApi(defaultClient);
    String id = "hL7vMrFQ"; // String | The tournament ID.
    try {
      Ok result = apiInstance.apiTournamentWithdraw(id);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ArenaTournamentsApi#apiTournamentWithdraw");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID. |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The tournament was successfully paused or left. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Pausing/leaving the tournament failed. |  -  |

<a name="apiUserNameTournamentCreated"></a>
# **apiUserNameTournamentCreated**
> Object apiUserNameTournamentCreated(username, status)

Get tournaments created by a user

Get all tournaments created by a given user.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ArenaTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    ArenaTournamentsApi apiInstance = new ArenaTournamentsApi(defaultClient);
    String username = "username_example"; // String | The user whose created tournaments to fetch
    Integer status = 10; // Integer | Include tournaments in the given status: \"Created\" (10), \"Started\" (20), \"Finished\" (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: `?status=10&status=20` 
    try {
      Object result = apiInstance.apiUserNameTournamentCreated(username, status);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ArenaTournamentsApi#apiUserNameTournamentCreated");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**| The user whose created tournaments to fetch |
 **status** | **Integer**| Include tournaments in the given status: \&quot;Created\&quot; (10), \&quot;Started\&quot; (20), \&quot;Finished\&quot; (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: &#x60;?status&#x3D;10&amp;status&#x3D;20&#x60;  | [optional] [enum: 10, 20, 30]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of tournaments created by the user. |  * Access-Control-Allow-Origin -  <br>  |

<a name="gamesByTournament"></a>
# **gamesByTournament**
> Object gamesByTournament(id, player, moves, pgnInJson, tags, clocks, evals, opening)

Export games of an Arena tournament

Download games of a tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first) 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ArenaTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    ArenaTournamentsApi apiInstance = new ArenaTournamentsApi(defaultClient);
    String id = "id_example"; // String | The tournament ID.
    String player = "player_example"; // String | Only games of a particular player. Leave empty to fetch games of all players.
    Boolean moves = true; // Boolean | Include the PGN moves.
    Boolean pgnInJson = false; // Boolean | Include the full PGN within the JSON response, in a `pgn` field.
    Boolean tags = true; // Boolean | Include the PGN tags.
    Boolean clocks = false; // Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
    Boolean evals = false; // Boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }` 
    Boolean opening = false; // Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
    try {
      Object result = apiInstance.gamesByTournament(id, player, moves, pgnInJson, tags, clocks, evals, opening);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ArenaTournamentsApi#gamesByTournament");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID. |
 **player** | **String**| Only games of a particular player. Leave empty to fetch games of all players. | [optional]
 **moves** | **Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | [optional] [default to false]
 **tags** | **Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to false]
 **evals** | **Boolean**| Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | [optional] [default to false]
 **opening** | **Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to false]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of games of an Arena tournament. |  * Access-Control-Allow-Origin -  <br>  |

<a name="resultsByTournament"></a>
# **resultsByTournament**
> Object resultsByTournament(id, nb)

Get results of an Arena tournament

Players of an Arena tournament, with their score and performance, sorted by rank (best first).  **Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON)**, i.e. one JSON object per line.  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ArenaTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    ArenaTournamentsApi apiInstance = new ArenaTournamentsApi(defaultClient);
    String id = "id_example"; // String | The tournament ID.
    Integer nb = 56; // Integer | Max number of players to fetch
    try {
      Object result = apiInstance.resultsByTournament(id, nb);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ArenaTournamentsApi#resultsByTournament");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID. |
 **nb** | **Integer**| Max number of players to fetch | [optional]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The results of the Arena tournament. |  * Access-Control-Allow-Origin -  <br>  |

<a name="teamsByTournament"></a>
# **teamsByTournament**
> Object teamsByTournament(id)

Get team standing of a team battle

Teams of a team battle tournament, with top players, sorted by rank (best first). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ArenaTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    ArenaTournamentsApi apiInstance = new ArenaTournamentsApi(defaultClient);
    String id = "id_example"; // String | The tournament ID.
    try {
      Object result = apiInstance.teamsByTournament(id);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ArenaTournamentsApi#teamsByTournament");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID. |

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of teams of a team battle tournament, with their respective top players. |  * Access-Control-Allow-Origin -  <br>  |

<a name="tournament"></a>
# **tournament**
> Object tournament(id, page)

Get info about an Arena tournament

Get detailed info about recently finished, current, or upcoming tournament&#39;s duels, player standings, and other info. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ArenaTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    ArenaTournamentsApi apiInstance = new ArenaTournamentsApi(defaultClient);
    String id = "id_example"; // String | The tournament ID.
    BigDecimal page = new BigDecimal("1"); // BigDecimal | Specify which page of player standings to view.
    try {
      Object result = apiInstance.tournament(id, page);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ArenaTournamentsApi#tournament");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID. |
 **page** | **BigDecimal**| Specify which page of player standings to view. | [optional] [default to 1]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The information of the Arena tournament. |  * Access-Control-Allow-Origin -  <br>  |

