# BoardApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiBoardSeek**](BoardApi.md#apiBoardSeek) | **POST** /api/board/seek | Create a seek
[**apiStreamEvent**](BoardApi.md#apiStreamEvent) | **GET** /api/stream/event | Stream incoming events
[**boardGameAbort**](BoardApi.md#boardGameAbort) | **POST** /api/board/game/{gameId}/abort | Abort a game
[**boardGameChatGet**](BoardApi.md#boardGameChatGet) | **GET** /api/board/game/{gameId}/chat | Fetch the game chat
[**boardGameChatPost**](BoardApi.md#boardGameChatPost) | **POST** /api/board/game/{gameId}/chat | Write in the chat
[**boardGameClaimVictory**](BoardApi.md#boardGameClaimVictory) | **POST** /api/board/game/{gameId}/claim-victory | Claim victory of a game
[**boardGameDraw**](BoardApi.md#boardGameDraw) | **POST** /api/board/game/{gameId}/draw/{accept} | Handle draw offers
[**boardGameMove**](BoardApi.md#boardGameMove) | **POST** /api/board/game/{gameId}/move/{move} | Make a Board move
[**boardGameResign**](BoardApi.md#boardGameResign) | **POST** /api/board/game/{gameId}/resign | Resign a game
[**boardGameStream**](BoardApi.md#boardGameStream) | **GET** /api/board/game/stream/{gameId} | Stream Board game state
[**boardGameTakeback**](BoardApi.md#boardGameTakeback) | **POST** /api/board/game/{gameId}/takeback/{accept} | Handle takeback offers


<a name="apiBoardSeek"></a>
# **apiBoardSeek**
> apiBoardSeek(rated, time, increment, days, variant, color, ratingRange)

Create a seek

   Create a public seek, to start a game with a random player.    ### Real-time seek    Specify the &#x60;time&#x60; and &#x60;increment&#x60; clock values.  The response is streamed but doesn&#39;t contain any information.    **Keep the connection open to keep the seek active**.    If the client closes the connection, the seek is canceled. This way, if the client terminates, the user won&#39;t be paired in a game they wouldn&#39;t play.   When the seek is accepted, or expires, the server closes the connection.    **Make sure to also have an [Event stream](#operation/apiStreamEvent) open**, to be notified when a game starts.   We recommend opening the [Event stream](#operation/apiStreamEvent) first, then the seek stream. This way,   you won&#39;t miss the game event if the seek is accepted immediately.    ### Correspondence seek    Specify the &#x60;days&#x60; per turn value.  The response is not streamed, it immediately completes with the seek ID. The seek remains active on the server until it is joined by someone.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BoardApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BoardApi apiInstance = new BoardApi(defaultClient);
    Boolean rated = false; // Boolean | Whether the game is rated and impacts players ratings.
    BigDecimal time = new BigDecimal(78); // BigDecimal | Clock initial time in minutes. Required for real-time seeks.
    Integer increment = 56; // Integer | Clock increment in seconds. Required for real-time seeks.
    Integer days = 1; // Integer | Days per turn. Required for correspondence seeks.
    VariantKey variant = VariantKey.fromValue("standard"); // VariantKey | 
    String color = "random"; // String | The color to play. Better left empty to automatically get 50% white.
    String ratingRange = "ratingRange_example"; // String | The rating range of potential opponents. Better left empty. Example: 1500-1800 
    try {
      apiInstance.apiBoardSeek(rated, time, increment, days, variant, color, ratingRange);
    } catch (ApiException e) {
      System.err.println("Exception when calling BoardApi#apiBoardSeek");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **rated** | **Boolean**| Whether the game is rated and impacts players ratings. | [optional] [default to false]
 **time** | **BigDecimal**| Clock initial time in minutes. Required for real-time seeks. | [optional]
 **increment** | **Integer**| Clock increment in seconds. Required for real-time seeks. | [optional]
 **days** | **Integer**| Days per turn. Required for correspondence seeks. | [optional] [enum: 1, 3, 5, 7, 10, 14]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.STANDARD] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **color** | **String**| The color to play. Better left empty to automatically get 50% white. | [optional] [default to random] [enum: random, white, black]
 **ratingRange** | **String**| The rating range of potential opponents. Better left empty. Example: 1500-1800  | [optional]

### Return type

null (empty response body)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: text/plain, application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The seek was successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the seek failed. |  -  |

<a name="apiStreamEvent"></a>
# **apiStreamEvent**
> ApiStreamEvent apiStreamEvent()

Stream incoming events

   Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameStart&#x60; Start of a game   - &#x60;gameFinish&#x60; Completion of a game   - &#x60;challenge&#x60; A player sends you a challenge   - &#x60;challengeCanceled&#x60; A player cancels their challenge to you   - &#x60;challengeDeclined&#x60; The opponent declines your challenge     When the stream opens, all current challenges and games are sent.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BoardApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BoardApi apiInstance = new BoardApi(defaultClient);
    try {
      ApiStreamEvent result = apiInstance.apiStreamEvent();
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BoardApi#apiStreamEvent");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**ApiStreamEvent**](ApiStreamEvent.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of events reaching the logged in user. |  * Access-Control-Allow-Origin -  <br>  |

<a name="boardGameAbort"></a>
# **boardGameAbort**
> Ok boardGameAbort(gameId)

Abort a game

Abort a game being played with the Board API. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BoardApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BoardApi apiInstance = new BoardApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    try {
      Ok result = apiInstance.boardGameAbort(gameId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BoardApi#boardGameAbort");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game successfully aborted. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The abortion of the game failed. |  -  |

<a name="boardGameChatGet"></a>
# **boardGameChatGet**
> Object boardGameChatGet(gameId)

Fetch the game chat

Get the messages posted in the game chat 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BoardApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BoardApi apiInstance = new BoardApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    try {
      Object result = apiInstance.boardGameChatGet(gameId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BoardApi#boardGameChatGet");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |

### Return type

**Object**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The messages posted in the chat. |  * Access-Control-Allow-Origin -  <br>  |

<a name="boardGameChatPost"></a>
# **boardGameChatPost**
> Ok boardGameChatPost(gameId, room, text)

Write in the chat

Post a message to the player or spectator chat, in a game being played with the Board API. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BoardApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BoardApi apiInstance = new BoardApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    String room = "player"; // String | 
    String text = "text_example"; // String | 
    try {
      Ok result = apiInstance.boardGameChatPost(gameId, room, text);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BoardApi#boardGameChatPost");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |
 **room** | **String**|  | [enum: player, spectator]
 **text** | **String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The message was successfully posted in the chat. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The posting of the message in the chat failed. |  -  |

<a name="boardGameClaimVictory"></a>
# **boardGameClaimVictory**
> Ok boardGameClaimVictory(gameId)

Claim victory of a game

Claim victory when the opponent has left the game for a while. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BoardApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BoardApi apiInstance = new BoardApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    try {
      Ok result = apiInstance.boardGameClaimVictory(gameId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BoardApi#boardGameClaimVictory");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The victory was successfully claimed. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The victory claim has failed. |  -  |

<a name="boardGameDraw"></a>
# **boardGameDraw**
> Ok boardGameDraw(gameId, accept)

Handle draw offers

Create/accept/decline draw offers. - &#x60;yes&#x60;: Offer a draw, or accept the opponent&#39;s draw offer. - &#x60;no&#x60;: Decline a draw offer from the opponent. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BoardApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BoardApi apiInstance = new BoardApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    Boolean accept = false; // Boolean | 
    try {
      Ok result = apiInstance.boardGameDraw(gameId, accept);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BoardApi#boardGameDraw");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |
 **accept** | **Boolean**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The draw offer was successfully sent. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The draw offering failed. |  -  |

<a name="boardGameMove"></a>
# **boardGameMove**
> Ok boardGameMove(gameId, move, offeringDraw)

Make a Board move

Make a move in a game being played with the Board API.  The move can also contain a draw offer/agreement. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BoardApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BoardApi apiInstance = new BoardApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    String move = "e2e4"; // String | The move to play, in UCI format
    Boolean offeringDraw = true; // Boolean | Whether to offer (or agree to) a draw
    try {
      Ok result = apiInstance.boardGameMove(gameId, move, offeringDraw);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BoardApi#boardGameMove");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |
 **move** | **String**| The move to play, in UCI format |
 **offeringDraw** | **Boolean**| Whether to offer (or agree to) a draw | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The move was successfully made. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The move failed. |  -  |

<a name="boardGameResign"></a>
# **boardGameResign**
> Ok boardGameResign(gameId)

Resign a game

Resign a game being played with the Board API. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BoardApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BoardApi apiInstance = new BoardApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    try {
      Ok result = apiInstance.boardGameResign(gameId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BoardApi#boardGameResign");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game was successfully resigned. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The resigning from the game failed. |  -  |

<a name="boardGameStream"></a>
# **boardGameStream**
> GameStreamEvent boardGameStream(gameId)

Stream Board game state

 Stream the state of a game being played with the Board API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameFull&#x60; Full game data. All values are immutable, except for the &#x60;state&#x60; field.   - &#x60;gameState&#x60; Current state of the game. Immutable values not included. Sent when a move is played, a draw is offered, or when the game ends.   - &#x60;chatLine&#x60; Chat message sent by a user in the &#x60;room&#x60; \&quot;player\&quot; or \&quot;spectator\&quot;.    The first line is always of type &#x60;gameFull&#x60;.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BoardApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BoardApi apiInstance = new BoardApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    try {
      GameStreamEvent result = apiInstance.boardGameStream(gameId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BoardApi#boardGameStream");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |

### Return type

[**GameStreamEvent**](GameStreamEvent.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson, application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of the game. |  * Access-Control-Allow-Origin -  <br>  |
**404** | The game was not found. |  -  |

<a name="boardGameTakeback"></a>
# **boardGameTakeback**
> Ok boardGameTakeback(gameId, accept)

Handle takeback offers

Create/accept/decline takebacks. - &#x60;yes&#x60;: Propose a takeback, or accept the opponent&#39;s takeback offer. - &#x60;no&#x60;: Decline a takeback offer from the opponent. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BoardApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BoardApi apiInstance = new BoardApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    Boolean accept = false; // Boolean | 
    try {
      Ok result = apiInstance.boardGameTakeback(gameId, accept);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BoardApi#boardGameTakeback");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |
 **accept** | **Boolean**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The takeback offer was successfully sent. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The takeback offering failed. |  -  |

