# BotApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiBotOnline**](BotApi.md#apiBotOnline) | **GET** /api/bot/online | Get online bots
[**apiStreamEvent**](BotApi.md#apiStreamEvent) | **GET** /api/stream/event | Stream incoming events
[**botAccountUpgrade**](BotApi.md#botAccountUpgrade) | **POST** /api/bot/account/upgrade | Upgrade to Bot account
[**botGameAbort**](BotApi.md#botGameAbort) | **POST** /api/bot/game/{gameId}/abort | Abort a game
[**botGameChat**](BotApi.md#botGameChat) | **POST** /api/bot/game/{gameId}/chat | Write in the chat
[**botGameMove**](BotApi.md#botGameMove) | **POST** /api/bot/game/{gameId}/move/{move} | Make a Bot move
[**botGameResign**](BotApi.md#botGameResign) | **POST** /api/bot/game/{gameId}/resign | Resign a game
[**botGameStream**](BotApi.md#botGameStream) | **GET** /api/bot/game/stream/{gameId} | Stream Bot game state


<a name="apiBotOnline"></a>
# **apiBotOnline**
> User apiBotOnline(nb)

Get online bots

Stream the [online bot users](https://lichess.org/player/bots), as [ndjson](#section/Introduction/Streaming-with-ND-JSON). Throttled to 50 bot users per second.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BotApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    BotApi apiInstance = new BotApi(defaultClient);
    Integer nb = 20; // Integer | How many bot users to fetch
    try {
      User result = apiInstance.apiBotOnline(nb);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BotApi#apiBotOnline");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nb** | **Integer**| How many bot users to fetch | [optional]

### Return type

[**User**](User.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of online bot users |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiStreamEvent"></a>
# **apiStreamEvent**
> ApiStreamEvent apiStreamEvent()

Stream incoming events

   Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameStart&#x60; Start of a game   - &#x60;gameFinish&#x60; Completion of a game   - &#x60;challenge&#x60; A player sends you a challenge   - &#x60;challengeCanceled&#x60; A player cancels their challenge to you   - &#x60;challengeDeclined&#x60; The opponent declines your challenge     When the stream opens, all current challenges and games are sent.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BotApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BotApi apiInstance = new BotApi(defaultClient);
    try {
      ApiStreamEvent result = apiInstance.apiStreamEvent();
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BotApi#apiStreamEvent");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**ApiStreamEvent**](ApiStreamEvent.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of events reaching the logged in user. |  * Access-Control-Allow-Origin -  <br>  |

<a name="botAccountUpgrade"></a>
# **botAccountUpgrade**
> Ok botAccountUpgrade()

Upgrade to Bot account

Upgrade a lichess player account into a Bot account. Only Bot accounts can use the Bot API.  The account **cannot have played any game** before becoming a Bot account. The upgrade is **irreversible**. The account will only be able to play as a Bot.  To upgrade an account to Bot, use the [official lichess-bot client](https://github.com/careless25/lichess-bot), or follow these steps: - Create an [API access token](https://lichess.org/account/oauth/token/create?scopes[]&#x3D;bot:play) with \&quot;Play bot moves\&quot; permission. - &#x60;curl -d &#39;&#39; https://lichess.org/api/bot/account/upgrade -H \&quot;Authorization: Bearer &lt;yourTokenHere&gt;\&quot;&#x60;  To know if an account has already been upgraded, use the [Get my profile API](#operation/accountMe): the &#x60;title&#x60; field should be set to &#x60;BOT&#x60;. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BotApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BotApi apiInstance = new BotApi(defaultClient);
    try {
      Ok result = apiInstance.botAccountUpgrade();
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BotApi#botAccountUpgrade");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The bot account was successfully upgraded. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The upgrade of the bot account failed. |  -  |

<a name="botGameAbort"></a>
# **botGameAbort**
> Ok botGameAbort(gameId)

Abort a game

Abort a game being played with the Bot API. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BotApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BotApi apiInstance = new BotApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    try {
      Ok result = apiInstance.botGameAbort(gameId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BotApi#botGameAbort");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game was successfully aborted. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The abortion of the game failed. |  -  |

<a name="botGameChat"></a>
# **botGameChat**
> Ok botGameChat(gameId, room, text)

Write in the chat

Post a message to the player or spectator chat, in a game being played with the Bot API. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BotApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BotApi apiInstance = new BotApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    String room = "player"; // String | 
    String text = "text_example"; // String | 
    try {
      Ok result = apiInstance.botGameChat(gameId, room, text);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BotApi#botGameChat");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |
 **room** | **String**|  | [enum: player, spectator]
 **text** | **String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The message was successfully posted in chat. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The posting of the  message in chat failed. |  -  |

<a name="botGameMove"></a>
# **botGameMove**
> Ok botGameMove(gameId, move, offeringDraw)

Make a Bot move

Make a move in a game being played with the Bot API.  The move can also contain a draw offer/agreement. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BotApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BotApi apiInstance = new BotApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    String move = "e2e4"; // String | The move to play, in UCI format
    Boolean offeringDraw = true; // Boolean | Whether to offer (or agree to) a draw
    try {
      Ok result = apiInstance.botGameMove(gameId, move, offeringDraw);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BotApi#botGameMove");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |
 **move** | **String**| The move to play, in UCI format |
 **offeringDraw** | **Boolean**| Whether to offer (or agree to) a draw | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The bot move was successfully made. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The bot move failed. |  -  |

<a name="botGameResign"></a>
# **botGameResign**
> Ok botGameResign(gameId)

Resign a game

Resign a game being played with the Bot API. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BotApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BotApi apiInstance = new BotApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    try {
      Ok result = apiInstance.botGameResign(gameId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BotApi#botGameResign");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game was successfully resigned from. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Resigning the game failed. |  -  |

<a name="botGameStream"></a>
# **botGameStream**
> GameStreamEvent botGameStream(gameId)

Stream Bot game state

 Stream the state of a game being played with the Bot API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameFull&#x60; Full game data. All values are immutable, except for the &#x60;state&#x60; field.   - &#x60;gameState&#x60; Current state of the game. Immutable values not included.   - &#x60;chatLine&#x60; Chat message sent by a user (or the bot itself) in the &#x60;room&#x60; \&quot;player\&quot; or \&quot;spectator\&quot;.    The first line is always of type &#x60;gameFull&#x60;.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BotApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BotApi apiInstance = new BotApi(defaultClient);
    String gameId = "5IrD6Gzz"; // String | 
    try {
      GameStreamEvent result = apiInstance.botGameStream(gameId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BotApi#botGameStream");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |

### Return type

[**GameStreamEvent**](GameStreamEvent.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson, application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of the bot game. |  * Access-Control-Allow-Origin -  <br>  |
**404** | The bot game was not found. |  -  |

