# BroadcastsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**broadcastAllRoundsPgn**](BroadcastsApi.md#broadcastAllRoundsPgn) | **GET** /api/broadcast/{broadcastTournamentId}.pgn | Export all rounds as PGN
[**broadcastIndex**](BroadcastsApi.md#broadcastIndex) | **GET** /api/broadcast | Get official broadcasts
[**broadcastPush**](BroadcastsApi.md#broadcastPush) | **POST** /broadcast/round/{broadcastRoundId}/push | Push PGN to your broadcast round
[**broadcastRoundCreate**](BroadcastsApi.md#broadcastRoundCreate) | **POST** /broadcast/{broadcastTournamentId}/new | Create a broadcast round
[**broadcastRoundGet**](BroadcastsApi.md#broadcastRoundGet) | **GET** /broadcast/{broadcastTournamentSlug}/{broadcastRoundSlug}/{broadcastRoundId} | Get your broadcast round
[**broadcastRoundPgn**](BroadcastsApi.md#broadcastRoundPgn) | **GET** /api/broadcast/round/{broadcastRoundId}.pgn | Export one round as PGN
[**broadcastRoundUpdate**](BroadcastsApi.md#broadcastRoundUpdate) | **POST** /broadcast/round/{broadcastRoundId}/edit | Update your broadcast round
[**broadcastStreamRoundPgn**](BroadcastsApi.md#broadcastStreamRoundPgn) | **GET** /api/stream/broadcast/round/{broadcastRoundId}.pgn | Stream an ongoing broadcast tournament as PGN
[**broadcastTourCreate**](BroadcastsApi.md#broadcastTourCreate) | **POST** /broadcast/new | Create a broadcast tournament
[**broadcastTourGet**](BroadcastsApi.md#broadcastTourGet) | **GET** /broadcast/{slug}/{broadcastTournamentId} | Get your broadcast tournament
[**broadcastTourUpdate**](BroadcastsApi.md#broadcastTourUpdate) | **POST** /broadcast/{broadcastTournamentId}/edit | Update your broadcast tournament


<a name="broadcastAllRoundsPgn"></a>
# **broadcastAllRoundsPgn**
> Object broadcastAllRoundsPgn(broadcastTournamentId)

Export all rounds as PGN

Download all games of all rounds of a broadcast in PGN format.  You may want to [download only the games of a single round](#operation/broadcastRoundPgn) instead. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BroadcastsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    BroadcastsApi apiInstance = new BroadcastsApi(defaultClient);
    String broadcastTournamentId = "broadcastTournamentId_example"; // String | The broadcast tournament ID (8 characters).
    try {
      Object result = apiInstance.broadcastAllRoundsPgn(broadcastTournamentId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BroadcastsApi#broadcastAllRoundsPgn");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastTournamentId** | **String**| The broadcast tournament ID (8 characters). |

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The PGN representation of the broadcast. |  * Access-Control-Allow-Origin -  <br>  |

<a name="broadcastIndex"></a>
# **broadcastIndex**
> List&lt;Object&gt; broadcastIndex(nb)

Get official broadcasts

Get all incoming, ongoing, and finished official broadcasts. The broadcasts are sorted by start date, most recent first.  Broadcasts are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BroadcastsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    BroadcastsApi apiInstance = new BroadcastsApi(defaultClient);
    Integer nb = 20; // Integer | Max number of broadcasts to fetch
    try {
      List<Object> result = apiInstance.broadcastIndex(nb);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BroadcastsApi#broadcastIndex");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nb** | **Integer**| Max number of broadcasts to fetch | [optional] [default to 20]

### Return type

**List&lt;Object&gt;**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of official broadcasts. |  * Access-Control-Allow-Origin -  <br>  |

<a name="broadcastPush"></a>
# **broadcastPush**
> List&lt;Ok&gt; broadcastPush(broadcastRoundId, body)

Push PGN to your broadcast round

Update your broadcast with new PGN. Only for broadcast without a source URL. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BroadcastsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BroadcastsApi apiInstance = new BroadcastsApi(defaultClient);
    String broadcastRoundId = "broadcastRoundId_example"; // String | The broadcast round ID (8 characters).
    String body = "body_example"; // String | The PGN. It can contain up to 64 games, separated by a double new line.
    try {
      List<Ok> result = apiInstance.broadcastPush(broadcastRoundId, body);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BroadcastsApi#broadcastPush");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastRoundId** | **String**| The broadcast round ID (8 characters). |
 **body** | **String**| The PGN. It can contain up to 64 games, separated by a double new line. |

### Return type

[**List&lt;Ok&gt;**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The broadcast was successfully updated. |  * Access-Control-Allow-Origin -  <br>  |

<a name="broadcastRoundCreate"></a>
# **broadcastRoundCreate**
> Object broadcastRoundCreate(broadcastTournamentId, name, syncUrl, startsAt)

Create a broadcast round

Create a new broadcast round to relay external games. This endpoint accepts the same form data as the web form. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BroadcastsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BroadcastsApi apiInstance = new BroadcastsApi(defaultClient);
    String broadcastTournamentId = "broadcastTournamentId_example"; // String | The broadcast tournament ID (8 characters).
    String name = "name_example"; // String | Name of the broadcast round. Length must be between 3 and 80 characters.  Example: `Round 1` 
    String syncUrl = "syncUrl_example"; // String | URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: `https://myserver.org/myevent/round-10/games.pgn`  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush). 
    Integer startsAt = 56; // Integer | Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: `1356998400070` 
    try {
      Object result = apiInstance.broadcastRoundCreate(broadcastTournamentId, name, syncUrl, startsAt);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BroadcastsApi#broadcastRoundCreate");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastTournamentId** | **String**| The broadcast tournament ID (8 characters). |
 **name** | **String**| Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 1&#x60;  |
 **syncUrl** | **String**| URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush).  | [optional]
 **startsAt** | **Integer**| Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: &#x60;1356998400070&#x60;  | [optional]

### Return type

**Object**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The broadcast round was successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the broadcast failed. |  -  |

<a name="broadcastRoundGet"></a>
# **broadcastRoundGet**
> List&lt;Object&gt; broadcastRoundGet(broadcastTournamentSlug, broadcastRoundSlug, broadcastRoundId)

Get your broadcast round

Get information about a broadcast round that you created. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BroadcastsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BroadcastsApi apiInstance = new BroadcastsApi(defaultClient);
    String broadcastTournamentSlug = "broadcastTournamentSlug_example"; // String | The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by `-`. Only the `broadcastRoundId` is actually used.
    String broadcastRoundSlug = "broadcastRoundSlug_example"; // String | The broadcast round slug. Only used for SEO, the slug can be safely replaced by `-`. Only the `broadcastRoundId` is actually used.
    String broadcastRoundId = "broadcastRoundId_example"; // String | The broadcast Round ID (8 characters).
    try {
      List<Object> result = apiInstance.broadcastRoundGet(broadcastTournamentSlug, broadcastRoundSlug, broadcastRoundId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BroadcastsApi#broadcastRoundGet");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastTournamentSlug** | **String**| The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. |
 **broadcastRoundSlug** | **String**| The broadcast round slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. |
 **broadcastRoundId** | **String**| The broadcast Round ID (8 characters). |

### Return type

**List&lt;Object&gt;**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The information about the broadcast round. |  -  |

<a name="broadcastRoundPgn"></a>
# **broadcastRoundPgn**
> Object broadcastRoundPgn(broadcastRoundId)

Export one round as PGN

Download all games of a single round of a broadcast tournament in PGN format.  You *could* poll this endpoint to get updates about a tournament, but it would be slow, and very inneficient.  Instead, consider [streaming the tournament](#operation/broadcastStreamRoundPgn) to get a new PGN every time a game is updated, in real-time. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BroadcastsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    BroadcastsApi apiInstance = new BroadcastsApi(defaultClient);
    String broadcastRoundId = "broadcastRoundId_example"; // String | The round ID (8 characters).
    try {
      Object result = apiInstance.broadcastRoundPgn(broadcastRoundId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BroadcastsApi#broadcastRoundPgn");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastRoundId** | **String**| The round ID (8 characters). |

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The PGN representation of the round. |  * Access-Control-Allow-Origin -  <br>  |

<a name="broadcastRoundUpdate"></a>
# **broadcastRoundUpdate**
> Ok broadcastRoundUpdate(broadcastRoundId, name, syncUrl, startsAt)

Update your broadcast round

Update information about a broadcast round that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. For instance, if you omit &#x60;startDate&#x60;, then any pre-existing start date will be removed. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BroadcastsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BroadcastsApi apiInstance = new BroadcastsApi(defaultClient);
    String broadcastRoundId = "broadcastRoundId_example"; // String | The broadcast round ID (8 characters).
    String name = "name_example"; // String | Name of the broadcast round. Length must be between 3 and 80 characters.  Example: `Round 10` 
    String syncUrl = "syncUrl_example"; // String | URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: `https://myserver.org/myevent/round-10/games.pgn` 
    Integer startsAt = 56; // Integer | Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: `1356998400070` 
    try {
      Ok result = apiInstance.broadcastRoundUpdate(broadcastRoundId, name, syncUrl, startsAt);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BroadcastsApi#broadcastRoundUpdate");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastRoundId** | **String**| The broadcast round ID (8 characters). |
 **name** | **String**| Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 10&#x60;  |
 **syncUrl** | **String**| URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  | [optional]
 **startsAt** | **Integer**| Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: &#x60;1356998400070&#x60;  | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The broadcast round was successfully edited. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The edition of the broadcast tournament failed. |  -  |

<a name="broadcastStreamRoundPgn"></a>
# **broadcastStreamRoundPgn**
> Object broadcastStreamRoundPgn(broadcastRoundId)

Stream an ongoing broadcast tournament as PGN

This streaming endpoint first sends all games of a broadcast tournament in PGN format.  Then, it waits for new moves to be played. As soon as it happens, the entire PGN of the game is sent to the stream.  The stream will also send PGNs when games are added to the tournament.  This is the best way to get updates about an ongoing tournament. Streaming means no polling, and no pollings means no latency, and minimum impact on the server. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BroadcastsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    BroadcastsApi apiInstance = new BroadcastsApi(defaultClient);
    String broadcastRoundId = "broadcastRoundId_example"; // String | The broadcast round ID (8 characters).
    try {
      Object result = apiInstance.broadcastStreamRoundPgn(broadcastRoundId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BroadcastsApi#broadcastStreamRoundPgn");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastRoundId** | **String**| The broadcast round ID (8 characters). |

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The PGN representation of the tournament games, then the PGNs of games as they are updated. |  * Access-Control-Allow-Origin -  <br>  |

<a name="broadcastTourCreate"></a>
# **broadcastTourCreate**
> Object broadcastTourCreate(name, description, markup, official)

Create a broadcast tournament

Create a new broadcast tournament to relay external games. This endpoint accepts the same form data as the [web form](https://lichess.org/broadcast/new). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BroadcastsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BroadcastsApi apiInstance = new BroadcastsApi(defaultClient);
    String name = "name_example"; // String | Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: `Sinquefield Cup` 
    String description = "description_example"; // String | Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: `An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.` 
    String markup = "markup_example"; // String | Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters.
    Boolean official = true; // Boolean | For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police.
    try {
      Object result = apiInstance.broadcastTourCreate(name, description, markup, official);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BroadcastsApi#broadcastTourCreate");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **String**| Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  |
 **description** | **String**| Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  |
 **markup** | **String**| Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters. | [optional]
 **official** | **Boolean**| For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. | [optional]

### Return type

**Object**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The broadcast tournament was successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the broadcast tournament failed. |  -  |

<a name="broadcastTourGet"></a>
# **broadcastTourGet**
> List&lt;Object&gt; broadcastTourGet(slug, broadcastTournamentId)

Get your broadcast tournament

Get information about a broadcast tournament that you created. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BroadcastsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BroadcastsApi apiInstance = new BroadcastsApi(defaultClient);
    String slug = "slug_example"; // String | The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by `-`. Only the `broadcastTournamentId` is actually used.
    String broadcastTournamentId = "broadcastTournamentId_example"; // String | The broadcast tournament ID (8 characters).
    try {
      List<Object> result = apiInstance.broadcastTourGet(slug, broadcastTournamentId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BroadcastsApi#broadcastTourGet");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **slug** | **String**| The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastTournamentId&#x60; is actually used. |
 **broadcastTournamentId** | **String**| The broadcast tournament ID (8 characters). |

### Return type

**List&lt;Object&gt;**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The information about the broadcast tournament. |  -  |

<a name="broadcastTourUpdate"></a>
# **broadcastTourUpdate**
> Ok broadcastTourUpdate(broadcastTournamentId, name, description, markup, official)

Update your broadcast tournament

Update information about a broadcast tournament that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BroadcastsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    BroadcastsApi apiInstance = new BroadcastsApi(defaultClient);
    String broadcastTournamentId = "broadcastTournamentId_example"; // String | The broadcast ID (8 characters).
    String name = "name_example"; // String | Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: `Sinquefield Cup` 
    String description = "description_example"; // String | Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: `An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.` 
    String markup = "markup_example"; // String | Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters.
    Boolean official = true; // Boolean | For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police.
    try {
      Ok result = apiInstance.broadcastTourUpdate(broadcastTournamentId, name, description, markup, official);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BroadcastsApi#broadcastTourUpdate");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastTournamentId** | **String**| The broadcast ID (8 characters). |
 **name** | **String**| Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  |
 **description** | **String**| Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  |
 **markup** | **String**| Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters. | [optional]
 **official** | **Boolean**| For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The broadcast tournament was successfully edited. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The edition of the broadcast tournament failed. |  -  |

