# ChallengesApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**adminChallengeTokens**](ChallengesApi.md#adminChallengeTokens) | **POST** /api/token/admin-challenge | Admin challenge tokens
[**challengeAccept**](ChallengesApi.md#challengeAccept) | **POST** /api/challenge/{challengeId}/accept | Accept a challenge
[**challengeAi**](ChallengesApi.md#challengeAi) | **POST** /api/challenge/ai | Challenge the AI
[**challengeCancel**](ChallengesApi.md#challengeCancel) | **POST** /api/challenge/{challengeId}/cancel | Cancel a challenge
[**challengeCreate**](ChallengesApi.md#challengeCreate) | **POST** /api/challenge/{username} | Create a challenge
[**challengeDecline**](ChallengesApi.md#challengeDecline) | **POST** /api/challenge/{challengeId}/decline | Decline a challenge
[**challengeList**](ChallengesApi.md#challengeList) | **GET** /api/challenge | List your challenges
[**challengeOpen**](ChallengesApi.md#challengeOpen) | **POST** /api/challenge/open | Open-ended challenge
[**challengeStartClocks**](ChallengesApi.md#challengeStartClocks) | **POST** /api/challenge/{gameId}/start-clocks | Start clocks of a game
[**roundAddTime**](ChallengesApi.md#roundAddTime) | **POST** /api/round/{gameId}/add-time/{seconds} | Add time to the opponent clock


<a name="adminChallengeTokens"></a>
# **adminChallengeTokens**
> adminChallengeTokens(users, description)

Admin challenge tokens

**For administrators only. You are not allowed to use this endpoint.**  Create and obtain &#x60;challenge:write&#x60; tokens for multiple users.  If a similar token already exists for a user, it is reused. This endpoint is idempotent. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ChallengesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ChallengesApi apiInstance = new ChallengesApi(defaultClient);
    String users = "users_example"; // String | Usernames separated with commas
    String description = "description_example"; // String | User visible description of the token
    try {
      apiInstance.adminChallengeTokens(users, description);
    } catch (ApiException e) {
      System.err.println("Exception when calling ChallengesApi#adminChallengeTokens");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **users** | **String**| Usernames separated with commas |
 **description** | **String**| User visible description of the token |

### Return type

null (empty response body)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The &#x60;challenge:write&#x60; tokens of each user |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the tokens failed. |  -  |

<a name="challengeAccept"></a>
# **challengeAccept**
> Ok challengeAccept(challengeId)

Accept a challenge

Accept an incoming challenge.  You should receive a &#x60;gameStart&#x60; event on the [incoming events stream](#operation/apiStreamEvent). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ChallengesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ChallengesApi apiInstance = new ChallengesApi(defaultClient);
    String challengeId = "5IrD6Gzz"; // String | 
    try {
      Ok result = apiInstance.challengeAccept(challengeId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ChallengesApi#challengeAccept");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **challengeId** | **String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The challenge was successfully accepted. |  * Access-Control-Allow-Origin -  <br>  |
**404** | The challenge to accept was not found. |  -  |

<a name="challengeAi"></a>
# **challengeAi**
> GameJson challengeAi(level, clockLimit, clockIncrement, days, color, variant, fen)

Challenge the AI

Start a game with Lichess AI.  You will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ChallengesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ChallengesApi apiInstance = new ChallengesApi(defaultClient);
    BigDecimal level = new BigDecimal(78); // BigDecimal | AI strength
    BigDecimal clockLimit = new BigDecimal(78); // BigDecimal | Clock initial time in seconds. If empty, a correspondence game is created.
    Integer clockIncrement = 56; // Integer | Clock increment in seconds. If empty, a correspondence game is created.
    Integer days = 56; // Integer | Days per move, for correspondence games. Clock settings must be omitted.
    String color = "random"; // String | Which color you get to play
    VariantKey variant = VariantKey.fromValue("standard"); // VariantKey | 
    String fen = "\"rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1\""; // String | Custom initial position (in FEN). Variant must be standard, and the game cannot be rated.
    try {
      GameJson result = apiInstance.challengeAi(level, clockLimit, clockIncrement, days, color, variant, fen);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ChallengesApi#challengeAi");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **level** | **BigDecimal**| AI strength | [optional]
 **clockLimit** | **BigDecimal**| Clock initial time in seconds. If empty, a correspondence game is created. | [optional]
 **clockIncrement** | **Integer**| Clock increment in seconds. If empty, a correspondence game is created. | [optional]
 **days** | **Integer**| Days per move, for correspondence games. Clock settings must be omitted. | [optional]
 **color** | **String**| Which color you get to play | [optional] [default to ColorEnum.RANDOM] [enum: random, white, black]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.STANDARD] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **fen** | **String**| Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. | [optional] [default to &quot;rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1&quot;]

### Return type

[**GameJson**](GameJson.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game with Lichess AI was successfully started. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of a game with Lichess AI failed. |  -  |

<a name="challengeCancel"></a>
# **challengeCancel**
> Ok challengeCancel(challengeId, opponentToken)

Cancel a challenge

Cancel a challenge you sent, or aborts the game if the challenge was accepted, but the game was not yet played. Note that the ID of a game is the same as the ID of the challenge that created it. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ChallengesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ChallengesApi apiInstance = new ChallengesApi(defaultClient);
    String challengeId = "5IrD6Gzz"; // String | 
    String opponentToken = "opponentToken_example"; // String | Optional `challenge:write` token of the opponent. If set, the game can be canceled even if both players have moved.
    try {
      Ok result = apiInstance.challengeCancel(challengeId, opponentToken);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ChallengesApi#challengeCancel");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **challengeId** | **String**|  |
 **opponentToken** | **String**| Optional &#x60;challenge:write&#x60; token of the opponent. If set, the game can be canceled even if both players have moved. | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The challenge was successfully cancelled. |  * Access-Control-Allow-Origin -  <br>  |
**404** | The challenge to cancel was not found. |  -  |

<a name="challengeCreate"></a>
# **challengeCreate**
> ChallengeJson challengeCreate(username, rated, clockLimit, clockIncrement, days, color, variant, fen, keepAliveStream, acceptByToken, message)

Create a challenge

Challenge someone to play. The targeted player can choose to accept or decline.  If the challenge is accepted, you will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. The game ID will be the same as the challenge ID.  If you also have an OAuth token with &#x60;challenge:write&#x60; scope for the receiving user, you can make them accept the challenge immediately by setting the &#x60;acceptByToken&#x60; field.  Challenges for realtime games (not correspondence) expire after 20s if not accepted. To prevent that, use the &#x60;keepAliveStream&#x60; flag described below. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ChallengesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ChallengesApi apiInstance = new ChallengesApi(defaultClient);
    String username = "LeelaChess"; // String | 
    Boolean rated = true; // Boolean | Game is rated and impacts players ratings
    BigDecimal clockLimit = new BigDecimal(78); // BigDecimal | Clock initial time in seconds. If empty, a correspondence game is created.
    Integer clockIncrement = 56; // Integer | Clock increment in seconds. If empty, a correspondence game is created.
    Integer days = 56; // Integer | Days per move, for correspondence games. Clock settings must be omitted.
    String color = "random"; // String | Which color you get to play
    VariantKey variant = VariantKey.fromValue("standard"); // VariantKey | 
    String fen = "\"rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1\""; // String | Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. Castling moves will use UCI_Chess960 notation, for example e1h1 instead of e1g1.
    Boolean keepAliveStream = true; // Boolean | If set, the response is streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). The challenge is kept alive until the connection is closed by the client. When the challenge is accepted, declined or canceled, a message of the form `{\\\"done\\\":\\\"accepted\\\"}` is sent, then the connection is closed by the server. If not set, the response is not streamed, and the challenge expires after 20s if not accepted. 
    String acceptByToken = "acceptByToken_example"; // String | Immediately accept the challenge and create the game. Pass in an OAuth token (with the `challenge:write` scope) for the receiving user. On success, the response will contain a `game` field instead of a `challenge` field.  Alternatively, consider the [bulk pairing API](#operation/bulkPairingCreate). 
    String message = "\"Your game with {opponent} is ready: {game}.\""; // String | **Only if `acceptByToken` is set.**  Message that is sent to each player, when the game is created. It is sent from your user account.  `{opponent}`, `{player}` and `{game}` are placeholders that will be replaced with the opponent name, player name, and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the `{game}` placeholder. 
    try {
      ChallengeJson result = apiInstance.challengeCreate(username, rated, clockLimit, clockIncrement, days, color, variant, fen, keepAliveStream, acceptByToken, message);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ChallengesApi#challengeCreate");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |
 **rated** | **Boolean**| Game is rated and impacts players ratings | [optional]
 **clockLimit** | **BigDecimal**| Clock initial time in seconds. If empty, a correspondence game is created. | [optional]
 **clockIncrement** | **Integer**| Clock increment in seconds. If empty, a correspondence game is created. | [optional]
 **days** | **Integer**| Days per move, for correspondence games. Clock settings must be omitted. | [optional]
 **color** | **String**| Which color you get to play | [optional] [default to random] [enum: random, white, black]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.STANDARD] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **fen** | **String**| Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. Castling moves will use UCI_Chess960 notation, for example e1h1 instead of e1g1. | [optional] [default to &quot;rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1&quot;]
 **keepAliveStream** | **Boolean**| If set, the response is streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). The challenge is kept alive until the connection is closed by the client. When the challenge is accepted, declined or canceled, a message of the form &#x60;{\\\&quot;done\\\&quot;:\\\&quot;accepted\\\&quot;}&#x60; is sent, then the connection is closed by the server. If not set, the response is not streamed, and the challenge expires after 20s if not accepted.  | [optional]
 **acceptByToken** | **String**| Immediately accept the challenge and create the game. Pass in an OAuth token (with the &#x60;challenge:write&#x60; scope) for the receiving user. On success, the response will contain a &#x60;game&#x60; field instead of a &#x60;challenge&#x60; field.  Alternatively, consider the [bulk pairing API](#operation/bulkPairingCreate).  | [optional]
 **message** | **String**| **Only if &#x60;acceptByToken&#x60; is set.**  Message that is sent to each player, when the game is created. It is sent from your user account.  &#x60;{opponent}&#x60;, &#x60;{player}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent name, player name, and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder.  | [optional] [default to &quot;Your game with {opponent} is ready: {game}.&quot;]

### Return type

[**ChallengeJson**](ChallengeJson.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The challenge was successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the challenge failed. |  -  |

<a name="challengeDecline"></a>
# **challengeDecline**
> Ok challengeDecline(challengeId, reason)

Decline a challenge

Decline an incoming challenge. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ChallengesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ChallengesApi apiInstance = new ChallengesApi(defaultClient);
    String challengeId = "5IrD6Gzz"; // String | 
    String reason = "generic"; // String | Reason challenge was declined. It will be translated to the player's language. See [the full list in the translation file](https://github.com/ornicar/lila/blob/43fbd61029ff3960a21fbd213944bed66325696d/translation/source/challenge.xml#L14).
    try {
      Ok result = apiInstance.challengeDecline(challengeId, reason);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ChallengesApi#challengeDecline");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **challengeId** | **String**|  |
 **reason** | **String**| Reason challenge was declined. It will be translated to the player&#39;s language. See [the full list in the translation file](https://github.com/ornicar/lila/blob/43fbd61029ff3960a21fbd213944bed66325696d/translation/source/challenge.xml#L14). | [optional] [enum: generic, later, tooFast, tooSlow, timeControl, rated, casual, standard, variant, noBot, onlyBot]

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The challenge was successfully declined. |  * Access-Control-Allow-Origin -  <br>  |
**404** | The challenge to decline was not found. |  -  |

<a name="challengeList"></a>
# **challengeList**
> InlineResponse2003 challengeList()

List your challenges

Get a list of challenges created by or targeted at you. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ChallengesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ChallengesApi apiInstance = new ChallengesApi(defaultClient);
    try {
      InlineResponse2003 result = apiInstance.challengeList();
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ChallengesApi#challengeList");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of challenges created by or targeted at the logged in user. |  * Access-Control-Allow-Origin -  <br>  |

<a name="challengeOpen"></a>
# **challengeOpen**
> Object challengeOpen(rated, clockLimit, clockIncrement, variant, fen, name)

Open-ended challenge

Create a challenge that any 2 players can join.  Share the URL of the challenge. the first 2 players to click it will be paired for a game.  The response body also contains &#x60;whiteUrl&#x60; and &#x60;blackUrl&#x60;. You can control which color each player gets by giving them these URLs, instead of the main challenge URL.  Open challenges expire after 24h.  To directly pair 2 known players, use [this endpoint](#operation/challengeCreate) instead, with the &#x60;acceptByToken&#x60; parameter. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ChallengesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    ChallengesApi apiInstance = new ChallengesApi(defaultClient);
    Boolean rated = true; // Boolean | Game is rated and impacts players ratings
    BigDecimal clockLimit = new BigDecimal(78); // BigDecimal | Clock initial time in seconds. If empty, a correspondence game is created.
    Integer clockIncrement = 56; // Integer | Clock increment in seconds. If empty, a correspondence game is created.
    VariantKey variant = VariantKey.fromValue("standard"); // VariantKey | 
    String fen = "\"rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1\""; // String | Custom initial position (in FEN). Variant must be standard, and the game cannot be rated.
    String name = "name_example"; // String | Optional name for the challenge, that players will see on the challenge page.
    try {
      Object result = apiInstance.challengeOpen(rated, clockLimit, clockIncrement, variant, fen, name);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ChallengesApi#challengeOpen");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **rated** | **Boolean**| Game is rated and impacts players ratings | [optional]
 **clockLimit** | **BigDecimal**| Clock initial time in seconds. If empty, a correspondence game is created. | [optional]
 **clockIncrement** | **Integer**| Clock increment in seconds. If empty, a correspondence game is created. | [optional]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.STANDARD] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **fen** | **String**| Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. | [optional] [default to &quot;rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1&quot;]
 **name** | **String**| Optional name for the challenge, that players will see on the challenge page. | [optional]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The challenge was successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the challenge failed. |  -  |

<a name="challengeStartClocks"></a>
# **challengeStartClocks**
> Ok challengeStartClocks(gameId, token1, token2)

Start clocks of a game

Start the clocks of a game immediately, even if a player has not yet made a move.  Requires the OAuth tokens of both players with &#x60;challenge:write&#x60; scope.  If the clocks have already started, the call will have no effect. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ChallengesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ChallengesApi apiInstance = new ChallengesApi(defaultClient);
    String gameId = "gameId_example"; // String | 
    String token1 = "token1_example"; // String | OAuth token of a player
    String token2 = "token2_example"; // String | OAuth token of the other player
    try {
      Ok result = apiInstance.challengeStartClocks(gameId, token1, token2);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ChallengesApi#challengeStartClocks");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |
 **token1** | **String**| OAuth token of a player | [optional]
 **token2** | **String**| OAuth token of the other player | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The clock of a game was successfully started. |  * Access-Control-Allow-Origin -  <br>  |

<a name="roundAddTime"></a>
# **roundAddTime**
> Ok roundAddTime(gameId, seconds)

Add time to the opponent clock

Add seconds to the opponent&#39;s clock. Can be used to create games with time odds. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ChallengesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    ChallengesApi apiInstance = new ChallengesApi(defaultClient);
    String gameId = "gameId_example"; // String | 
    String seconds = "seconds_example"; // String | How many seconds to give
    try {
      Ok result = apiInstance.roundAddTime(gameId, seconds);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ChallengesApi#roundAddTime");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |
 **seconds** | **String**| How many seconds to give |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Time was successfully added to the opponent&#39;s clock. |  * Access-Control-Allow-Origin -  <br>  |

