# GamesApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiAccountPlaying**](GamesApi.md#apiAccountPlaying) | **GET** /api/account/playing | Get my ongoing games
[**apiGamesUser**](GamesApi.md#apiGamesUser) | **GET** /api/games/user/{username} | Export games of a user
[**apiUserCurrentGame**](GamesApi.md#apiUserCurrentGame) | **GET** /api/user/{username}/current-game | Export ongoing game of a user
[**gameImport**](GamesApi.md#gameImport) | **POST** /api/import | Import one game
[**gamePgn**](GamesApi.md#gamePgn) | **GET** /game/export/{gameId} | Export one game
[**gamesByUsers**](GamesApi.md#gamesByUsers) | **POST** /api/stream/games-by-users | Stream games of users
[**gamesExportIds**](GamesApi.md#gamesExportIds) | **POST** /games/export/_ids | Export games by IDs
[**streamGame**](GamesApi.md#streamGame) | **GET** /api/stream/game/{id} | Stream moves of a game


<a name="apiAccountPlaying"></a>
# **apiAccountPlaying**
> Object apiAccountPlaying(nb)

Get my ongoing games

Get the ongoing games of the current user. Real-time and correspondence games are included. The most urgent games are listed first. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.GamesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    GamesApi apiInstance = new GamesApi(defaultClient);
    Integer nb = 9; // Integer | Max number of games to fetch
    try {
      Object result = apiInstance.apiAccountPlaying(nb);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling GamesApi#apiAccountPlaying");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nb** | **Integer**| Max number of games to fetch | [optional] [default to 9]

### Return type

**Object**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The ongoing games of the logged in user. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiGamesUser"></a>
# **apiGamesUser**
> Object apiGamesUser(username, since, until, max, vs, rated, perfType, color, analysed, moves, pgnInJson, tags, clocks, evals, opening, ongoing, finished, players, sort)

Export games of a user

Download all games of any user in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first)  We recommend streaming the response, for it can be very long. &lt;https://lichess.org/@/german11&gt; for instance has more than 320,000 games.  The game stream is throttled, depending on who is making the request:   - Anonymous request: 20 games per second   - [OAuth2 authenticated](#section/Authentication) request: 30 games per second   - Authenticated, downloading your own games: 60 games per second 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.GamesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    GamesApi apiInstance = new GamesApi(defaultClient);
    String username = "username_example"; // String | The user name.
    Integer since = 56; // Integer | Download games played since this timestamp.
    Integer until = 56; // Integer | Download games played until this timestamp.
    Integer max = 56; // Integer | How many games to download. Leave empty to download all games.
    String vs = "vs_example"; // String | [Filter] Only games played against this opponent
    Boolean rated = true; // Boolean | [Filter] Only rated (`true`) or casual (`false`) games
    PerfType perfType = new PerfType(); // PerfType | [Filter] Only games in these speeds or variants.   Multiple perf types can be specified, separated by a comma.   Example: blitz,rapid,classical
    String color = "white"; // String | [Filter] Only games played as this color.
    Boolean analysed = true; // Boolean | [Filter] Only games with or without a computer analysis available
    Boolean moves = true; // Boolean | Include the PGN moves.
    Boolean pgnInJson = false; // Boolean | Include the full PGN within the JSON response, in a `pgn` field. The response type must be set to `application/x-ndjson` by the request `Accept` header.
    Boolean tags = true; // Boolean | Include the PGN tags.
    Boolean clocks = false; // Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
    Boolean evals = false; // Boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }` 
    Boolean opening = false; // Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
    Boolean ongoing = false; // Boolean | Include ongoing games. The last 3 moves will be omitted.
    Boolean finished = true; // Boolean | Include finished games. Set to `false` to only get ongoing games.
    String players = "players_example"; // String | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: <https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt> 
    String sort = "dateAsc"; // String | Sort order of the games.
    try {
      Object result = apiInstance.apiGamesUser(username, since, until, max, vs, rated, perfType, color, analysed, moves, pgnInJson, tags, clocks, evals, opening, ongoing, finished, players, sort);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling GamesApi#apiGamesUser");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**| The user name. |
 **since** | **Integer**| Download games played since this timestamp. | [optional]
 **until** | **Integer**| Download games played until this timestamp. | [optional]
 **max** | **Integer**| How many games to download. Leave empty to download all games. | [optional]
 **vs** | **String**| [Filter] Only games played against this opponent | [optional]
 **rated** | **Boolean**| [Filter] Only rated (&#x60;true&#x60;) or casual (&#x60;false&#x60;) games | [optional]
 **perfType** | [**PerfType**](.md)| [Filter] Only games in these speeds or variants.   Multiple perf types can be specified, separated by a comma.   Example: blitz,rapid,classical | [optional]
 **color** | **String**| [Filter] Only games played as this color. | [optional] [default to null] [enum: white, black]
 **analysed** | **Boolean**| [Filter] Only games with or without a computer analysis available | [optional]
 **moves** | **Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. The response type must be set to &#x60;application/x-ndjson&#x60; by the request &#x60;Accept&#x60; header. | [optional] [default to false]
 **tags** | **Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to false]
 **evals** | **Boolean**| Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | [optional] [default to false]
 **opening** | **Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to false]
 **ongoing** | **Boolean**| Include ongoing games. The last 3 moves will be omitted. | [optional] [default to false]
 **finished** | **Boolean**| Include finished games. Set to &#x60;false&#x60; to only get ongoing games. | [optional] [default to true]
 **players** | **String**| URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  | [optional]
 **sort** | **String**| Sort order of the games. | [optional] [default to dateDesc] [enum: dateAsc, dateDesc]

### Return type

**Object**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The games of the user. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiUserCurrentGame"></a>
# **apiUserCurrentGame**
> Object apiUserCurrentGame(username, moves, pgnInJson, tags, clocks, evals, opening, literate, players)

Export ongoing game of a user

Download the ongoing game, or the last game played, of a user. Available in either PGN or JSON format. If the game is ongoing, the 3 last moves are omitted. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.GamesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    GamesApi apiInstance = new GamesApi(defaultClient);
    String username = "username_example"; // String | 
    Boolean moves = true; // Boolean | Include the PGN moves.
    Boolean pgnInJson = false; // Boolean | Include the full PGN within the JSON response, in a `pgn` field.
    Boolean tags = true; // Boolean | Include the PGN tags.
    Boolean clocks = true; // Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
    Boolean evals = true; // Boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }` 
    Boolean opening = true; // Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
    Boolean literate = false; // Boolean | Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: `5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)` 
    String players = "players_example"; // String | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: <https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt> 
    try {
      Object result = apiInstance.apiUserCurrentGame(username, moves, pgnInJson, tags, clocks, evals, opening, literate, players);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling GamesApi#apiUserCurrentGame");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |
 **moves** | **Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | [optional] [default to false]
 **tags** | **Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to true]
 **evals** | **Boolean**| Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | [optional] [default to true]
 **opening** | **Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to true]
 **literate** | **Boolean**| Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60;  | [optional] [default to false]
 **players** | **String**| URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  | [optional]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The ongoing (or last) game of a user. |  * Access-Control-Allow-Origin -  <br>  |

<a name="gameImport"></a>
# **gameImport**
> Object gameImport(pgn)

Import one game

Import a game from PGN. See &lt;https://lichess.org/paste&gt;.  Rate limiting: 200 games per hour for OAuth requests, 100 games per hour for anonymous requests.  To broadcast ongoing games, consider [pushing to a broadcast instead](#operation/broadcastPush). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.GamesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    GamesApi apiInstance = new GamesApi(defaultClient);
    String pgn = "pgn_example"; // String | The PGN. It can contain only one game. Most standard tags are supported.
    try {
      Object result = apiInstance.gameImport(pgn);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling GamesApi#gameImport");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pgn** | **String**| The PGN. It can contain only one game. Most standard tags are supported. | [optional]

### Return type

**Object**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game was successfully imported. |  * Access-Control-Allow-Origin -  <br>  |

<a name="gamePgn"></a>
# **gamePgn**
> Object gamePgn(gameId, moves, pgnInJson, tags, clocks, evals, opening, literate, players)

Export one game

Download one game in either PGN or JSON format.  Ongoing games have their last 3 moves omitted, after move 5. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.GamesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    GamesApi apiInstance = new GamesApi(defaultClient);
    String gameId = "gameId_example"; // String | The game ID (8 characters).
    Boolean moves = true; // Boolean | Include the PGN moves.
    Boolean pgnInJson = false; // Boolean | Include the full PGN within the JSON response, in a `pgn` field.
    Boolean tags = true; // Boolean | Include the PGN tags.
    Boolean clocks = true; // Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
    Boolean evals = true; // Boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }` 
    Boolean opening = true; // Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
    Boolean literate = false; // Boolean | Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: `5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)` 
    String players = "players_example"; // String | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: <https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt> 
    try {
      Object result = apiInstance.gamePgn(gameId, moves, pgnInJson, tags, clocks, evals, opening, literate, players);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling GamesApi#gamePgn");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**| The game ID (8 characters). |
 **moves** | **Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | [optional] [default to false]
 **tags** | **Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to true]
 **evals** | **Boolean**| Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | [optional] [default to true]
 **opening** | **Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to true]
 **literate** | **Boolean**| Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60;  | [optional] [default to false]
 **players** | **String**| URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  | [optional]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The game representation. |  * Access-Control-Allow-Origin -  <br>  |

<a name="gamesByUsers"></a>
# **gamesByUsers**
> Object gamesByUsers(body, withCurrentGames)

Stream games of users

Stream the games played between a list of users, in real time. Only games where **both players** are part of the list are included.  By default, games are only sent to the stream when they start. To also get all ongoing games at the beginning of the stream, use the &#x60;withCurrentGames&#x60; flag.  Maximum number of users: 300.  Games are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  The method is &#x60;POST&#x60; so a longer list of IDs can be sent in the request body. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.GamesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    GamesApi apiInstance = new GamesApi(defaultClient);
    String body = aliquantus,chess-network,lovlas; // String | Up to 300 user IDs separated by commas.
    Boolean withCurrentGames = false; // Boolean | Include the already started games at the beginning of the stream.
    try {
      Object result = apiInstance.gamesByUsers(body, withCurrentGames);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling GamesApi#gamesByUsers");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | **String**| Up to 300 user IDs separated by commas. |
 **withCurrentGames** | **Boolean**| Include the already started games at the beginning of the stream. | [optional] [default to false]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of the games played between the users. |  * Access-Control-Allow-Origin -  <br>  |

<a name="gamesExportIds"></a>
# **gamesExportIds**
> Object gamesExportIds(body, moves, pgnInJson, tags, clocks, evals, opening, players)

Export games by IDs

Download games by IDs in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header.  Games are sorted by reverse chronological order (most recent first)  The method is &#x60;POST&#x60; so a longer list of IDs can be sent in the request body.  300 IDs can be submitted.  Ongoing games have their last 3 moves omitted, after move 5. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.GamesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    GamesApi apiInstance = new GamesApi(defaultClient);
    String body = TJxUmbWK,4OtIh2oh,ILwozzRZ; // String | Game IDs separated by commas. Up to 300.
    Boolean moves = true; // Boolean | Include the PGN moves.
    Boolean pgnInJson = false; // Boolean | Include the full PGN within the JSON response, in a `pgn` field.
    Boolean tags = true; // Boolean | Include the PGN tags.
    Boolean clocks = false; // Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
    Boolean evals = false; // Boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }` 
    Boolean opening = false; // Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
    String players = "players_example"; // String | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: <https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt> 
    try {
      Object result = apiInstance.gamesExportIds(body, moves, pgnInJson, tags, clocks, evals, opening, players);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling GamesApi#gamesExportIds");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | **String**| Game IDs separated by commas. Up to 300. |
 **moves** | **Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | [optional] [default to false]
 **tags** | **Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to false]
 **evals** | **Boolean**| Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | [optional] [default to false]
 **opening** | **Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to false]
 **players** | **String**| URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  | [optional]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/x-chess-pgn, application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The representation of the games. |  -  |

<a name="streamGame"></a>
# **streamGame**
> Object streamGame(id)

Stream moves of a game

Stream positions and moves of any ongoing game, in [ndjson](#section/Introduction/Streaming-with-ND-JSON).  A description of the game is sent as a first message. Then a message is sent each time a move is played. Finally a description of the game is sent when it finishes, and the stream is closed.  After move 5, the stream intentionally remains 3 moves behind the game status, as to prevent cheat bots from using this API.  No more than 8 game streams can be opened at the same time from the same IP address. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.GamesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    GamesApi apiInstance = new GamesApi(defaultClient);
    String id = "LuGQwhBb"; // String | 
    try {
      Object result = apiInstance.streamGame(id);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling GamesApi#streamGame");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**|  |

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of the game moves. |  -  |

