# OAuthApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiToken**](OAuthApi.md#apiToken) | **POST** /api/token | Obtain access token
[**apiTokenDelete**](OAuthApi.md#apiTokenDelete) | **DELETE** /api/token | Revoke access token
[**oauth**](OAuthApi.md#oauth) | **GET** /oauth | Request authorization code


<a name="apiToken"></a>
# **apiToken**
> apiToken(grantType, code, codeVerifier, redirectUri, clientId)

Obtain access token

OAuth2 token endpoint. Exchanges an authorization code for an access token. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.OAuthApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    OAuthApi apiInstance = new OAuthApi(defaultClient);
    String grantType = "grantType_example"; // String | Must be `authorization_code`.
    String code = "code_example"; // String | The authorization code that was sent in the `code` parameter to your `redirect_uri`.
    String codeVerifier = "codeVerifier_example"; // String | A `code_challenge` was used to request the authorization code. This must be the `code_verifier` it was derived from.
    String redirectUri = "redirectUri_example"; // String | Must match the `redirect_uri` used to request the authorization code.
    String clientId = "clientId_example"; // String | Must match the `client_id` used to request the authorization code.
    try {
      apiInstance.apiToken(grantType, code, codeVerifier, redirectUri, clientId);
    } catch (ApiException e) {
      System.err.println("Exception when calling OAuthApi#apiToken");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **grantType** | **String**| Must be &#x60;authorization_code&#x60;. | [optional]
 **code** | **String**| The authorization code that was sent in the &#x60;code&#x60; parameter to your &#x60;redirect_uri&#x60;. | [optional]
 **codeVerifier** | **String**| A &#x60;code_challenge&#x60; was used to request the authorization code. This must be the &#x60;code_verifier&#x60; it was derived from. | [optional]
 **redirectUri** | **String**| Must match the &#x60;redirect_uri&#x60; used to request the authorization code. | [optional]
 **clientId** | **String**| Must match the &#x60;client_id&#x60; used to request the authorization code. | [optional]

### Return type

null (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Access token successfully obtained. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Failed to obtain access token. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiTokenDelete"></a>
# **apiTokenDelete**
> apiTokenDelete()

Revoke access token

Revokes the access token sent as Bearer for this request.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.OAuthApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    OAuthApi apiInstance = new OAuthApi(defaultClient);
    try {
      apiInstance.apiTokenDelete();
    } catch (ApiException e) {
      System.err.println("Exception when calling OAuthApi#apiTokenDelete");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

null (empty response body)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**204** | Access token revoked. |  * Access-Control-Allow-Origin -  <br>  |

<a name="oauth"></a>
# **oauth**
> oauth(responseType, clientId, redirectUri, codeChallengeMethod, codeChallenge, scope, state)

Request authorization code

OAuth2 authorization endpoint.  Start the OAuth2 Authorization Code Flow with PKCE by securely generating two random strings unique to each authorization request: * &#x60;code_verifier&#x60; * &#x60;state&#x60;  Store these in session storage. Make sure not to reveal &#x60;code_verifier&#x60; to eavesdroppers. Do not show it in URLs, do not abuse &#x60;state&#x60; to store it, do not send it over insecure connections. However it is fine if the user themselves can extract &#x60;code_verifier&#x60;, which will always be possible for fully client-side apps.  Then send the user to this endpoint. They will be prompted to grant authorization and then be redirected back to the given &#x60;redirect_uri&#x60;.  If the authorization failed, the following query string parameters will be appended to the redirection: * &#x60;error&#x60;, in particular with value &#x60;access_denied&#x60; if the user    cancelled authorization * &#x60;error_description&#x60; to aid debugging * &#x60;state&#x60;, exactly as passed in the &#x60;state&#x60; parameter  If the authorization succeeded, the following query string parameters will be appended to the redirection: * &#x60;code&#x60;, containing a fresh short-lived authorization code * &#x60;state&#x60;, exactly as passed in the &#x60;state&#x60; parameter  Next, to defend against cross site request forgery, check that the returned &#x60;state&#x60; matches the &#x60;state&#x60; you originally generated.  Finally, continue by using the authorization code to [obtain an access token](#operation/apiToken). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.OAuthApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    OAuthApi apiInstance = new OAuthApi(defaultClient);
    String responseType = "responseType_example"; // String | Must be `code`.
    String clientId = "example.com"; // String | Arbitrary identifier that uniquely identifies your application.
    String redirectUri = "redirectUri_example"; // String | The absolute URL that the user should be redirected to with the authorization result.
    String codeChallengeMethod = "codeChallengeMethod_example"; // String | Must be `S256`.
    String codeChallenge = "codeChallenge_example"; // String | Compute `BASE64URL(SHA256(code_verifier))`.
    String scope = "scope_example"; // String | Space separated list of requested OAuth scopes, if any.
    String state = "state_example"; // String | Arbitrary state that will be returned verbatim with the authorization result.
    try {
      apiInstance.oauth(responseType, clientId, redirectUri, codeChallengeMethod, codeChallenge, scope, state);
    } catch (ApiException e) {
      System.err.println("Exception when calling OAuthApi#oauth");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **responseType** | **String**| Must be &#x60;code&#x60;. |
 **clientId** | **String**| Arbitrary identifier that uniquely identifies your application. |
 **redirectUri** | **String**| The absolute URL that the user should be redirected to with the authorization result. |
 **codeChallengeMethod** | **String**| Must be &#x60;S256&#x60;. |
 **codeChallenge** | **String**| Compute &#x60;BASE64URL(SHA256(code_verifier))&#x60;. |
 **scope** | **String**| Space separated list of requested OAuth scopes, if any. | [optional]
 **state** | **String**| Arbitrary state that will be returned verbatim with the authorization result. | [optional]

### Return type

null (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Authorization prompt will be displayed to the user. |  -  |

