# OpeningExplorerApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**openingExplorerLichess**](OpeningExplorerApi.md#openingExplorerLichess) | **GET** /lichess | Lichess games
[**openingExplorerMaster**](OpeningExplorerApi.md#openingExplorerMaster) | **GET** /masters | Masters database
[**openingExplorerMasterGame**](OpeningExplorerApi.md#openingExplorerMasterGame) | **GET** /master/pgn/{gameId} | OTB master game
[**openingExplorerPlayer**](OpeningExplorerApi.md#openingExplorerPlayer) | **GET** /player? | Player games


<a name="openingExplorerLichess"></a>
# **openingExplorerLichess**
> Object openingExplorerLichess(variant, fen, play, speeds, ratings, since, until, moves, topGames, recentGames)

Lichess games

**Endpoint: &lt;https://explorer.lichess.ovh/lichess&gt;**  Games sampled from all Lichess players.  Example: &#x60;curl https://explorer.lichess.ovh/lichess?variant&#x3D;standard&amp;speeds&#x3D;blitz,rapid,classical&amp;ratings&#x3D;2200,2500&amp;fen&#x3D;rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR%20w%20KQkq%20-%200%201&#x60; 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.OpeningExplorerApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    OpeningExplorerApi apiInstance = new OpeningExplorerApi(defaultClient);
    VariantKey variant = VariantKey.fromValue("standard"); // VariantKey | Variant
    String fen = "rnbqkbnr/ppp1pppp/8/3pP3/8/8/PPPP1PPP/RNBQKBNR b KQkq - 0 2"; // String | FEN of the root position
    String play = ""; // String | Comma separated sequence of legal moves in UCI notation. Play additional moves starting from `fen`. Required to find an opening name, if `fen` is not an exact match for a named position. 
    List<Speed> speeds = Arrays.asList(); // List<Speed> | Comma separated list of game speeds to look for
    List<BigDecimal> ratings = Arrays.asList(); // List<BigDecimal> | Comma separated list of rating groups, ranging from their value to the next higher group
    String since = "0000-01"; // String | Include only games from this month or later
    String until = "3000-12"; // String | Include only games from this month or earlier
    BigDecimal moves = new BigDecimal("12"); // BigDecimal | Number of most common moves to display
    BigDecimal topGames = new BigDecimal("4"); // BigDecimal | Number of top games to display
    BigDecimal recentGames = new BigDecimal("4"); // BigDecimal | Number of recent games to display
    try {
      Object result = apiInstance.openingExplorerLichess(variant, fen, play, speeds, ratings, since, until, moves, topGames, recentGames);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling OpeningExplorerApi#openingExplorerLichess");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **variant** | [**VariantKey**](.md)| Variant | [optional] [default to standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **fen** | **String**| FEN of the root position | [optional]
 **play** | **String**| Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  | [optional] [default to ]
 **speeds** | [**List&lt;Speed&gt;**](Speed.md)| Comma separated list of game speeds to look for | [optional]
 **ratings** | [**List&lt;BigDecimal&gt;**](BigDecimal.md)| Comma separated list of rating groups, ranging from their value to the next higher group | [optional] [enum: 1600, 1800, 2000, 2200, 2500]
 **since** | **String**| Include only games from this month or later | [optional] [default to 0000-01]
 **until** | **String**| Include only games from this month or earlier | [optional] [default to 3000-12]
 **moves** | **BigDecimal**| Number of most common moves to display | [optional] [default to 12]
 **topGames** | **BigDecimal**| Number of top games to display | [optional] [default to 4]
 **recentGames** | **BigDecimal**| Number of recent games to display | [optional] [default to 4]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Opening statistics and game references for the position. |  * Access-Control-Allow-Origin -  <br>  |

<a name="openingExplorerMaster"></a>
# **openingExplorerMaster**
> Object openingExplorerMaster(fen, play, since, until, moves, topGames)

Masters database

**Endpoint: &lt;https://explorer.lichess.ovh/masters&gt;**  Example: &#x60;curl https://explorer.lichess.ovh/masters?play&#x3D;d2d4,d7d5,c2c4,c7c6,c4d5&#x60; 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.OpeningExplorerApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    OpeningExplorerApi apiInstance = new OpeningExplorerApi(defaultClient);
    String fen = "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1"; // String | FEN of the root position
    String play = ""; // String | Comma separated sequence of legal moves in UCI notation. Play additional moves starting from `fen`. Required to find an opening name, if `fen` is not an exact match for a named position. 
    BigDecimal since = new BigDecimal("1952"); // BigDecimal | Include only games from this year or later
    BigDecimal until = new BigDecimal(78); // BigDecimal | Include only games from thi year or earlier
    BigDecimal moves = new BigDecimal("12"); // BigDecimal | Number of most common moves to display
    BigDecimal topGames = new BigDecimal("15"); // BigDecimal | Number of top games to display
    try {
      Object result = apiInstance.openingExplorerMaster(fen, play, since, until, moves, topGames);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling OpeningExplorerApi#openingExplorerMaster");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **fen** | **String**| FEN of the root position | [optional]
 **play** | **String**| Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  | [optional] [default to ]
 **since** | **BigDecimal**| Include only games from this year or later | [optional] [default to 1952]
 **until** | **BigDecimal**| Include only games from thi year or earlier | [optional]
 **moves** | **BigDecimal**| Number of most common moves to display | [optional] [default to 12]
 **topGames** | **BigDecimal**| Number of top games to display | [optional] [default to 15]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Opening statistics and game references for the position. |  * Access-Control-Allow-Origin -  <br>  |

<a name="openingExplorerMasterGame"></a>
# **openingExplorerMasterGame**
> Object openingExplorerMasterGame(gameId)

OTB master game

**Endpoint: &#x60;https://explorer.lichess.ovh/masters/pgn/{gameId}&#x60;**  Example: &#x60;curl https://explorer.lichess.ovh/masters/pgn/aAbqI4ey&#x60; 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.OpeningExplorerApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    OpeningExplorerApi apiInstance = new OpeningExplorerApi(defaultClient);
    String gameId = "gameId_example"; // String | 
    try {
      Object result = apiInstance.openingExplorerMasterGame(gameId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling OpeningExplorerApi#openingExplorerMasterGame");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **String**|  |

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The PGN representation of the game. |  * Access-Control-Allow-Origin -  <br>  |

<a name="openingExplorerPlayer"></a>
# **openingExplorerPlayer**
> Object openingExplorerPlayer(variant, fen, play, speeds, modes, since, until, moves, recentGames)

Player games

**Endpoint: &lt;https://explorer.lichess.ovh/player&gt;**  Games of a Lichess player.  Responds with a stream of newline delimited JSON. Will start indexing on demand, immediately respond with the current results, and stream more updates until indexing is complete. The stream is throttled and deduplicated. Empty lines may be sent to avoid timeouts.  Will index new games at most once per minute, and revisit previously ongoing games at most once every day.  Example: &#x60;curl https://explorer.lichess.ovh/player?player&#x3D;revoof&amp;color&#x3D;white&amp;play&#x3D;d2d4,d7d5&amp;recentGames&#x3D;1&#x60; 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.OpeningExplorerApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    OpeningExplorerApi apiInstance = new OpeningExplorerApi(defaultClient);
    VariantKey variant = VariantKey.fromValue("standard"); // VariantKey | Variant
    String fen = "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1"; // String | FEN of the root position
    String play = ""; // String | Comma separated sequence of legal moves in UCI notation. Play additional moves starting from `fen`. Required to find an opening name, if `fen` is not an exact match for a named position. 
    List<Speed> speeds = Arrays.asList(); // List<Speed> | Comma separated list of game speeds to look for
    List<String> modes = Arrays.asList(); // List<String> | Comma separated list of modes
    String since = "0000-01"; // String | Include only games from this month or later
    String until = "3000-12"; // String | Include only games from this month or earlier
    BigDecimal moves = new BigDecimal(78); // BigDecimal | Number of most common moves to display
    BigDecimal recentGames = new BigDecimal("4"); // BigDecimal | Number of recent games to display
    try {
      Object result = apiInstance.openingExplorerPlayer(variant, fen, play, speeds, modes, since, until, moves, recentGames);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling OpeningExplorerApi#openingExplorerPlayer");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **variant** | [**VariantKey**](.md)| Variant | [optional] [default to standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **fen** | **String**| FEN of the root position | [optional]
 **play** | **String**| Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  | [optional] [default to ]
 **speeds** | [**List&lt;Speed&gt;**](Speed.md)| Comma separated list of game speeds to look for | [optional]
 **modes** | [**List&lt;String&gt;**](String.md)| Comma separated list of modes | [optional] [enum: casual, rated]
 **since** | **String**| Include only games from this month or later | [optional] [default to 0000-01]
 **until** | **String**| Include only games from this month or earlier | [optional] [default to 3000-12]
 **moves** | **BigDecimal**| Number of most common moves to display | [optional]
 **recentGames** | **BigDecimal**| Number of recent games to display | [optional] [default to 4]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/nd-json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Opening statistics and game references for the position. |  * Access-Control-Allow-Origin -  <br>  |

