# PuzzlesApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiPuzzleActivity**](PuzzlesApi.md#apiPuzzleActivity) | **GET** /api/puzzle/activity | Get your puzzle activity
[**apiPuzzleDaily**](PuzzlesApi.md#apiPuzzleDaily) | **GET** /api/puzzle/daily | Get the daily puzzle
[**apiPuzzleDashboard**](PuzzlesApi.md#apiPuzzleDashboard) | **GET** /api/puzzle/dashboard/{days} | Get your puzzle dashboard
[**apiStormDashboard**](PuzzlesApi.md#apiStormDashboard) | **GET** /api/storm/dashboard/{username} | Get the storm dashboard of a player


<a name="apiPuzzleActivity"></a>
# **apiPuzzleActivity**
> PuzzleRoundJson apiPuzzleActivity(max)

Get your puzzle activity

Download your puzzle activity in [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Puzzle activity is sorted by reverse chronological order (most recent first)  We recommend streaming the response, for it can be very long. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.PuzzlesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    PuzzlesApi apiInstance = new PuzzlesApi(defaultClient);
    Integer max = 56; // Integer | How many entries to download. Leave empty to download all activity.
    try {
      PuzzleRoundJson result = apiInstance.apiPuzzleActivity(max);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling PuzzlesApi#apiPuzzleActivity");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **max** | **Integer**| How many entries to download. Leave empty to download all activity. | [optional]

### Return type

[**PuzzleRoundJson**](PuzzleRoundJson.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The puzzle activity of the logged in user. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiPuzzleDaily"></a>
# **apiPuzzleDaily**
> Object apiPuzzleDaily()

Get the daily puzzle

Get the daily Lichess puzzle in JSON format.  Alternatively, you can [post it in your slack workspace](https://lichess.org/daily-puzzle-slack). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.PuzzlesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    PuzzlesApi apiInstance = new PuzzlesApi(defaultClient);
    try {
      Object result = apiInstance.apiPuzzleDaily();
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling PuzzlesApi#apiPuzzleDaily");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The daily puzzle. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiPuzzleDashboard"></a>
# **apiPuzzleDashboard**
> Object apiPuzzleDashboard(days)

Get your puzzle dashboard

Download your [puzzle dashboard](https://lichess.org/training/dashboard/30/dashboard) as JSON.  Also includes all puzzle themes played, with aggregated results.  Allows re-creating the [improvement/strengths](https://lichess.org/training/dashboard/30/improvementAreas) interfaces. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.PuzzlesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    PuzzlesApi apiInstance = new PuzzlesApi(defaultClient);
    Integer days = 56; // Integer | How many days to look back when aggregating puzzle results. 30 is sensible.
    try {
      Object result = apiInstance.apiPuzzleDashboard(days);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling PuzzlesApi#apiPuzzleDashboard");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **days** | **Integer**| How many days to look back when aggregating puzzle results. 30 is sensible. |

### Return type

**Object**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The puzzle dashboard of the logged in user. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiStormDashboard"></a>
# **apiStormDashboard**
> Object apiStormDashboard(username, days)

Get the storm dashboard of a player

Download the [storm dashboard](https://lichess.org/storm/dashboard/mrbasso) of any player as JSON.  Contains the aggregated highscores, and the history of storm runs aggregated by days.  Use &#x60;?days&#x3D;0&#x60; if you only care about the highscores. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.PuzzlesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    PuzzlesApi apiInstance = new PuzzlesApi(defaultClient);
    String username = "username_example"; // String | Username of the player
    Integer days = 30; // Integer | How many days of history to return
    try {
      Object result = apiInstance.apiStormDashboard(username, days);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling PuzzlesApi#apiStormDashboard");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**| Username of the player |
 **days** | **Integer**| How many days of history to return | [optional] [default to 30]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The storm dashboard of a player. |  * Access-Control-Allow-Origin -  <br>  |

