# RelationsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiUserFollowing**](RelationsApi.md#apiUserFollowing) | **GET** /api/rel/following | Get users followed the logged in user
[**followUser**](RelationsApi.md#followUser) | **POST** /api/rel/follow/{username} | Follow a player
[**unfollowUser**](RelationsApi.md#unfollowUser) | **POST** /api/rel/unfollow/{username} | Unfollow a player


<a name="apiUserFollowing"></a>
# **apiUserFollowing**
> UserExtended apiUserFollowing()

Get users followed the logged in user

Users are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.RelationsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    RelationsApi apiInstance = new RelationsApi(defaultClient);
    try {
      UserExtended result = apiInstance.apiUserFollowing();
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling RelationsApi#apiUserFollowing");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**UserExtended**](UserExtended.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of users followed by a user. |  * Access-Control-Allow-Origin -  <br>  |

<a name="followUser"></a>
# **followUser**
> Ok followUser(username)

Follow a player

Follow a player, adding them to your list of Lichess friends. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.RelationsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    RelationsApi apiInstance = new RelationsApi(defaultClient);
    String username = "thibault"; // String | 
    try {
      Ok result = apiInstance.followUser(username);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling RelationsApi#followUser");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The player was successfully added. |  -  |

<a name="unfollowUser"></a>
# **unfollowUser**
> Ok unfollowUser(username)

Unfollow a player

Unfollow a player, removing them from your list of Lichess friends. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.RelationsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    RelationsApi apiInstance = new RelationsApi(defaultClient);
    String username = "thibault"; // String | 
    try {
      Ok result = apiInstance.unfollowUser(username);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling RelationsApi#unfollowUser");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The player was successfully removed. |  -  |

