# StudiesApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**studyAllChaptersPgn**](StudiesApi.md#studyAllChaptersPgn) | **GET** /api/study/{studyId}.pgn | Export all chapters
[**studyChapterPgn**](StudiesApi.md#studyChapterPgn) | **GET** /study/{studyId}/{chapterId}.pgn | Export one study chapter
[**studyExportAllPgn**](StudiesApi.md#studyExportAllPgn) | **GET** /study/by/{username}/export.pgn | Export all studies of a user


<a name="studyAllChaptersPgn"></a>
# **studyAllChaptersPgn**
> Object studyAllChaptersPgn(studyId, clocks, comments, variations)

Export all chapters

Download all chapters of a study in PGN format. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.StudiesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    StudiesApi apiInstance = new StudiesApi(defaultClient);
    String studyId = "studyId_example"; // String | The study ID (8 characters).
    Boolean clocks = true; // Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
    Boolean comments = true; // Boolean | Include analysis and annotator comments in the PGN moves, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }` 
    Boolean variations = true; // Boolean | Include non-mainline moves, when available.  Example: `4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2` 
    try {
      Object result = apiInstance.studyAllChaptersPgn(studyId, clocks, comments, variations);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling StudiesApi#studyAllChaptersPgn");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **studyId** | **String**| The study ID (8 characters). |
 **clocks** | **Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to true]
 **comments** | **Boolean**| Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60;  | [optional] [default to true]
 **variations** | **Boolean**| Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60;  | [optional] [default to true]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The PGN representation of the study. |  * Access-Control-Allow-Origin -  <br>  |

<a name="studyChapterPgn"></a>
# **studyChapterPgn**
> Object studyChapterPgn(studyId, chapterId, clocks, comments, variations)

Export one study chapter

Download one study chapter in PGN format. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.StudiesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    StudiesApi apiInstance = new StudiesApi(defaultClient);
    String studyId = "studyId_example"; // String | The study ID (8 characters).
    String chapterId = "chapterId_example"; // String | The chapter ID (8 characters).
    Boolean clocks = true; // Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
    Boolean comments = true; // Boolean | Include analysis and annotator comments in the PGN moves, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }` 
    Boolean variations = true; // Boolean | Include non-mainline moves, when available.  Example: `4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2` 
    try {
      Object result = apiInstance.studyChapterPgn(studyId, chapterId, clocks, comments, variations);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling StudiesApi#studyChapterPgn");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **studyId** | **String**| The study ID (8 characters). |
 **chapterId** | **String**| The chapter ID (8 characters). |
 **clocks** | **Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to true]
 **comments** | **Boolean**| Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60;  | [optional] [default to true]
 **variations** | **Boolean**| Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60;  | [optional] [default to true]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The chapter of the study. |  -  |

<a name="studyExportAllPgn"></a>
# **studyExportAllPgn**
> Object studyExportAllPgn(username, clocks, comments, variations)

Export all studies of a user

Download all chapters of all studies of a user in PGN format.  If authenticated, then all public, unlisted, and private studies are included.  If not, only public, listed studies are included. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.StudiesApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    StudiesApi apiInstance = new StudiesApi(defaultClient);
    String username = "username_example"; // String | The user whose studies we export
    Boolean clocks = true; // Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
    Boolean comments = true; // Boolean | Include analysis and annotator comments in the PGN moves, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }` 
    Boolean variations = true; // Boolean | Include non-mainline moves, when available.  Example: `4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2` 
    try {
      Object result = apiInstance.studyExportAllPgn(username, clocks, comments, variations);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling StudiesApi#studyExportAllPgn");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**| The user whose studies we export |
 **clocks** | **Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to true]
 **comments** | **Boolean**| Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60;  | [optional] [default to true]
 **variations** | **Boolean**| Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60;  | [optional] [default to true]

### Return type

**Object**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The studies of the user. |  -  |

