# SwissTournamentsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiSwissJoin**](SwissTournamentsApi.md#apiSwissJoin) | **POST** /api/swiss/{id}/join | Join a Swiss tournament
[**apiSwissNew**](SwissTournamentsApi.md#apiSwissNew) | **POST** /api/swiss/new/{teamId} | Create a new Swiss tournament
[**apiSwissTerminate**](SwissTournamentsApi.md#apiSwissTerminate) | **POST** /api/swiss/{id}/terminate | Terminate a Swiss tournament
[**apiSwissUpdate**](SwissTournamentsApi.md#apiSwissUpdate) | **POST** /api/swiss/{id}/edit | Update a Swiss tournament.
[**apiTeamSwiss**](SwissTournamentsApi.md#apiTeamSwiss) | **GET** /api/team/{teamId}/swiss | Get team swiss tournaments
[**gamesBySwiss**](SwissTournamentsApi.md#gamesBySwiss) | **GET** /api/swiss/{id}/games | Export games of a Swiss tournament
[**resultsBySwiss**](SwissTournamentsApi.md#resultsBySwiss) | **GET** /api/swiss/{id}/results | Get results of a swiss tournament
[**swissTrf**](SwissTournamentsApi.md#swissTrf) | **GET** /swiss/{id}.trf | Export TRF of a Swiss tournament


<a name="apiSwissJoin"></a>
# **apiSwissJoin**
> Ok apiSwissJoin(id, password)

Join a Swiss tournament

Join a Swiss tournament, possibly with a password. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.SwissTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    SwissTournamentsApi apiInstance = new SwissTournamentsApi(defaultClient);
    String id = "hL7vMrFQ"; // String | The tournament ID.
    String password = "password_example"; // String | The tournament password, if one is required
    try {
      Ok result = apiInstance.apiSwissJoin(id, password);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling SwissTournamentsApi#apiSwissJoin");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID. |
 **password** | **String**| The tournament password, if one is required | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The tournament was successfully joined. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Joining the tournament failed. |  -  |

<a name="apiSwissNew"></a>
# **apiSwissNew**
> Object apiSwissNew(teamId, clockLimit, clockIncrement, nbRounds, name, startsAt, roundInterval, variant, description, rated, chatFor)

Create a new Swiss tournament

Create a Swiss tournament for your team.  This endpoint mirrors the Swiss tournament form from your team pagee.  You can create up to 12 tournaments per day. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.SwissTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    SwissTournamentsApi apiInstance = new SwissTournamentsApi(defaultClient);
    String teamId = "teamId_example"; // String | ID of the team
    BigDecimal clockLimit = new BigDecimal(78); // BigDecimal | Clock initial time in seconds
    Integer clockIncrement = 56; // Integer | Clock increment in seconds
    Integer nbRounds = 8; // Integer | Maximum number of rounds to play
    String name = "name_example"; // String | The tournament name. Leave empty to get a random Grandmaster name
    Integer startsAt = 56; // Integer | Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation.
    Integer roundInterval = 56; // Integer | How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI. 
    VariantKey variant = VariantKey.fromValue("standard"); // VariantKey | 
    String description = "description_example"; // String | Anything you want to tell players about the tournament
    Boolean rated = true; // Boolean | Games are rated and impact players ratings
    BigDecimal chatFor = new BigDecimal("new BigDecimal("20")"); // BigDecimal | Who can read and write in the chat. - 0  = No-one - 10 = Only team leaders - 20 = Only team members - 30 = All Lichess players 
    try {
      Object result = apiInstance.apiSwissNew(teamId, clockLimit, clockIncrement, nbRounds, name, startsAt, roundInterval, variant, description, rated, chatFor);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling SwissTournamentsApi#apiSwissNew");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **String**| ID of the team |
 **clockLimit** | **BigDecimal**| Clock initial time in seconds |
 **clockIncrement** | **Integer**| Clock increment in seconds |
 **nbRounds** | **Integer**| Maximum number of rounds to play | [default to 8]
 **name** | **String**| The tournament name. Leave empty to get a random Grandmaster name | [optional]
 **startsAt** | **Integer**| Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation. | [optional]
 **roundInterval** | **Integer**| How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI.  | [optional]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.STANDARD] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **description** | **String**| Anything you want to tell players about the tournament | [optional]
 **rated** | **Boolean**| Games are rated and impact players ratings | [optional] [default to true]
 **chatFor** | **BigDecimal**| Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players  | [optional] [default to new BigDecimal(&quot;20&quot;)]

### Return type

**Object**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The Swiss tournament was successfully created. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The creation of the Swiss tournament failed. |  -  |

<a name="apiSwissTerminate"></a>
# **apiSwissTerminate**
> Ok apiSwissTerminate(id)

Terminate a Swiss tournament

Terminate a Swiss tournament 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.SwissTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    SwissTournamentsApi apiInstance = new SwissTournamentsApi(defaultClient);
    String id = "W5FrxusN"; // String | The Swiss tournament ID.
    try {
      Ok result = apiInstance.apiSwissTerminate(id);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling SwissTournamentsApi#apiSwissTerminate");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The Swiss tournament ID. |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The Swiss tournament was successfully terminated. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Terminating the Swiss tournament failed. |  -  |

<a name="apiSwissUpdate"></a>
# **apiSwissUpdate**
> Object apiSwissUpdate(id, clockLimit, clockIncrement, nbRounds, name, startsAt, roundInterval, variant, description, rated, chatFor)

Update a Swiss tournament.

Update a Swiss tournament.  Be mindful not to make important changes to ongoing tournaments. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.SwissTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    SwissTournamentsApi apiInstance = new SwissTournamentsApi(defaultClient);
    String id = "hL7vMrFQ"; // String | The tournament ID.
    BigDecimal clockLimit = new BigDecimal(78); // BigDecimal | Clock initial time in seconds
    Integer clockIncrement = 56; // Integer | Clock increment in seconds
    Integer nbRounds = 8; // Integer | Maximum number of rounds to play
    String name = "name_example"; // String | The tournament name. Leave empty to get a random Grandmaster name
    Integer startsAt = 56; // Integer | Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation.
    Integer roundInterval = 56; // Integer | How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI. 
    VariantKey variant = VariantKey.fromValue("standard"); // VariantKey | 
    String description = "description_example"; // String | Anything you want to tell players about the tournament
    Boolean rated = true; // Boolean | Games are rated and impact players ratings
    BigDecimal chatFor = new BigDecimal("new BigDecimal("20")"); // BigDecimal | Who can read and write in the chat. - 0  = No-one - 10 = Only team leaders - 20 = Only team members - 30 = All Lichess players 
    try {
      Object result = apiInstance.apiSwissUpdate(id, clockLimit, clockIncrement, nbRounds, name, startsAt, roundInterval, variant, description, rated, chatFor);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling SwissTournamentsApi#apiSwissUpdate");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID. |
 **clockLimit** | **BigDecimal**| Clock initial time in seconds |
 **clockIncrement** | **Integer**| Clock increment in seconds |
 **nbRounds** | **Integer**| Maximum number of rounds to play | [default to 8]
 **name** | **String**| The tournament name. Leave empty to get a random Grandmaster name | [optional]
 **startsAt** | **Integer**| Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation. | [optional]
 **roundInterval** | **Integer**| How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI.  | [optional]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.STANDARD] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **description** | **String**| Anything you want to tell players about the tournament | [optional]
 **rated** | **Boolean**| Games are rated and impact players ratings | [optional] [default to true]
 **chatFor** | **BigDecimal**| Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players  | [optional] [default to new BigDecimal(&quot;20&quot;)]

### Return type

**Object**

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The Swiss tournament was successfully updated. |  * Access-Control-Allow-Origin -  <br>  |
**400** | Updating the swiss failed. |  -  |
**401** | This user cannot update this Swiss. |  -  |

<a name="apiTeamSwiss"></a>
# **apiTeamSwiss**
> List&lt;Object&gt; apiTeamSwiss(teamId, max)

Get team swiss tournaments

Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.SwissTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    SwissTournamentsApi apiInstance = new SwissTournamentsApi(defaultClient);
    String teamId = "coders"; // String | 
    Integer max = 100; // Integer | How many tournaments to download.
    try {
      List<Object> result = apiInstance.apiTeamSwiss(teamId, max);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling SwissTournamentsApi#apiTeamSwiss");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **String**|  |
 **max** | **Integer**| How many tournaments to download. | [optional] [default to 100]

### Return type

**List&lt;Object&gt;**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of Swiss tournaments of a team. |  * Access-Control-Allow-Origin -  <br>  |

<a name="gamesBySwiss"></a>
# **gamesBySwiss**
> Object gamesBySwiss(id, moves, pgnInJson, tags, clocks, evals, opening)

Export games of a Swiss tournament

Download games of a swiss tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (last round first) 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.SwissTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    SwissTournamentsApi apiInstance = new SwissTournamentsApi(defaultClient);
    String id = "id_example"; // String | The tournament ID.
    Boolean moves = true; // Boolean | Include the PGN moves.
    Boolean pgnInJson = false; // Boolean | Include the full PGN within the JSON response, in a `pgn` field.
    Boolean tags = true; // Boolean | Include the PGN tags.
    Boolean clocks = false; // Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
    Boolean evals = false; // Boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }` 
    Boolean opening = false; // Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
    try {
      Object result = apiInstance.gamesBySwiss(id, moves, pgnInJson, tags, clocks, evals, opening);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling SwissTournamentsApi#gamesBySwiss");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID. |
 **moves** | **Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | [optional] [default to false]
 **tags** | **Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to false]
 **evals** | **Boolean**| Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | [optional] [default to false]
 **opening** | **Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to false]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of games of a Swiss tournament. |  * Access-Control-Allow-Origin -  <br>  |

<a name="resultsBySwiss"></a>
# **resultsBySwiss**
> Object resultsBySwiss(id, nb)

Get results of a swiss tournament

Players of a swiss tournament, with their score and performance, sorted by rank (best first).  Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.SwissTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    SwissTournamentsApi apiInstance = new SwissTournamentsApi(defaultClient);
    String id = "id_example"; // String | The tournament ID.
    Integer nb = 56; // Integer | Max number of players to fetch
    try {
      Object result = apiInstance.resultsBySwiss(id, nb);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling SwissTournamentsApi#resultsBySwiss");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID. |
 **nb** | **Integer**| Max number of players to fetch | [optional]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The results of a Swiss tournament. |  * Access-Control-Allow-Origin -  <br>  |

<a name="swissTrf"></a>
# **swissTrf**
> String swissTrf(id)

Export TRF of a Swiss tournament

Download a tournament in the Tournament Report File format, the FIDE standard.  Documentation: &lt;https://www.fide.com/FIDE/handbook/C04Annex2_TRF16.pdf&gt;  Example: &lt;https://lichess.org/swiss/j8rtJ5GL.trf&gt; 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.SwissTournamentsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    SwissTournamentsApi apiInstance = new SwissTournamentsApi(defaultClient);
    String id = "id_example"; // String | The tournament ID.
    try {
      String result = apiInstance.swissTrf(id);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling SwissTournamentsApi#swissTrf");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| The tournament ID. |

### Return type

**String**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: text/plain

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The TRF representation of a Swiss tournament. |  * Access-Control-Allow-Origin -  <br>  |

