# TeamsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiTeamArena**](TeamsApi.md#apiTeamArena) | **GET** /api/team/{teamId}/arena | Get team Arena tournaments
[**apiTeamSwiss**](TeamsApi.md#apiTeamSwiss) | **GET** /api/team/{teamId}/swiss | Get team swiss tournaments
[**teamAll**](TeamsApi.md#teamAll) | **GET** /api/team/all | Get popular teams
[**teamIdJoin**](TeamsApi.md#teamIdJoin) | **POST** /team/{teamId}/join | Join a team
[**teamIdKickUserId**](TeamsApi.md#teamIdKickUserId) | **POST** /team/{teamId}/kick/{userId} | Kick a user from your team
[**teamIdPmAll**](TeamsApi.md#teamIdPmAll) | **POST** /team/{teamId}/pm-all | Message all members
[**teamIdQuit**](TeamsApi.md#teamIdQuit) | **POST** /team/{teamId}/quit | Leave a team
[**teamIdUsers**](TeamsApi.md#teamIdUsers) | **GET** /api/team/{teamId}/users | Get members of a team
[**teamOfUsername**](TeamsApi.md#teamOfUsername) | **GET** /api/team/of/{username} | Teams of a player
[**teamSearch**](TeamsApi.md#teamSearch) | **GET** /api/team/search | Search teams
[**teamShow**](TeamsApi.md#teamShow) | **GET** /api/team/{teamId} | Get a single team


<a name="apiTeamArena"></a>
# **apiTeamArena**
> List&lt;Object&gt; apiTeamArena(teamId, max)

Get team Arena tournaments

Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TeamsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    TeamsApi apiInstance = new TeamsApi(defaultClient);
    String teamId = "teamId_example"; // String | ID of the team
    Integer max = 100; // Integer | How many tournaments to download.
    try {
      List<Object> result = apiInstance.apiTeamArena(teamId, max);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TeamsApi#apiTeamArena");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **String**| ID of the team |
 **max** | **Integer**| How many tournaments to download. | [optional] [default to 100]

### Return type

**List&lt;Object&gt;**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of Arena tournaments of a team. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiTeamSwiss"></a>
# **apiTeamSwiss**
> List&lt;Object&gt; apiTeamSwiss(teamId, max)

Get team swiss tournaments

Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TeamsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    TeamsApi apiInstance = new TeamsApi(defaultClient);
    String teamId = "coders"; // String | 
    Integer max = 100; // Integer | How many tournaments to download.
    try {
      List<Object> result = apiInstance.apiTeamSwiss(teamId, max);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TeamsApi#apiTeamSwiss");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **String**|  |
 **max** | **Integer**| How many tournaments to download. | [optional] [default to 100]

### Return type

**List&lt;Object&gt;**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of Swiss tournaments of a team. |  * Access-Control-Allow-Origin -  <br>  |

<a name="teamAll"></a>
# **teamAll**
> InlineResponse2001 teamAll(page)

Get popular teams

Paginator of the most popular teams. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TeamsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    TeamsApi apiInstance = new TeamsApi(defaultClient);
    BigDecimal page = new BigDecimal("1"); // BigDecimal | 
    try {
      InlineResponse2001 result = apiInstance.teamAll(page);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TeamsApi#teamAll");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **page** | **BigDecimal**|  | [optional] [default to 1]

### Return type

[**InlineResponse2001**](InlineResponse2001.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | A paginated list of the most popular teams. |  * Access-Control-Allow-Origin -  <br>  |

<a name="teamIdJoin"></a>
# **teamIdJoin**
> Ok teamIdJoin(teamId, message, password)

Join a team

Join a team. If the team requires a password but the &#x60;password&#x60; field is incorrect, then the call fails with &#x60;403 Forbidden&#x60;. Similarly, if the team join policy requires a confirmation but the &#x60;message&#x60; parameter is not given, then the call fails with &#x60;403 Forbidden&#x60;. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TeamsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    TeamsApi apiInstance = new TeamsApi(defaultClient);
    String teamId = "coders"; // String | 
    String message = "message_example"; // String | Optional request message, if the team requires one.
    String password = "password_example"; // String | Optional password, if the team requires one.
    try {
      Ok result = apiInstance.teamIdJoin(teamId, message, password);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TeamsApi#teamIdJoin");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **String**|  |
 **message** | **String**| Optional request message, if the team requires one. | [optional]
 **password** | **String**| Optional password, if the team requires one. | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The request to join a team was successfully sent. |  -  |

<a name="teamIdKickUserId"></a>
# **teamIdKickUserId**
> Ok teamIdKickUserId(teamId, userId)

Kick a user from your team

Kick a member out of one of your teams. - &lt;https://lichess.org/team&gt; 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TeamsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    TeamsApi apiInstance = new TeamsApi(defaultClient);
    String teamId = "coders"; // String | 
    String userId = "neio"; // String | 
    try {
      Ok result = apiInstance.teamIdKickUserId(teamId, userId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TeamsApi#teamIdKickUserId");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **String**|  |
 **userId** | **String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The member has been kicked from the team. |  -  |

<a name="teamIdPmAll"></a>
# **teamIdPmAll**
> Ok teamIdPmAll(teamId, message)

Message all members

Send a private message to all members of a team. You must own the team. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TeamsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    TeamsApi apiInstance = new TeamsApi(defaultClient);
    String teamId = "coders"; // String | 
    String message = "message_example"; // String | The message to send to all your team members.
    try {
      Ok result = apiInstance.teamIdPmAll(teamId, message);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TeamsApi#teamIdPmAll");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **String**|  |
 **message** | **String**| The message to send to all your team members. | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The message has successfully been sent to all team members. |  * Access-Control-Allow-Origin -  <br>  |
**400** | The sending of message to all team members has failed. |  -  |

<a name="teamIdQuit"></a>
# **teamIdQuit**
> Ok teamIdQuit(teamId)

Leave a team

Leave a team. - &lt;https://lichess.org/team&gt; 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TeamsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    TeamsApi apiInstance = new TeamsApi(defaultClient);
    String teamId = "coders"; // String | 
    try {
      Ok result = apiInstance.teamIdQuit(teamId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TeamsApi#teamIdQuit");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The logged in user has successfully left the team. |  -  |

<a name="teamIdUsers"></a>
# **teamIdUsers**
> UserExtended teamIdUsers(teamId)

Get members of a team

Members are sorted by reverse chronological order of joining the team (most recent first). OAuth only required if the list of members is private.  Members are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TeamsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    TeamsApi apiInstance = new TeamsApi(defaultClient);
    String teamId = "coders"; // String | 
    try {
      UserExtended result = apiInstance.teamIdUsers(teamId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TeamsApi#teamIdUsers");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **String**|  |

### Return type

[**UserExtended**](UserExtended.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of users in the team. |  * Access-Control-Allow-Origin -  <br>  |

<a name="teamOfUsername"></a>
# **teamOfUsername**
> List&lt;Team&gt; teamOfUsername(username)

Teams of a player

All the teams a player is a member of. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TeamsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    TeamsApi apiInstance = new TeamsApi(defaultClient);
    String username = "thibault"; // String | 
    try {
      List<Team> result = apiInstance.teamOfUsername(username);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TeamsApi#teamOfUsername");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |

### Return type

[**List&lt;Team&gt;**](Team.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of teams the user is a member of. |  * Access-Control-Allow-Origin -  <br>  |

<a name="teamSearch"></a>
# **teamSearch**
> List&lt;Team&gt; teamSearch(text, page)

Search teams

Paginator of team search results for a keyword. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TeamsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    TeamsApi apiInstance = new TeamsApi(defaultClient);
    String text = "coders"; // String | 
    BigDecimal page = new BigDecimal("1"); // BigDecimal | 
    try {
      List<Team> result = apiInstance.teamSearch(text, page);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TeamsApi#teamSearch");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **text** | **String**|  | [optional]
 **page** | **BigDecimal**|  | [optional] [default to 1]

### Return type

[**List&lt;Team&gt;**](Team.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The paginated list of teams. |  * Access-Control-Allow-Origin -  <br>  |

<a name="teamShow"></a>
# **teamShow**
> Team teamShow(teamId)

Get a single team

Infos about a team

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TeamsApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    TeamsApi apiInstance = new TeamsApi(defaultClient);
    String teamId = "teamId_example"; // String | 
    try {
      Team result = apiInstance.teamShow(teamId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TeamsApi#teamShow");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **String**|  |

### Return type

[**Team**](Team.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The information about the team. |  * Access-Control-Allow-Origin -  <br>  |

