# TvApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**tvChannelGames**](TvApi.md#tvChannelGames) | **GET** /api/tv/{channel} | Get best ongoing games of a TV channel
[**tvChannels**](TvApi.md#tvChannels) | **GET** /api/tv/channels | Get current TV games
[**tvFeed**](TvApi.md#tvFeed) | **GET** /api/tv/feed | Stream current TV game


<a name="tvChannelGames"></a>
# **tvChannelGames**
> Object tvChannelGames(channel, nb, moves, pgnInJson, tags, clocks, opening)

Get best ongoing games of a TV channel

Get a list of ongoing games for a given TV channel. Similar to [lichess.org/games](https://lichess.org/games).  Available in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TvApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    TvApi apiInstance = new TvApi(defaultClient);
    String channel = "channel_example"; // String | The name of the channel in lowercase.
    BigDecimal nb = new BigDecimal("10"); // BigDecimal | Number of games to fetch.
    Boolean moves = true; // Boolean | Include the PGN moves.
    Boolean pgnInJson = false; // Boolean | Include the full PGN within the JSON response, in a `pgn` field.
    Boolean tags = true; // Boolean | Include the PGN tags.
    Boolean clocks = false; // Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
    Boolean opening = false; // Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
    try {
      Object result = apiInstance.tvChannelGames(channel, nb, moves, pgnInJson, tags, clocks, opening);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TvApi#tvChannelGames");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **channel** | **String**| The name of the channel in lowercase. |
 **nb** | **BigDecimal**| Number of games to fetch. | [optional] [default to 10]
 **moves** | **Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | [optional] [default to false]
 **tags** | **Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to false]
 **opening** | **Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to false]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The representation of the games. |  -  |

<a name="tvChannels"></a>
# **tvChannels**
> Object tvChannels()

Get current TV games

Get basic info about the best games being played for each speed and variant, but also computer games and bot games.  See [lichess.org/tv](https://lichess.org/tv). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TvApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    TvApi apiInstance = new TvApi(defaultClient);
    try {
      Object result = apiInstance.tvChannels();
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TvApi#tvChannels");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of games being played for each speed and variant. |  * Access-Control-Allow-Origin -  <br>  |

<a name="tvFeed"></a>
# **tvFeed**
> Object tvFeed()

Stream current TV game

Stream positions and moves of the current [TV game](https://lichess.org/tv) in [ndjson](#section/Introduction/Streaming-with-ND-JSON). A summary of the game is sent as a first message, and when the featured game changes.  Try it with &#x60;curl https://lichess.org/api/tv/feed&#x60;. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.TvApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    TvApi apiInstance = new TvApi(defaultClient);
    try {
      Object result = apiInstance.tvFeed();
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling TvApi#tvFeed");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The stream of the current TV game. |  -  |

