# UsersApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiCrosstable**](UsersApi.md#apiCrosstable) | **GET** /api/crosstable/{user1}/{user2} | Get crosstable
[**apiUser**](UsersApi.md#apiUser) | **GET** /api/user/{username} | Get user public data
[**apiUserActivity**](UsersApi.md#apiUserActivity) | **GET** /api/user/{username}/activity | Get user activity
[**apiUserPerf**](UsersApi.md#apiUserPerf) | **GET** /api/user/{username}/perf/{perf} | Get performance statistics of a user
[**apiUserRatingHistory**](UsersApi.md#apiUserRatingHistory) | **GET** /api/user/{username}/rating-history | Get rating history of a user
[**apiUsers**](UsersApi.md#apiUsers) | **POST** /api/users | Get users by ID
[**apiUsersStatus**](UsersApi.md#apiUsersStatus) | **GET** /api/users/status | Get real-time users status
[**player**](UsersApi.md#player) | **GET** /player | Get all top 10
[**playerTopNbPerfType**](UsersApi.md#playerTopNbPerfType) | **GET** /player/top/{nb}/{perfType} | Get one leaderboard
[**streamerLive**](UsersApi.md#streamerLive) | **GET** /streamer/live | Get live streamers
[**teamIdUsers**](UsersApi.md#teamIdUsers) | **GET** /api/team/{teamId}/users | Get members of a team


<a name="apiCrosstable"></a>
# **apiCrosstable**
> Object apiCrosstable(user1, user2, matchup)

Get crosstable

Get total number of games, and current score, of any two users.  If the &#x60;matchup&#x60; flag is provided, and the users are currently playing, also gets the current match game number and scores. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.UsersApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    UsersApi apiInstance = new UsersApi(defaultClient);
    String user1 = "user1_example"; // String | 
    String user2 = "user2_example"; // String | 
    Boolean matchup = true; // Boolean | Whether to get the current match data, if any
    try {
      Object result = apiInstance.apiCrosstable(user1, user2, matchup);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling UsersApi#apiCrosstable");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **user1** | **String**|  |
 **user2** | **String**|  |
 **matchup** | **Boolean**| Whether to get the current match data, if any | [optional]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The crosstable of the two users. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiUser"></a>
# **apiUser**
> UserExtended apiUser(username)

Get user public data

Read public data of a user. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.UsersApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    UsersApi apiInstance = new UsersApi(defaultClient);
    String username = "username_example"; // String | 
    try {
      UserExtended result = apiInstance.apiUser(username);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling UsersApi#apiUser");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |

### Return type

[**UserExtended**](UserExtended.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The information of the user. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiUserActivity"></a>
# **apiUserActivity**
> apiUserActivity(username)

Get user activity

Read data to generate the activity feed of a user. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.UsersApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    UsersApi apiInstance = new UsersApi(defaultClient);
    String username = "username_example"; // String | 
    try {
      apiInstance.apiUserActivity(username);
    } catch (ApiException e) {
      System.err.println("Exception when calling UsersApi#apiUserActivity");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |

### Return type

null (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The activity feed of the user. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiUserPerf"></a>
# **apiUserPerf**
> Object apiUserPerf(username, perf)

Get performance statistics of a user

Read performance statistics of a user, for a single performance. Similar to the [performance pages on the website](https://lichess.org/@/thibault/perf/bullet). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.UsersApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    UsersApi apiInstance = new UsersApi(defaultClient);
    String username = "username_example"; // String | 
    PerfType perf = PerfType.fromValue("ultraBullet"); // PerfType | 
    try {
      Object result = apiInstance.apiUserPerf(username, perf);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling UsersApi#apiUserPerf");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |
 **perf** | [**PerfType**](.md)|  | [enum: ultraBullet, bullet, blitz, rapid, classical, correspondence, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The performance statistics of the user |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiUserRatingHistory"></a>
# **apiUserRatingHistory**
> Object apiUserRatingHistory(username)

Get rating history of a user

Read rating history of a user, for all perf types. There is at most one entry per day. Format of an entry is &#x60;[year, month, day, rating]&#x60;. &#x60;month&#x60; starts at zero (January). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.UsersApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    UsersApi apiInstance = new UsersApi(defaultClient);
    String username = "username_example"; // String | 
    try {
      Object result = apiInstance.apiUserRatingHistory(username);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling UsersApi#apiUserRatingHistory");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The rating history of the user. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiUsers"></a>
# **apiUsers**
> List&lt;User&gt; apiUsers(body)

Get users by ID

Get up to 300 users by their IDs. Users are returned in the same order as the IDs.  The method is &#x60;POST&#x60; so a longer list of IDs can be sent in the request body. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.UsersApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    UsersApi apiInstance = new UsersApi(defaultClient);
    String body = aliquantus,chess-network,lovlas; // String | User IDs separated by commas.
    try {
      List<User> result = apiInstance.apiUsers(body);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling UsersApi#apiUsers");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | **String**| User IDs separated by commas. |

### Return type

[**List&lt;User&gt;**](User.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of users. |  * Access-Control-Allow-Origin -  <br>  |

<a name="apiUsersStatus"></a>
# **apiUsersStatus**
> List&lt;InlineResponse200&gt; apiUsersStatus(ids)

Get real-time users status

Read the &#x60;online&#x60;, &#x60;playing&#x60; and &#x60;streaming&#x60; flags of several users.  This API is very fast and cheap on lichess side. So you can call it quite often (like once every 5 seconds).  Use it to track players and know when they&#39;re connected on lichess and playing games. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.UsersApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    UsersApi apiInstance = new UsersApi(defaultClient);
    String ids = "aliquantus,chess-network,lovlas"; // String | User IDs separated by commas. Up to 100 IDs.
    try {
      List<InlineResponse200> result = apiInstance.apiUsersStatus(ids);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling UsersApi#apiUsersStatus");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ids** | **String**| User IDs separated by commas. Up to 100 IDs. |

### Return type

[**List&lt;InlineResponse200&gt;**](InlineResponse200.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of users and their respective statuses. |  * Access-Control-Allow-Origin -  <br>  |

<a name="player"></a>
# **player**
> Object player()

Get all top 10

Get the top 10 players for each speed and variant.  See &lt;https://lichess.org/player&gt;. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.UsersApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    UsersApi apiInstance = new UsersApi(defaultClient);
    try {
      Object result = apiInstance.player();
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling UsersApi#player");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/vnd.lichess.v3+json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of variants with their respective top players. |  -  |

<a name="playerTopNbPerfType"></a>
# **playerTopNbPerfType**
> Object playerTopNbPerfType(nb, perfType)

Get one leaderboard

Get the leaderboard for a single speed or variant (a.k.a. &#x60;perfType&#x60;). There is no leaderboard for correspondence or puzzles.  See &lt;https://lichess.org/player/top/200/bullet&gt;. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.UsersApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    UsersApi apiInstance = new UsersApi(defaultClient);
    Integer nb = 100; // Integer | How many users to fetch
    String perfType = "ultraBullet"; // String | The speed or variant
    try {
      Object result = apiInstance.playerTopNbPerfType(nb, perfType);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling UsersApi#playerTopNbPerfType");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nb** | **Integer**| How many users to fetch |
 **perfType** | **String**| The speed or variant | [enum: ultraBullet, bullet, blitz, rapid, classical, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]

### Return type

**Object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/vnd.lichess.v3+json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of top players for the variant. |  * Access-Control-Allow-Origin -  <br>  |

<a name="streamerLive"></a>
# **streamerLive**
> List&lt;InlineResponse2002&gt; streamerLive()

Get live streamers

Get basic info about currently streaming users.  This API is very fast and cheap on lichess side. So you can call it quite often (like once every 5 seconds). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.UsersApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");

    UsersApi apiInstance = new UsersApi(defaultClient);
    try {
      List<InlineResponse2002> result = apiInstance.streamerLive();
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling UsersApi#streamerLive");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List&lt;InlineResponse2002&gt;**](InlineResponse2002.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of live streamers and their respective information. |  -  |

<a name="teamIdUsers"></a>
# **teamIdUsers**
> UserExtended teamIdUsers(teamId)

Get members of a team

Members are sorted by reverse chronological order of joining the team (most recent first). OAuth only required if the list of members is private.  Members are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.UsersApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://lichess.org");
    
    // Configure OAuth2 access token for authorization: OAuth2
    OAuth OAuth2 = (OAuth) defaultClient.getAuthentication("OAuth2");
    OAuth2.setAccessToken("YOUR ACCESS TOKEN");

    UsersApi apiInstance = new UsersApi(defaultClient);
    String teamId = "coders"; // String | 
    try {
      UserExtended result = apiInstance.teamIdUsers(teamId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling UsersApi#teamIdUsers");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **String**|  |

### Return type

[**UserExtended**](UserExtended.md)

### Authorization

[OAuth2](../README.md#OAuth2)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The list of users in the team. |  * Access-Control-Allow-Origin -  <br>  |

