/*
 * Lichess.org API reference
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */


package org.openapitools.client.api;

import org.openapitools.client.ApiCallback;
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.ApiResponse;
import org.openapitools.client.Configuration;
import org.openapitools.client.Pair;
import org.openapitools.client.ProgressRequestBody;
import org.openapitools.client.ProgressResponseBody;

import com.google.gson.reflect.TypeToken;

import java.io.IOException;


import java.math.BigDecimal;
import org.openapitools.client.model.VariantKey;

import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class AnalysisApi {
    private ApiClient localVarApiClient;

    public AnalysisApi() {
        this(Configuration.getDefaultApiClient());
    }

    public AnalysisApi(ApiClient apiClient) {
        this.localVarApiClient = apiClient;
    }

    public ApiClient getApiClient() {
        return localVarApiClient;
    }

    public void setApiClient(ApiClient apiClient) {
        this.localVarApiClient = apiClient;
    }

    /**
     * Build call for apiCloudEval
     * @param fen FEN of the position (required)
     * @param multiPv Number of variations (optional, default to 1)
     * @param variant Variant (optional, default to standard)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The evaluation of the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call apiCloudEvalCall(String fen, BigDecimal multiPv, VariantKey variant, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/cloud-eval";

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (fen != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("fen", fen));
        }

        if (multiPv != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("multiPv", multiPv));
        }

        if (variant != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("variant", variant));
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call apiCloudEvalValidateBeforeCall(String fen, BigDecimal multiPv, VariantKey variant, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'fen' is set
        if (fen == null) {
            throw new ApiException("Missing the required parameter 'fen' when calling apiCloudEval(Async)");
        }
        

        okhttp3.Call localVarCall = apiCloudEvalCall(fen, multiPv, variant, _callback);
        return localVarCall;

    }

    /**
     * Get cloud evaluation of a position.
     * Get the cached evaluation of a position, if available.  Opening positions have more chances of being available. There are about 7 million positions in the database.  Up to 5 variations may be available. Variants are supported. 
     * @param fen FEN of the position (required)
     * @param multiPv Number of variations (optional, default to 1)
     * @param variant Variant (optional, default to standard)
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The evaluation of the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public void apiCloudEval(String fen, BigDecimal multiPv, VariantKey variant) throws ApiException {
        apiCloudEvalWithHttpInfo(fen, multiPv, variant);
    }

    /**
     * Get cloud evaluation of a position.
     * Get the cached evaluation of a position, if available.  Opening positions have more chances of being available. There are about 7 million positions in the database.  Up to 5 variations may be available. Variants are supported. 
     * @param fen FEN of the position (required)
     * @param multiPv Number of variations (optional, default to 1)
     * @param variant Variant (optional, default to standard)
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The evaluation of the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<Void> apiCloudEvalWithHttpInfo(String fen, BigDecimal multiPv, VariantKey variant) throws ApiException {
        okhttp3.Call localVarCall = apiCloudEvalValidateBeforeCall(fen, multiPv, variant, null);
        return localVarApiClient.execute(localVarCall);
    }

    /**
     * Get cloud evaluation of a position. (asynchronously)
     * Get the cached evaluation of a position, if available.  Opening positions have more chances of being available. There are about 7 million positions in the database.  Up to 5 variations may be available. Variants are supported. 
     * @param fen FEN of the position (required)
     * @param multiPv Number of variations (optional, default to 1)
     * @param variant Variant (optional, default to standard)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The evaluation of the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call apiCloudEvalAsync(String fen, BigDecimal multiPv, VariantKey variant, final ApiCallback<Void> _callback) throws ApiException {

        okhttp3.Call localVarCall = apiCloudEvalValidateBeforeCall(fen, multiPv, variant, _callback);
        localVarApiClient.executeAsync(localVarCall, _callback);
        return localVarCall;
    }
}
