/*
 * Lichess.org API reference
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */


package org.openapitools.client.api;

import org.openapitools.client.ApiCallback;
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.ApiResponse;
import org.openapitools.client.Configuration;
import org.openapitools.client.Pair;
import org.openapitools.client.ProgressRequestBody;
import org.openapitools.client.ProgressResponseBody;

import com.google.gson.reflect.TypeToken;

import java.io.IOException;


import org.openapitools.client.model.ArenaTournaments;
import java.math.BigDecimal;
import org.openapitools.client.model.Error;
import org.openapitools.client.model.Ok;
import org.openapitools.client.model.VariantKey;

import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class ArenaTournamentsApi {
    private ApiClient localVarApiClient;

    public ArenaTournamentsApi() {
        this(Configuration.getDefaultApiClient());
    }

    public ArenaTournamentsApi(ApiClient apiClient) {
        this.localVarApiClient = apiClient;
    }

    public ApiClient getApiClient() {
        return localVarApiClient;
    }

    public void setApiClient(ApiClient apiClient) {
        this.localVarApiClient = apiClient;
    }

    /**
     * Build call for apiTeamArena
     * @param teamId ID of the team (required)
     * @param max How many tournaments to download. (optional, default to 100)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of Arena tournaments of a team. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call apiTeamArenaCall(String teamId, Integer max, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/team/{teamId}/arena"
            .replaceAll("\\{" + "teamId" + "\\}", localVarApiClient.escapeString(teamId.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (max != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("max", max));
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call apiTeamArenaValidateBeforeCall(String teamId, Integer max, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'teamId' is set
        if (teamId == null) {
            throw new ApiException("Missing the required parameter 'teamId' when calling apiTeamArena(Async)");
        }
        

        okhttp3.Call localVarCall = apiTeamArenaCall(teamId, max, _callback);
        return localVarCall;

    }

    /**
     * Get team Arena tournaments
     * Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * @param teamId ID of the team (required)
     * @param max How many tournaments to download. (optional, default to 100)
     * @return List&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of Arena tournaments of a team. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public List<Object> apiTeamArena(String teamId, Integer max) throws ApiException {
        ApiResponse<List<Object>> localVarResp = apiTeamArenaWithHttpInfo(teamId, max);
        return localVarResp.getData();
    }

    /**
     * Get team Arena tournaments
     * Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * @param teamId ID of the team (required)
     * @param max How many tournaments to download. (optional, default to 100)
     * @return ApiResponse&lt;List&lt;Object&gt;&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of Arena tournaments of a team. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<List<Object>> apiTeamArenaWithHttpInfo(String teamId, Integer max) throws ApiException {
        okhttp3.Call localVarCall = apiTeamArenaValidateBeforeCall(teamId, max, null);
        Type localVarReturnType = new TypeToken<List<Object>>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Get team Arena tournaments (asynchronously)
     * Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * @param teamId ID of the team (required)
     * @param max How many tournaments to download. (optional, default to 100)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of Arena tournaments of a team. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call apiTeamArenaAsync(String teamId, Integer max, final ApiCallback<List<Object>> _callback) throws ApiException {

        okhttp3.Call localVarCall = apiTeamArenaValidateBeforeCall(teamId, max, _callback);
        Type localVarReturnType = new TypeToken<List<Object>>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for apiTournament
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of current tournaments. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentCall(final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/tournament";

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call apiTournamentValidateBeforeCall(final ApiCallback _callback) throws ApiException {
        

        okhttp3.Call localVarCall = apiTournamentCall(_callback);
        return localVarCall;

    }

    /**
     * Get current tournaments
     * Get recently finished, ongoing, and upcoming tournaments.  This API is used to display the [Lichess tournament schedule](https://lichess.org/tournament). 
     * @return ArenaTournaments
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of current tournaments. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ArenaTournaments apiTournament() throws ApiException {
        ApiResponse<ArenaTournaments> localVarResp = apiTournamentWithHttpInfo();
        return localVarResp.getData();
    }

    /**
     * Get current tournaments
     * Get recently finished, ongoing, and upcoming tournaments.  This API is used to display the [Lichess tournament schedule](https://lichess.org/tournament). 
     * @return ApiResponse&lt;ArenaTournaments&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of current tournaments. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<ArenaTournaments> apiTournamentWithHttpInfo() throws ApiException {
        okhttp3.Call localVarCall = apiTournamentValidateBeforeCall(null);
        Type localVarReturnType = new TypeToken<ArenaTournaments>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Get current tournaments (asynchronously)
     * Get recently finished, ongoing, and upcoming tournaments.  This API is used to display the [Lichess tournament schedule](https://lichess.org/tournament). 
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of current tournaments. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentAsync(final ApiCallback<ArenaTournaments> _callback) throws ApiException {

        okhttp3.Call localVarCall = apiTournamentValidateBeforeCall(_callback);
        Type localVarReturnType = new TypeToken<ArenaTournaments>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for apiTournamentJoin
     * @param id The tournament ID. (required)
     * @param password The tournament password, if one is required (optional)
     * @param team The team to join the tournament with, for team battle tournaments (optional)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The tournament was successfully joined. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> Joining the tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentJoinCall(String id, String password, String team, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/tournament/{id}/join"
            .replaceAll("\\{" + "id" + "\\}", localVarApiClient.escapeString(id.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (password != null) {
            localVarFormParams.put("password", password);
        }

        if (team != null) {
            localVarFormParams.put("team", team);
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            "application/x-www-form-urlencoded"
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "POST", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call apiTournamentJoinValidateBeforeCall(String id, String password, String team, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'id' is set
        if (id == null) {
            throw new ApiException("Missing the required parameter 'id' when calling apiTournamentJoin(Async)");
        }
        

        okhttp3.Call localVarCall = apiTournamentJoinCall(id, password, team, _callback);
        return localVarCall;

    }

    /**
     * Join an Arena tournament
     * Join an Arena tournament, possibly with a password and/or a team. 
     * @param id The tournament ID. (required)
     * @param password The tournament password, if one is required (optional)
     * @param team The team to join the tournament with, for team battle tournaments (optional)
     * @return Ok
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The tournament was successfully joined. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> Joining the tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public Ok apiTournamentJoin(String id, String password, String team) throws ApiException {
        ApiResponse<Ok> localVarResp = apiTournamentJoinWithHttpInfo(id, password, team);
        return localVarResp.getData();
    }

    /**
     * Join an Arena tournament
     * Join an Arena tournament, possibly with a password and/or a team. 
     * @param id The tournament ID. (required)
     * @param password The tournament password, if one is required (optional)
     * @param team The team to join the tournament with, for team battle tournaments (optional)
     * @return ApiResponse&lt;Ok&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The tournament was successfully joined. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> Joining the tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<Ok> apiTournamentJoinWithHttpInfo(String id, String password, String team) throws ApiException {
        okhttp3.Call localVarCall = apiTournamentJoinValidateBeforeCall(id, password, team, null);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Join an Arena tournament (asynchronously)
     * Join an Arena tournament, possibly with a password and/or a team. 
     * @param id The tournament ID. (required)
     * @param password The tournament password, if one is required (optional)
     * @param team The team to join the tournament with, for team battle tournaments (optional)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The tournament was successfully joined. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> Joining the tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentJoinAsync(String id, String password, String team, final ApiCallback<Ok> _callback) throws ApiException {

        okhttp3.Call localVarCall = apiTournamentJoinValidateBeforeCall(id, password, team, _callback);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for apiTournamentPost
     * @param clockTime Clock initial time in minutes (required)
     * @param clockIncrement Clock increment in seconds (required)
     * @param minutes How long the tournament lasts, in minutes (required)
     * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
     * @param waitMinutes How long to wait before starting the tournament, from now, in minutes (optional, default to 5)
     * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting (optional)
     * @param variant  (optional, default to standard)
     * @param rated Games are rated and impact players ratings (optional, default to true)
     * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
     * @param berserkable Whether the players can use berserk (optional, default to true)
     * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2. (optional, default to true)
     * @param hasChat Whether the players can discuss in a chat (optional, default to true)
     * @param description Anything you want to tell players about the tournament (optional)
     * @param password Make the tournament private, and restrict access with a password (optional)
     * @param teambBattleByTeam Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost).  (optional)
     * @param conditionsTeamMemberTeamId Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. &#x60;https://lichess.org/team/coders&#x60; has teamId &#x3D; &#x60;coders&#x60;.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use &#x60;teamBattleByTeam&#x60; instead.  (optional)
     * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsNbRatedGameNb Minimum number of rated games required to join. (optional)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The Arena tournament has been successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the Arena tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentPostCall(BigDecimal clockTime, Integer clockIncrement, Integer minutes, String name, Integer waitMinutes, Integer startDate, VariantKey variant, Boolean rated, String position, Boolean berserkable, Boolean streakable, Boolean hasChat, String description, String password, String teambBattleByTeam, String conditionsTeamMemberTeamId, Integer conditionsMinRatingRating, Integer conditionsMaxRatingRating, Integer conditionsNbRatedGameNb, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/tournament";

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (name != null) {
            localVarFormParams.put("name", name);
        }

        if (clockTime != null) {
            localVarFormParams.put("clockTime", clockTime);
        }

        if (clockIncrement != null) {
            localVarFormParams.put("clockIncrement", clockIncrement);
        }

        if (minutes != null) {
            localVarFormParams.put("minutes", minutes);
        }

        if (waitMinutes != null) {
            localVarFormParams.put("waitMinutes", waitMinutes);
        }

        if (startDate != null) {
            localVarFormParams.put("startDate", startDate);
        }

        if (variant != null) {
            localVarFormParams.put("variant", variant);
        }

        if (rated != null) {
            localVarFormParams.put("rated", rated);
        }

        if (position != null) {
            localVarFormParams.put("position", position);
        }

        if (berserkable != null) {
            localVarFormParams.put("berserkable", berserkable);
        }

        if (streakable != null) {
            localVarFormParams.put("streakable", streakable);
        }

        if (hasChat != null) {
            localVarFormParams.put("hasChat", hasChat);
        }

        if (description != null) {
            localVarFormParams.put("description", description);
        }

        if (password != null) {
            localVarFormParams.put("password", password);
        }

        if (teambBattleByTeam != null) {
            localVarFormParams.put("teambBattleByTeam", teambBattleByTeam);
        }

        if (conditionsTeamMemberTeamId != null) {
            localVarFormParams.put("conditions.teamMember.teamId", conditionsTeamMemberTeamId);
        }

        if (conditionsMinRatingRating != null) {
            localVarFormParams.put("conditions.minRating.rating", conditionsMinRatingRating);
        }

        if (conditionsMaxRatingRating != null) {
            localVarFormParams.put("conditions.maxRating.rating", conditionsMaxRatingRating);
        }

        if (conditionsNbRatedGameNb != null) {
            localVarFormParams.put("conditions.nbRatedGame.nb", conditionsNbRatedGameNb);
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            "application/x-www-form-urlencoded"
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "POST", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call apiTournamentPostValidateBeforeCall(BigDecimal clockTime, Integer clockIncrement, Integer minutes, String name, Integer waitMinutes, Integer startDate, VariantKey variant, Boolean rated, String position, Boolean berserkable, Boolean streakable, Boolean hasChat, String description, String password, String teambBattleByTeam, String conditionsTeamMemberTeamId, Integer conditionsMinRatingRating, Integer conditionsMaxRatingRating, Integer conditionsNbRatedGameNb, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'clockTime' is set
        if (clockTime == null) {
            throw new ApiException("Missing the required parameter 'clockTime' when calling apiTournamentPost(Async)");
        }
        
        // verify the required parameter 'clockIncrement' is set
        if (clockIncrement == null) {
            throw new ApiException("Missing the required parameter 'clockIncrement' when calling apiTournamentPost(Async)");
        }
        
        // verify the required parameter 'minutes' is set
        if (minutes == null) {
            throw new ApiException("Missing the required parameter 'minutes' when calling apiTournamentPost(Async)");
        }
        

        okhttp3.Call localVarCall = apiTournamentPostCall(clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, teambBattleByTeam, conditionsTeamMemberTeamId, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb, _callback);
        return localVarCall;

    }

    /**
     * Create a new Arena tournament
     * Create a public or private Arena tournament.  This endpoint mirrors the form on &lt;https://lichess.org/tournament/new&gt;.  You can create up to 12 public tournaments per day, or 24 private tournaments.  A team battle can be created by specifying the &#x60;teambBattleByTeam&#x60; argument. 
     * @param clockTime Clock initial time in minutes (required)
     * @param clockIncrement Clock increment in seconds (required)
     * @param minutes How long the tournament lasts, in minutes (required)
     * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
     * @param waitMinutes How long to wait before starting the tournament, from now, in minutes (optional, default to 5)
     * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting (optional)
     * @param variant  (optional, default to standard)
     * @param rated Games are rated and impact players ratings (optional, default to true)
     * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
     * @param berserkable Whether the players can use berserk (optional, default to true)
     * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2. (optional, default to true)
     * @param hasChat Whether the players can discuss in a chat (optional, default to true)
     * @param description Anything you want to tell players about the tournament (optional)
     * @param password Make the tournament private, and restrict access with a password (optional)
     * @param teambBattleByTeam Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost).  (optional)
     * @param conditionsTeamMemberTeamId Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. &#x60;https://lichess.org/team/coders&#x60; has teamId &#x3D; &#x60;coders&#x60;.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use &#x60;teamBattleByTeam&#x60; instead.  (optional)
     * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsNbRatedGameNb Minimum number of rated games required to join. (optional)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The Arena tournament has been successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the Arena tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public Object apiTournamentPost(BigDecimal clockTime, Integer clockIncrement, Integer minutes, String name, Integer waitMinutes, Integer startDate, VariantKey variant, Boolean rated, String position, Boolean berserkable, Boolean streakable, Boolean hasChat, String description, String password, String teambBattleByTeam, String conditionsTeamMemberTeamId, Integer conditionsMinRatingRating, Integer conditionsMaxRatingRating, Integer conditionsNbRatedGameNb) throws ApiException {
        ApiResponse<Object> localVarResp = apiTournamentPostWithHttpInfo(clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, teambBattleByTeam, conditionsTeamMemberTeamId, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb);
        return localVarResp.getData();
    }

    /**
     * Create a new Arena tournament
     * Create a public or private Arena tournament.  This endpoint mirrors the form on &lt;https://lichess.org/tournament/new&gt;.  You can create up to 12 public tournaments per day, or 24 private tournaments.  A team battle can be created by specifying the &#x60;teambBattleByTeam&#x60; argument. 
     * @param clockTime Clock initial time in minutes (required)
     * @param clockIncrement Clock increment in seconds (required)
     * @param minutes How long the tournament lasts, in minutes (required)
     * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
     * @param waitMinutes How long to wait before starting the tournament, from now, in minutes (optional, default to 5)
     * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting (optional)
     * @param variant  (optional, default to standard)
     * @param rated Games are rated and impact players ratings (optional, default to true)
     * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
     * @param berserkable Whether the players can use berserk (optional, default to true)
     * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2. (optional, default to true)
     * @param hasChat Whether the players can discuss in a chat (optional, default to true)
     * @param description Anything you want to tell players about the tournament (optional)
     * @param password Make the tournament private, and restrict access with a password (optional)
     * @param teambBattleByTeam Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost).  (optional)
     * @param conditionsTeamMemberTeamId Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. &#x60;https://lichess.org/team/coders&#x60; has teamId &#x3D; &#x60;coders&#x60;.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use &#x60;teamBattleByTeam&#x60; instead.  (optional)
     * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsNbRatedGameNb Minimum number of rated games required to join. (optional)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The Arena tournament has been successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the Arena tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<Object> apiTournamentPostWithHttpInfo(BigDecimal clockTime, Integer clockIncrement, Integer minutes, String name, Integer waitMinutes, Integer startDate, VariantKey variant, Boolean rated, String position, Boolean berserkable, Boolean streakable, Boolean hasChat, String description, String password, String teambBattleByTeam, String conditionsTeamMemberTeamId, Integer conditionsMinRatingRating, Integer conditionsMaxRatingRating, Integer conditionsNbRatedGameNb) throws ApiException {
        okhttp3.Call localVarCall = apiTournamentPostValidateBeforeCall(clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, teambBattleByTeam, conditionsTeamMemberTeamId, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Create a new Arena tournament (asynchronously)
     * Create a public or private Arena tournament.  This endpoint mirrors the form on &lt;https://lichess.org/tournament/new&gt;.  You can create up to 12 public tournaments per day, or 24 private tournaments.  A team battle can be created by specifying the &#x60;teambBattleByTeam&#x60; argument. 
     * @param clockTime Clock initial time in minutes (required)
     * @param clockIncrement Clock increment in seconds (required)
     * @param minutes How long the tournament lasts, in minutes (required)
     * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
     * @param waitMinutes How long to wait before starting the tournament, from now, in minutes (optional, default to 5)
     * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting (optional)
     * @param variant  (optional, default to standard)
     * @param rated Games are rated and impact players ratings (optional, default to true)
     * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
     * @param berserkable Whether the players can use berserk (optional, default to true)
     * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2. (optional, default to true)
     * @param hasChat Whether the players can discuss in a chat (optional, default to true)
     * @param description Anything you want to tell players about the tournament (optional)
     * @param password Make the tournament private, and restrict access with a password (optional)
     * @param teambBattleByTeam Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost).  (optional)
     * @param conditionsTeamMemberTeamId Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. &#x60;https://lichess.org/team/coders&#x60; has teamId &#x3D; &#x60;coders&#x60;.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use &#x60;teamBattleByTeam&#x60; instead.  (optional)
     * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsNbRatedGameNb Minimum number of rated games required to join. (optional)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The Arena tournament has been successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the Arena tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentPostAsync(BigDecimal clockTime, Integer clockIncrement, Integer minutes, String name, Integer waitMinutes, Integer startDate, VariantKey variant, Boolean rated, String position, Boolean berserkable, Boolean streakable, Boolean hasChat, String description, String password, String teambBattleByTeam, String conditionsTeamMemberTeamId, Integer conditionsMinRatingRating, Integer conditionsMaxRatingRating, Integer conditionsNbRatedGameNb, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = apiTournamentPostValidateBeforeCall(clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, teambBattleByTeam, conditionsTeamMemberTeamId, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for apiTournamentTeamBattlePost
     * @param id The tournament ID (8 characters).. (required)
     * @param teams All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: &#x60;coders,zhigalko_sergei-fan-club,hhSwTKZv&#x60;  (required)
     * @param nbLeaders Number team leaders per team. (required)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The team battle tournament was successfully updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The update of the team battle tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentTeamBattlePostCall(String id, String teams, Integer nbLeaders, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/tournament/team-battle/{id}"
            .replaceAll("\\{" + "id" + "\\}", localVarApiClient.escapeString(id.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (teams != null) {
            localVarFormParams.put("teams", teams);
        }

        if (nbLeaders != null) {
            localVarFormParams.put("nbLeaders", nbLeaders);
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            "application/x-www-form-urlencoded"
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "POST", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call apiTournamentTeamBattlePostValidateBeforeCall(String id, String teams, Integer nbLeaders, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'id' is set
        if (id == null) {
            throw new ApiException("Missing the required parameter 'id' when calling apiTournamentTeamBattlePost(Async)");
        }
        
        // verify the required parameter 'teams' is set
        if (teams == null) {
            throw new ApiException("Missing the required parameter 'teams' when calling apiTournamentTeamBattlePost(Async)");
        }
        
        // verify the required parameter 'nbLeaders' is set
        if (nbLeaders == null) {
            throw new ApiException("Missing the required parameter 'nbLeaders' when calling apiTournamentTeamBattlePost(Async)");
        }
        

        okhttp3.Call localVarCall = apiTournamentTeamBattlePostCall(id, teams, nbLeaders, _callback);
        return localVarCall;

    }

    /**
     * Update a team battle
     * Set the teams and number of leaders of a team battle.  To update the other attributes of a team battle, use the [tournament update endpoint](#operation/apiTournamentUpdate). 
     * @param id The tournament ID (8 characters).. (required)
     * @param teams All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: &#x60;coders,zhigalko_sergei-fan-club,hhSwTKZv&#x60;  (required)
     * @param nbLeaders Number team leaders per team. (required)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The team battle tournament was successfully updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The update of the team battle tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public Object apiTournamentTeamBattlePost(String id, String teams, Integer nbLeaders) throws ApiException {
        ApiResponse<Object> localVarResp = apiTournamentTeamBattlePostWithHttpInfo(id, teams, nbLeaders);
        return localVarResp.getData();
    }

    /**
     * Update a team battle
     * Set the teams and number of leaders of a team battle.  To update the other attributes of a team battle, use the [tournament update endpoint](#operation/apiTournamentUpdate). 
     * @param id The tournament ID (8 characters).. (required)
     * @param teams All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: &#x60;coders,zhigalko_sergei-fan-club,hhSwTKZv&#x60;  (required)
     * @param nbLeaders Number team leaders per team. (required)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The team battle tournament was successfully updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The update of the team battle tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<Object> apiTournamentTeamBattlePostWithHttpInfo(String id, String teams, Integer nbLeaders) throws ApiException {
        okhttp3.Call localVarCall = apiTournamentTeamBattlePostValidateBeforeCall(id, teams, nbLeaders, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Update a team battle (asynchronously)
     * Set the teams and number of leaders of a team battle.  To update the other attributes of a team battle, use the [tournament update endpoint](#operation/apiTournamentUpdate). 
     * @param id The tournament ID (8 characters).. (required)
     * @param teams All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: &#x60;coders,zhigalko_sergei-fan-club,hhSwTKZv&#x60;  (required)
     * @param nbLeaders Number team leaders per team. (required)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The team battle tournament was successfully updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The update of the team battle tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentTeamBattlePostAsync(String id, String teams, Integer nbLeaders, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = apiTournamentTeamBattlePostValidateBeforeCall(id, teams, nbLeaders, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for apiTournamentTerminate
     * @param id The tournament ID. (required)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The tournament was successfully terminated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> Terminating the tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentTerminateCall(String id, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/tournament/{id}/terminate"
            .replaceAll("\\{" + "id" + "\\}", localVarApiClient.escapeString(id.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "POST", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call apiTournamentTerminateValidateBeforeCall(String id, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'id' is set
        if (id == null) {
            throw new ApiException("Missing the required parameter 'id' when calling apiTournamentTerminate(Async)");
        }
        

        okhttp3.Call localVarCall = apiTournamentTerminateCall(id, _callback);
        return localVarCall;

    }

    /**
     * Terminate an Arena tournament
     * Terminate an Arena tournament 
     * @param id The tournament ID. (required)
     * @return Ok
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The tournament was successfully terminated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> Terminating the tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public Ok apiTournamentTerminate(String id) throws ApiException {
        ApiResponse<Ok> localVarResp = apiTournamentTerminateWithHttpInfo(id);
        return localVarResp.getData();
    }

    /**
     * Terminate an Arena tournament
     * Terminate an Arena tournament 
     * @param id The tournament ID. (required)
     * @return ApiResponse&lt;Ok&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The tournament was successfully terminated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> Terminating the tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<Ok> apiTournamentTerminateWithHttpInfo(String id) throws ApiException {
        okhttp3.Call localVarCall = apiTournamentTerminateValidateBeforeCall(id, null);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Terminate an Arena tournament (asynchronously)
     * Terminate an Arena tournament 
     * @param id The tournament ID. (required)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The tournament was successfully terminated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> Terminating the tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentTerminateAsync(String id, final ApiCallback<Ok> _callback) throws ApiException {

        okhttp3.Call localVarCall = apiTournamentTerminateValidateBeforeCall(id, _callback);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for apiTournamentUpdate
     * @param id The tournament ID. (required)
     * @param clockTime Clock initial time in minutes (required)
     * @param clockIncrement Clock increment in seconds (required)
     * @param minutes How long the tournament lasts, in minutes (required)
     * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
     * @param waitMinutes How long to wait before starting the tournament, from now, in minutes (optional, default to 5)
     * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting (optional)
     * @param variant  (optional, default to VariantKey.STANDARD)
     * @param rated Games are rated and impact players ratings (optional, default to true)
     * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
     * @param berserkable Whether the players can use berserk (optional, default to true)
     * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2. (optional, default to true)
     * @param hasChat Whether the players can discuss in a chat (optional, default to true)
     * @param description Anything you want to tell players about the tournament (optional)
     * @param password Make the tournament private, and restrict access with a password (optional)
     * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsNbRatedGameNb Minimum number of rated games required to join. (optional)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The Arena tournament was successfully updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The update of the Arena tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentUpdateCall(String id, BigDecimal clockTime, Integer clockIncrement, Integer minutes, String name, Integer waitMinutes, Integer startDate, VariantKey variant, Boolean rated, String position, Boolean berserkable, Boolean streakable, Boolean hasChat, String description, String password, Integer conditionsMinRatingRating, Integer conditionsMaxRatingRating, Integer conditionsNbRatedGameNb, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/tournament/{id}"
            .replaceAll("\\{" + "id" + "\\}", localVarApiClient.escapeString(id.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (name != null) {
            localVarFormParams.put("name", name);
        }

        if (clockTime != null) {
            localVarFormParams.put("clockTime", clockTime);
        }

        if (clockIncrement != null) {
            localVarFormParams.put("clockIncrement", clockIncrement);
        }

        if (minutes != null) {
            localVarFormParams.put("minutes", minutes);
        }

        if (waitMinutes != null) {
            localVarFormParams.put("waitMinutes", waitMinutes);
        }

        if (startDate != null) {
            localVarFormParams.put("startDate", startDate);
        }

        if (variant != null) {
            localVarFormParams.put("variant", variant);
        }

        if (rated != null) {
            localVarFormParams.put("rated", rated);
        }

        if (position != null) {
            localVarFormParams.put("position", position);
        }

        if (berserkable != null) {
            localVarFormParams.put("berserkable", berserkable);
        }

        if (streakable != null) {
            localVarFormParams.put("streakable", streakable);
        }

        if (hasChat != null) {
            localVarFormParams.put("hasChat", hasChat);
        }

        if (description != null) {
            localVarFormParams.put("description", description);
        }

        if (password != null) {
            localVarFormParams.put("password", password);
        }

        if (conditionsMinRatingRating != null) {
            localVarFormParams.put("conditions.minRating.rating", conditionsMinRatingRating);
        }

        if (conditionsMaxRatingRating != null) {
            localVarFormParams.put("conditions.maxRating.rating", conditionsMaxRatingRating);
        }

        if (conditionsNbRatedGameNb != null) {
            localVarFormParams.put("conditions.nbRatedGame.nb", conditionsNbRatedGameNb);
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            "application/x-www-form-urlencoded"
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "POST", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call apiTournamentUpdateValidateBeforeCall(String id, BigDecimal clockTime, Integer clockIncrement, Integer minutes, String name, Integer waitMinutes, Integer startDate, VariantKey variant, Boolean rated, String position, Boolean berserkable, Boolean streakable, Boolean hasChat, String description, String password, Integer conditionsMinRatingRating, Integer conditionsMaxRatingRating, Integer conditionsNbRatedGameNb, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'id' is set
        if (id == null) {
            throw new ApiException("Missing the required parameter 'id' when calling apiTournamentUpdate(Async)");
        }
        
        // verify the required parameter 'clockTime' is set
        if (clockTime == null) {
            throw new ApiException("Missing the required parameter 'clockTime' when calling apiTournamentUpdate(Async)");
        }
        
        // verify the required parameter 'clockIncrement' is set
        if (clockIncrement == null) {
            throw new ApiException("Missing the required parameter 'clockIncrement' when calling apiTournamentUpdate(Async)");
        }
        
        // verify the required parameter 'minutes' is set
        if (minutes == null) {
            throw new ApiException("Missing the required parameter 'minutes' when calling apiTournamentUpdate(Async)");
        }
        

        okhttp3.Call localVarCall = apiTournamentUpdateCall(id, clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb, _callback);
        return localVarCall;

    }

    /**
     * Update an Arena tournament
     * Update an Arena tournament.  Be mindful not to make important changes to ongoing tournaments.  Can be used to update a team battle. 
     * @param id The tournament ID. (required)
     * @param clockTime Clock initial time in minutes (required)
     * @param clockIncrement Clock increment in seconds (required)
     * @param minutes How long the tournament lasts, in minutes (required)
     * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
     * @param waitMinutes How long to wait before starting the tournament, from now, in minutes (optional, default to 5)
     * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting (optional)
     * @param variant  (optional, default to VariantKey.STANDARD)
     * @param rated Games are rated and impact players ratings (optional, default to true)
     * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
     * @param berserkable Whether the players can use berserk (optional, default to true)
     * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2. (optional, default to true)
     * @param hasChat Whether the players can discuss in a chat (optional, default to true)
     * @param description Anything you want to tell players about the tournament (optional)
     * @param password Make the tournament private, and restrict access with a password (optional)
     * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsNbRatedGameNb Minimum number of rated games required to join. (optional)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The Arena tournament was successfully updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The update of the Arena tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public Object apiTournamentUpdate(String id, BigDecimal clockTime, Integer clockIncrement, Integer minutes, String name, Integer waitMinutes, Integer startDate, VariantKey variant, Boolean rated, String position, Boolean berserkable, Boolean streakable, Boolean hasChat, String description, String password, Integer conditionsMinRatingRating, Integer conditionsMaxRatingRating, Integer conditionsNbRatedGameNb) throws ApiException {
        ApiResponse<Object> localVarResp = apiTournamentUpdateWithHttpInfo(id, clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb);
        return localVarResp.getData();
    }

    /**
     * Update an Arena tournament
     * Update an Arena tournament.  Be mindful not to make important changes to ongoing tournaments.  Can be used to update a team battle. 
     * @param id The tournament ID. (required)
     * @param clockTime Clock initial time in minutes (required)
     * @param clockIncrement Clock increment in seconds (required)
     * @param minutes How long the tournament lasts, in minutes (required)
     * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
     * @param waitMinutes How long to wait before starting the tournament, from now, in minutes (optional, default to 5)
     * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting (optional)
     * @param variant  (optional, default to VariantKey.STANDARD)
     * @param rated Games are rated and impact players ratings (optional, default to true)
     * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
     * @param berserkable Whether the players can use berserk (optional, default to true)
     * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2. (optional, default to true)
     * @param hasChat Whether the players can discuss in a chat (optional, default to true)
     * @param description Anything you want to tell players about the tournament (optional)
     * @param password Make the tournament private, and restrict access with a password (optional)
     * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsNbRatedGameNb Minimum number of rated games required to join. (optional)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The Arena tournament was successfully updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The update of the Arena tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<Object> apiTournamentUpdateWithHttpInfo(String id, BigDecimal clockTime, Integer clockIncrement, Integer minutes, String name, Integer waitMinutes, Integer startDate, VariantKey variant, Boolean rated, String position, Boolean berserkable, Boolean streakable, Boolean hasChat, String description, String password, Integer conditionsMinRatingRating, Integer conditionsMaxRatingRating, Integer conditionsNbRatedGameNb) throws ApiException {
        okhttp3.Call localVarCall = apiTournamentUpdateValidateBeforeCall(id, clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Update an Arena tournament (asynchronously)
     * Update an Arena tournament.  Be mindful not to make important changes to ongoing tournaments.  Can be used to update a team battle. 
     * @param id The tournament ID. (required)
     * @param clockTime Clock initial time in minutes (required)
     * @param clockIncrement Clock increment in seconds (required)
     * @param minutes How long the tournament lasts, in minutes (required)
     * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
     * @param waitMinutes How long to wait before starting the tournament, from now, in minutes (optional, default to 5)
     * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting (optional)
     * @param variant  (optional, default to VariantKey.STANDARD)
     * @param rated Games are rated and impact players ratings (optional, default to true)
     * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
     * @param berserkable Whether the players can use berserk (optional, default to true)
     * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2. (optional, default to true)
     * @param hasChat Whether the players can discuss in a chat (optional, default to true)
     * @param description Anything you want to tell players about the tournament (optional)
     * @param password Make the tournament private, and restrict access with a password (optional)
     * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
     * @param conditionsNbRatedGameNb Minimum number of rated games required to join. (optional)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The Arena tournament was successfully updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The update of the Arena tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentUpdateAsync(String id, BigDecimal clockTime, Integer clockIncrement, Integer minutes, String name, Integer waitMinutes, Integer startDate, VariantKey variant, Boolean rated, String position, Boolean berserkable, Boolean streakable, Boolean hasChat, String description, String password, Integer conditionsMinRatingRating, Integer conditionsMaxRatingRating, Integer conditionsNbRatedGameNb, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = apiTournamentUpdateValidateBeforeCall(id, clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for apiTournamentWithdraw
     * @param id The tournament ID. (required)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The tournament was successfully paused or left. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> Pausing/leaving the tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentWithdrawCall(String id, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/tournament/{id}/withdraw"
            .replaceAll("\\{" + "id" + "\\}", localVarApiClient.escapeString(id.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "POST", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call apiTournamentWithdrawValidateBeforeCall(String id, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'id' is set
        if (id == null) {
            throw new ApiException("Missing the required parameter 'id' when calling apiTournamentWithdraw(Async)");
        }
        

        okhttp3.Call localVarCall = apiTournamentWithdrawCall(id, _callback);
        return localVarCall;

    }

    /**
     * Pause of leave an Arena tournament
     * Leave a future Arena tournament, or take a break on an ongoing Arena tournament. It&#39;s possible to join again later. Points and streaks are preserved. 
     * @param id The tournament ID. (required)
     * @return Ok
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The tournament was successfully paused or left. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> Pausing/leaving the tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public Ok apiTournamentWithdraw(String id) throws ApiException {
        ApiResponse<Ok> localVarResp = apiTournamentWithdrawWithHttpInfo(id);
        return localVarResp.getData();
    }

    /**
     * Pause of leave an Arena tournament
     * Leave a future Arena tournament, or take a break on an ongoing Arena tournament. It&#39;s possible to join again later. Points and streaks are preserved. 
     * @param id The tournament ID. (required)
     * @return ApiResponse&lt;Ok&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The tournament was successfully paused or left. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> Pausing/leaving the tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<Ok> apiTournamentWithdrawWithHttpInfo(String id) throws ApiException {
        okhttp3.Call localVarCall = apiTournamentWithdrawValidateBeforeCall(id, null);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Pause of leave an Arena tournament (asynchronously)
     * Leave a future Arena tournament, or take a break on an ongoing Arena tournament. It&#39;s possible to join again later. Points and streaks are preserved. 
     * @param id The tournament ID. (required)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The tournament was successfully paused or left. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> Pausing/leaving the tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call apiTournamentWithdrawAsync(String id, final ApiCallback<Ok> _callback) throws ApiException {

        okhttp3.Call localVarCall = apiTournamentWithdrawValidateBeforeCall(id, _callback);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for apiUserNameTournamentCreated
     * @param username The user whose created tournaments to fetch (required)
     * @param status Include tournaments in the given status: \&quot;Created\&quot; (10), \&quot;Started\&quot; (20), \&quot;Finished\&quot; (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: &#x60;?status&#x3D;10&amp;status&#x3D;20&#x60;  (optional)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of tournaments created by the user. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call apiUserNameTournamentCreatedCall(String username, Integer status, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/user/{username}/tournament/created"
            .replaceAll("\\{" + "username" + "\\}", localVarApiClient.escapeString(username.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (status != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("status", status));
        }

        final String[] localVarAccepts = {
            "application/x-ndjson"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call apiUserNameTournamentCreatedValidateBeforeCall(String username, Integer status, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'username' is set
        if (username == null) {
            throw new ApiException("Missing the required parameter 'username' when calling apiUserNameTournamentCreated(Async)");
        }
        

        okhttp3.Call localVarCall = apiUserNameTournamentCreatedCall(username, status, _callback);
        return localVarCall;

    }

    /**
     * Get tournaments created by a user
     * Get all tournaments created by a given user.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * @param username The user whose created tournaments to fetch (required)
     * @param status Include tournaments in the given status: \&quot;Created\&quot; (10), \&quot;Started\&quot; (20), \&quot;Finished\&quot; (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: &#x60;?status&#x3D;10&amp;status&#x3D;20&#x60;  (optional)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of tournaments created by the user. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public Object apiUserNameTournamentCreated(String username, Integer status) throws ApiException {
        ApiResponse<Object> localVarResp = apiUserNameTournamentCreatedWithHttpInfo(username, status);
        return localVarResp.getData();
    }

    /**
     * Get tournaments created by a user
     * Get all tournaments created by a given user.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * @param username The user whose created tournaments to fetch (required)
     * @param status Include tournaments in the given status: \&quot;Created\&quot; (10), \&quot;Started\&quot; (20), \&quot;Finished\&quot; (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: &#x60;?status&#x3D;10&amp;status&#x3D;20&#x60;  (optional)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of tournaments created by the user. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<Object> apiUserNameTournamentCreatedWithHttpInfo(String username, Integer status) throws ApiException {
        okhttp3.Call localVarCall = apiUserNameTournamentCreatedValidateBeforeCall(username, status, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Get tournaments created by a user (asynchronously)
     * Get all tournaments created by a given user.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * @param username The user whose created tournaments to fetch (required)
     * @param status Include tournaments in the given status: \&quot;Created\&quot; (10), \&quot;Started\&quot; (20), \&quot;Finished\&quot; (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: &#x60;?status&#x3D;10&amp;status&#x3D;20&#x60;  (optional)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of tournaments created by the user. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call apiUserNameTournamentCreatedAsync(String username, Integer status, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = apiUserNameTournamentCreatedValidateBeforeCall(username, status, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for gamesByTournament
     * @param id The tournament ID. (required)
     * @param player Only games of a particular player. Leave empty to fetch games of all players. (optional)
     * @param moves Include the PGN moves. (optional, default to true)
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
     * @param tags Include the PGN tags. (optional, default to true)
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to false)
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to false)
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to false)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of games of an Arena tournament. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call gamesByTournamentCall(String id, String player, Boolean moves, Boolean pgnInJson, Boolean tags, Boolean clocks, Boolean evals, Boolean opening, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/tournament/{id}/games"
            .replaceAll("\\{" + "id" + "\\}", localVarApiClient.escapeString(id.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (player != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("player", player));
        }

        if (moves != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("moves", moves));
        }

        if (pgnInJson != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("pgnInJson", pgnInJson));
        }

        if (tags != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("tags", tags));
        }

        if (clocks != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("clocks", clocks));
        }

        if (evals != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("evals", evals));
        }

        if (opening != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("opening", opening));
        }

        final String[] localVarAccepts = {
            "application/x-chess-pgn", "application/x-ndjson"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call gamesByTournamentValidateBeforeCall(String id, String player, Boolean moves, Boolean pgnInJson, Boolean tags, Boolean clocks, Boolean evals, Boolean opening, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'id' is set
        if (id == null) {
            throw new ApiException("Missing the required parameter 'id' when calling gamesByTournament(Async)");
        }
        

        okhttp3.Call localVarCall = gamesByTournamentCall(id, player, moves, pgnInJson, tags, clocks, evals, opening, _callback);
        return localVarCall;

    }

    /**
     * Export games of an Arena tournament
     * Download games of a tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first) 
     * @param id The tournament ID. (required)
     * @param player Only games of a particular player. Leave empty to fetch games of all players. (optional)
     * @param moves Include the PGN moves. (optional, default to true)
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
     * @param tags Include the PGN tags. (optional, default to true)
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to false)
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to false)
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to false)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of games of an Arena tournament. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public Object gamesByTournament(String id, String player, Boolean moves, Boolean pgnInJson, Boolean tags, Boolean clocks, Boolean evals, Boolean opening) throws ApiException {
        ApiResponse<Object> localVarResp = gamesByTournamentWithHttpInfo(id, player, moves, pgnInJson, tags, clocks, evals, opening);
        return localVarResp.getData();
    }

    /**
     * Export games of an Arena tournament
     * Download games of a tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first) 
     * @param id The tournament ID. (required)
     * @param player Only games of a particular player. Leave empty to fetch games of all players. (optional)
     * @param moves Include the PGN moves. (optional, default to true)
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
     * @param tags Include the PGN tags. (optional, default to true)
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to false)
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to false)
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to false)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of games of an Arena tournament. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<Object> gamesByTournamentWithHttpInfo(String id, String player, Boolean moves, Boolean pgnInJson, Boolean tags, Boolean clocks, Boolean evals, Boolean opening) throws ApiException {
        okhttp3.Call localVarCall = gamesByTournamentValidateBeforeCall(id, player, moves, pgnInJson, tags, clocks, evals, opening, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Export games of an Arena tournament (asynchronously)
     * Download games of a tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first) 
     * @param id The tournament ID. (required)
     * @param player Only games of a particular player. Leave empty to fetch games of all players. (optional)
     * @param moves Include the PGN moves. (optional, default to true)
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
     * @param tags Include the PGN tags. (optional, default to true)
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to false)
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to false)
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to false)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of games of an Arena tournament. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call gamesByTournamentAsync(String id, String player, Boolean moves, Boolean pgnInJson, Boolean tags, Boolean clocks, Boolean evals, Boolean opening, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = gamesByTournamentValidateBeforeCall(id, player, moves, pgnInJson, tags, clocks, evals, opening, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for resultsByTournament
     * @param id The tournament ID. (required)
     * @param nb Max number of players to fetch (optional)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The results of the Arena tournament. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call resultsByTournamentCall(String id, Integer nb, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/tournament/{id}/results"
            .replaceAll("\\{" + "id" + "\\}", localVarApiClient.escapeString(id.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (nb != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("nb", nb));
        }

        final String[] localVarAccepts = {
            "application/x-ndjson"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call resultsByTournamentValidateBeforeCall(String id, Integer nb, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'id' is set
        if (id == null) {
            throw new ApiException("Missing the required parameter 'id' when calling resultsByTournament(Async)");
        }
        

        okhttp3.Call localVarCall = resultsByTournamentCall(id, nb, _callback);
        return localVarCall;

    }

    /**
     * Get results of an Arena tournament
     * Players of an Arena tournament, with their score and performance, sorted by rank (best first).  **Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON)**, i.e. one JSON object per line.  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 
     * @param id The tournament ID. (required)
     * @param nb Max number of players to fetch (optional)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The results of the Arena tournament. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public Object resultsByTournament(String id, Integer nb) throws ApiException {
        ApiResponse<Object> localVarResp = resultsByTournamentWithHttpInfo(id, nb);
        return localVarResp.getData();
    }

    /**
     * Get results of an Arena tournament
     * Players of an Arena tournament, with their score and performance, sorted by rank (best first).  **Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON)**, i.e. one JSON object per line.  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 
     * @param id The tournament ID. (required)
     * @param nb Max number of players to fetch (optional)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The results of the Arena tournament. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<Object> resultsByTournamentWithHttpInfo(String id, Integer nb) throws ApiException {
        okhttp3.Call localVarCall = resultsByTournamentValidateBeforeCall(id, nb, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Get results of an Arena tournament (asynchronously)
     * Players of an Arena tournament, with their score and performance, sorted by rank (best first).  **Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON)**, i.e. one JSON object per line.  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 
     * @param id The tournament ID. (required)
     * @param nb Max number of players to fetch (optional)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The results of the Arena tournament. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call resultsByTournamentAsync(String id, Integer nb, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = resultsByTournamentValidateBeforeCall(id, nb, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for teamsByTournament
     * @param id The tournament ID. (required)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of teams of a team battle tournament, with their respective top players. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call teamsByTournamentCall(String id, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/tournament/{id}/teams"
            .replaceAll("\\{" + "id" + "\\}", localVarApiClient.escapeString(id.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call teamsByTournamentValidateBeforeCall(String id, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'id' is set
        if (id == null) {
            throw new ApiException("Missing the required parameter 'id' when calling teamsByTournament(Async)");
        }
        

        okhttp3.Call localVarCall = teamsByTournamentCall(id, _callback);
        return localVarCall;

    }

    /**
     * Get team standing of a team battle
     * Teams of a team battle tournament, with top players, sorted by rank (best first). 
     * @param id The tournament ID. (required)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of teams of a team battle tournament, with their respective top players. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public Object teamsByTournament(String id) throws ApiException {
        ApiResponse<Object> localVarResp = teamsByTournamentWithHttpInfo(id);
        return localVarResp.getData();
    }

    /**
     * Get team standing of a team battle
     * Teams of a team battle tournament, with top players, sorted by rank (best first). 
     * @param id The tournament ID. (required)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of teams of a team battle tournament, with their respective top players. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<Object> teamsByTournamentWithHttpInfo(String id) throws ApiException {
        okhttp3.Call localVarCall = teamsByTournamentValidateBeforeCall(id, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Get team standing of a team battle (asynchronously)
     * Teams of a team battle tournament, with top players, sorted by rank (best first). 
     * @param id The tournament ID. (required)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of teams of a team battle tournament, with their respective top players. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call teamsByTournamentAsync(String id, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = teamsByTournamentValidateBeforeCall(id, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for tournament
     * @param id The tournament ID. (required)
     * @param page Specify which page of player standings to view. (optional, default to 1)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The information of the Arena tournament. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call tournamentCall(String id, BigDecimal page, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/tournament/{id}"
            .replaceAll("\\{" + "id" + "\\}", localVarApiClient.escapeString(id.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (page != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("page", page));
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call tournamentValidateBeforeCall(String id, BigDecimal page, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'id' is set
        if (id == null) {
            throw new ApiException("Missing the required parameter 'id' when calling tournament(Async)");
        }
        

        okhttp3.Call localVarCall = tournamentCall(id, page, _callback);
        return localVarCall;

    }

    /**
     * Get info about an Arena tournament
     * Get detailed info about recently finished, current, or upcoming tournament&#39;s duels, player standings, and other info. 
     * @param id The tournament ID. (required)
     * @param page Specify which page of player standings to view. (optional, default to 1)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The information of the Arena tournament. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public Object tournament(String id, BigDecimal page) throws ApiException {
        ApiResponse<Object> localVarResp = tournamentWithHttpInfo(id, page);
        return localVarResp.getData();
    }

    /**
     * Get info about an Arena tournament
     * Get detailed info about recently finished, current, or upcoming tournament&#39;s duels, player standings, and other info. 
     * @param id The tournament ID. (required)
     * @param page Specify which page of player standings to view. (optional, default to 1)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The information of the Arena tournament. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<Object> tournamentWithHttpInfo(String id, BigDecimal page) throws ApiException {
        okhttp3.Call localVarCall = tournamentValidateBeforeCall(id, page, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Get info about an Arena tournament (asynchronously)
     * Get detailed info about recently finished, current, or upcoming tournament&#39;s duels, player standings, and other info. 
     * @param id The tournament ID. (required)
     * @param page Specify which page of player standings to view. (optional, default to 1)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The information of the Arena tournament. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call tournamentAsync(String id, BigDecimal page, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = tournamentValidateBeforeCall(id, page, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
}
