/*
 * Lichess.org API reference
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */


package org.openapitools.client.api;

import org.openapitools.client.ApiCallback;
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.ApiResponse;
import org.openapitools.client.Configuration;
import org.openapitools.client.Pair;
import org.openapitools.client.ProgressRequestBody;
import org.openapitools.client.ProgressResponseBody;

import com.google.gson.reflect.TypeToken;

import java.io.IOException;


import org.openapitools.client.model.Error;
import org.openapitools.client.model.Ok;

import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class BroadcastsApi {
    private ApiClient localVarApiClient;

    public BroadcastsApi() {
        this(Configuration.getDefaultApiClient());
    }

    public BroadcastsApi(ApiClient apiClient) {
        this.localVarApiClient = apiClient;
    }

    public ApiClient getApiClient() {
        return localVarApiClient;
    }

    public void setApiClient(ApiClient apiClient) {
        this.localVarApiClient = apiClient;
    }

    /**
     * Build call for broadcastAllRoundsPgn
     * @param broadcastTournamentId The broadcast tournament ID (8 characters). (required)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the broadcast. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastAllRoundsPgnCall(String broadcastTournamentId, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/broadcast/{broadcastTournamentId}.pgn"
            .replaceAll("\\{" + "broadcastTournamentId" + "\\}", localVarApiClient.escapeString(broadcastTournamentId.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/x-chess-pgn"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call broadcastAllRoundsPgnValidateBeforeCall(String broadcastTournamentId, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'broadcastTournamentId' is set
        if (broadcastTournamentId == null) {
            throw new ApiException("Missing the required parameter 'broadcastTournamentId' when calling broadcastAllRoundsPgn(Async)");
        }
        

        okhttp3.Call localVarCall = broadcastAllRoundsPgnCall(broadcastTournamentId, _callback);
        return localVarCall;

    }

    /**
     * Export all rounds as PGN
     * Download all games of all rounds of a broadcast in PGN format.  You may want to [download only the games of a single round](#operation/broadcastRoundPgn) instead. 
     * @param broadcastTournamentId The broadcast tournament ID (8 characters). (required)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the broadcast. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public Object broadcastAllRoundsPgn(String broadcastTournamentId) throws ApiException {
        ApiResponse<Object> localVarResp = broadcastAllRoundsPgnWithHttpInfo(broadcastTournamentId);
        return localVarResp.getData();
    }

    /**
     * Export all rounds as PGN
     * Download all games of all rounds of a broadcast in PGN format.  You may want to [download only the games of a single round](#operation/broadcastRoundPgn) instead. 
     * @param broadcastTournamentId The broadcast tournament ID (8 characters). (required)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the broadcast. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<Object> broadcastAllRoundsPgnWithHttpInfo(String broadcastTournamentId) throws ApiException {
        okhttp3.Call localVarCall = broadcastAllRoundsPgnValidateBeforeCall(broadcastTournamentId, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Export all rounds as PGN (asynchronously)
     * Download all games of all rounds of a broadcast in PGN format.  You may want to [download only the games of a single round](#operation/broadcastRoundPgn) instead. 
     * @param broadcastTournamentId The broadcast tournament ID (8 characters). (required)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the broadcast. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastAllRoundsPgnAsync(String broadcastTournamentId, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = broadcastAllRoundsPgnValidateBeforeCall(broadcastTournamentId, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for broadcastIndex
     * @param nb Max number of broadcasts to fetch (optional, default to 20)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of official broadcasts. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastIndexCall(Integer nb, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/broadcast";

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (nb != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("nb", nb));
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call broadcastIndexValidateBeforeCall(Integer nb, final ApiCallback _callback) throws ApiException {
        

        okhttp3.Call localVarCall = broadcastIndexCall(nb, _callback);
        return localVarCall;

    }

    /**
     * Get official broadcasts
     * Get all incoming, ongoing, and finished official broadcasts. The broadcasts are sorted by start date, most recent first.  Broadcasts are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * @param nb Max number of broadcasts to fetch (optional, default to 20)
     * @return List&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of official broadcasts. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public List<Object> broadcastIndex(Integer nb) throws ApiException {
        ApiResponse<List<Object>> localVarResp = broadcastIndexWithHttpInfo(nb);
        return localVarResp.getData();
    }

    /**
     * Get official broadcasts
     * Get all incoming, ongoing, and finished official broadcasts. The broadcasts are sorted by start date, most recent first.  Broadcasts are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * @param nb Max number of broadcasts to fetch (optional, default to 20)
     * @return ApiResponse&lt;List&lt;Object&gt;&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of official broadcasts. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<List<Object>> broadcastIndexWithHttpInfo(Integer nb) throws ApiException {
        okhttp3.Call localVarCall = broadcastIndexValidateBeforeCall(nb, null);
        Type localVarReturnType = new TypeToken<List<Object>>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Get official broadcasts (asynchronously)
     * Get all incoming, ongoing, and finished official broadcasts. The broadcasts are sorted by start date, most recent first.  Broadcasts are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * @param nb Max number of broadcasts to fetch (optional, default to 20)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of official broadcasts. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastIndexAsync(Integer nb, final ApiCallback<List<Object>> _callback) throws ApiException {

        okhttp3.Call localVarCall = broadcastIndexValidateBeforeCall(nb, _callback);
        Type localVarReturnType = new TypeToken<List<Object>>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for broadcastPush
     * @param broadcastRoundId The broadcast round ID (8 characters). (required)
     * @param body The PGN. It can contain up to 64 games, separated by a double new line. (required)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast was successfully updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastPushCall(String broadcastRoundId, String body, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = body;

        // create path and map variables
        String localVarPath = "/broadcast/round/{broadcastRoundId}/push"
            .replaceAll("\\{" + "broadcastRoundId" + "\\}", localVarApiClient.escapeString(broadcastRoundId.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            "text/plain"
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "POST", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call broadcastPushValidateBeforeCall(String broadcastRoundId, String body, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'broadcastRoundId' is set
        if (broadcastRoundId == null) {
            throw new ApiException("Missing the required parameter 'broadcastRoundId' when calling broadcastPush(Async)");
        }
        
        // verify the required parameter 'body' is set
        if (body == null) {
            throw new ApiException("Missing the required parameter 'body' when calling broadcastPush(Async)");
        }
        

        okhttp3.Call localVarCall = broadcastPushCall(broadcastRoundId, body, _callback);
        return localVarCall;

    }

    /**
     * Push PGN to your broadcast round
     * Update your broadcast with new PGN. Only for broadcast without a source URL. 
     * @param broadcastRoundId The broadcast round ID (8 characters). (required)
     * @param body The PGN. It can contain up to 64 games, separated by a double new line. (required)
     * @return List&lt;Ok&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast was successfully updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public List<Ok> broadcastPush(String broadcastRoundId, String body) throws ApiException {
        ApiResponse<List<Ok>> localVarResp = broadcastPushWithHttpInfo(broadcastRoundId, body);
        return localVarResp.getData();
    }

    /**
     * Push PGN to your broadcast round
     * Update your broadcast with new PGN. Only for broadcast without a source URL. 
     * @param broadcastRoundId The broadcast round ID (8 characters). (required)
     * @param body The PGN. It can contain up to 64 games, separated by a double new line. (required)
     * @return ApiResponse&lt;List&lt;Ok&gt;&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast was successfully updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<List<Ok>> broadcastPushWithHttpInfo(String broadcastRoundId, String body) throws ApiException {
        okhttp3.Call localVarCall = broadcastPushValidateBeforeCall(broadcastRoundId, body, null);
        Type localVarReturnType = new TypeToken<List<Ok>>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Push PGN to your broadcast round (asynchronously)
     * Update your broadcast with new PGN. Only for broadcast without a source URL. 
     * @param broadcastRoundId The broadcast round ID (8 characters). (required)
     * @param body The PGN. It can contain up to 64 games, separated by a double new line. (required)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast was successfully updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastPushAsync(String broadcastRoundId, String body, final ApiCallback<List<Ok>> _callback) throws ApiException {

        okhttp3.Call localVarCall = broadcastPushValidateBeforeCall(broadcastRoundId, body, _callback);
        Type localVarReturnType = new TypeToken<List<Ok>>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for broadcastRoundCreate
     * @param broadcastTournamentId The broadcast tournament ID (8 characters). (required)
     * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 1&#x60;  (required)
     * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush).  (optional)
     * @param startsAt Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: &#x60;1356998400070&#x60;  (optional)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast round was successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the broadcast failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastRoundCreateCall(String broadcastTournamentId, String name, String syncUrl, Integer startsAt, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/broadcast/{broadcastTournamentId}/new"
            .replaceAll("\\{" + "broadcastTournamentId" + "\\}", localVarApiClient.escapeString(broadcastTournamentId.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (name != null) {
            localVarFormParams.put("name", name);
        }

        if (syncUrl != null) {
            localVarFormParams.put("syncUrl", syncUrl);
        }

        if (startsAt != null) {
            localVarFormParams.put("startsAt", startsAt);
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            "application/x-www-form-urlencoded"
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "POST", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call broadcastRoundCreateValidateBeforeCall(String broadcastTournamentId, String name, String syncUrl, Integer startsAt, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'broadcastTournamentId' is set
        if (broadcastTournamentId == null) {
            throw new ApiException("Missing the required parameter 'broadcastTournamentId' when calling broadcastRoundCreate(Async)");
        }
        
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling broadcastRoundCreate(Async)");
        }
        

        okhttp3.Call localVarCall = broadcastRoundCreateCall(broadcastTournamentId, name, syncUrl, startsAt, _callback);
        return localVarCall;

    }

    /**
     * Create a broadcast round
     * Create a new broadcast round to relay external games. This endpoint accepts the same form data as the web form. 
     * @param broadcastTournamentId The broadcast tournament ID (8 characters). (required)
     * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 1&#x60;  (required)
     * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush).  (optional)
     * @param startsAt Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: &#x60;1356998400070&#x60;  (optional)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast round was successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the broadcast failed. </td><td>  -  </td></tr>
     </table>
     */
    public Object broadcastRoundCreate(String broadcastTournamentId, String name, String syncUrl, Integer startsAt) throws ApiException {
        ApiResponse<Object> localVarResp = broadcastRoundCreateWithHttpInfo(broadcastTournamentId, name, syncUrl, startsAt);
        return localVarResp.getData();
    }

    /**
     * Create a broadcast round
     * Create a new broadcast round to relay external games. This endpoint accepts the same form data as the web form. 
     * @param broadcastTournamentId The broadcast tournament ID (8 characters). (required)
     * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 1&#x60;  (required)
     * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush).  (optional)
     * @param startsAt Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: &#x60;1356998400070&#x60;  (optional)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast round was successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the broadcast failed. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<Object> broadcastRoundCreateWithHttpInfo(String broadcastTournamentId, String name, String syncUrl, Integer startsAt) throws ApiException {
        okhttp3.Call localVarCall = broadcastRoundCreateValidateBeforeCall(broadcastTournamentId, name, syncUrl, startsAt, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Create a broadcast round (asynchronously)
     * Create a new broadcast round to relay external games. This endpoint accepts the same form data as the web form. 
     * @param broadcastTournamentId The broadcast tournament ID (8 characters). (required)
     * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 1&#x60;  (required)
     * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush).  (optional)
     * @param startsAt Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: &#x60;1356998400070&#x60;  (optional)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast round was successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the broadcast failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastRoundCreateAsync(String broadcastTournamentId, String name, String syncUrl, Integer startsAt, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = broadcastRoundCreateValidateBeforeCall(broadcastTournamentId, name, syncUrl, startsAt, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for broadcastRoundGet
     * @param broadcastTournamentSlug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. (required)
     * @param broadcastRoundSlug The broadcast round slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. (required)
     * @param broadcastRoundId The broadcast Round ID (8 characters). (required)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The information about the broadcast round. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastRoundGetCall(String broadcastTournamentSlug, String broadcastRoundSlug, String broadcastRoundId, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/broadcast/{broadcastTournamentSlug}/{broadcastRoundSlug}/{broadcastRoundId}"
            .replaceAll("\\{" + "broadcastTournamentSlug" + "\\}", localVarApiClient.escapeString(broadcastTournamentSlug.toString()))
            .replaceAll("\\{" + "broadcastRoundSlug" + "\\}", localVarApiClient.escapeString(broadcastRoundSlug.toString()))
            .replaceAll("\\{" + "broadcastRoundId" + "\\}", localVarApiClient.escapeString(broadcastRoundId.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call broadcastRoundGetValidateBeforeCall(String broadcastTournamentSlug, String broadcastRoundSlug, String broadcastRoundId, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'broadcastTournamentSlug' is set
        if (broadcastTournamentSlug == null) {
            throw new ApiException("Missing the required parameter 'broadcastTournamentSlug' when calling broadcastRoundGet(Async)");
        }
        
        // verify the required parameter 'broadcastRoundSlug' is set
        if (broadcastRoundSlug == null) {
            throw new ApiException("Missing the required parameter 'broadcastRoundSlug' when calling broadcastRoundGet(Async)");
        }
        
        // verify the required parameter 'broadcastRoundId' is set
        if (broadcastRoundId == null) {
            throw new ApiException("Missing the required parameter 'broadcastRoundId' when calling broadcastRoundGet(Async)");
        }
        

        okhttp3.Call localVarCall = broadcastRoundGetCall(broadcastTournamentSlug, broadcastRoundSlug, broadcastRoundId, _callback);
        return localVarCall;

    }

    /**
     * Get your broadcast round
     * Get information about a broadcast round that you created. 
     * @param broadcastTournamentSlug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. (required)
     * @param broadcastRoundSlug The broadcast round slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. (required)
     * @param broadcastRoundId The broadcast Round ID (8 characters). (required)
     * @return List&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The information about the broadcast round. </td><td>  -  </td></tr>
     </table>
     */
    public List<Object> broadcastRoundGet(String broadcastTournamentSlug, String broadcastRoundSlug, String broadcastRoundId) throws ApiException {
        ApiResponse<List<Object>> localVarResp = broadcastRoundGetWithHttpInfo(broadcastTournamentSlug, broadcastRoundSlug, broadcastRoundId);
        return localVarResp.getData();
    }

    /**
     * Get your broadcast round
     * Get information about a broadcast round that you created. 
     * @param broadcastTournamentSlug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. (required)
     * @param broadcastRoundSlug The broadcast round slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. (required)
     * @param broadcastRoundId The broadcast Round ID (8 characters). (required)
     * @return ApiResponse&lt;List&lt;Object&gt;&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The information about the broadcast round. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<List<Object>> broadcastRoundGetWithHttpInfo(String broadcastTournamentSlug, String broadcastRoundSlug, String broadcastRoundId) throws ApiException {
        okhttp3.Call localVarCall = broadcastRoundGetValidateBeforeCall(broadcastTournamentSlug, broadcastRoundSlug, broadcastRoundId, null);
        Type localVarReturnType = new TypeToken<List<Object>>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Get your broadcast round (asynchronously)
     * Get information about a broadcast round that you created. 
     * @param broadcastTournamentSlug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. (required)
     * @param broadcastRoundSlug The broadcast round slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. (required)
     * @param broadcastRoundId The broadcast Round ID (8 characters). (required)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The information about the broadcast round. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastRoundGetAsync(String broadcastTournamentSlug, String broadcastRoundSlug, String broadcastRoundId, final ApiCallback<List<Object>> _callback) throws ApiException {

        okhttp3.Call localVarCall = broadcastRoundGetValidateBeforeCall(broadcastTournamentSlug, broadcastRoundSlug, broadcastRoundId, _callback);
        Type localVarReturnType = new TypeToken<List<Object>>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for broadcastRoundPgn
     * @param broadcastRoundId The round ID (8 characters). (required)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the round. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastRoundPgnCall(String broadcastRoundId, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/broadcast/round/{broadcastRoundId}.pgn"
            .replaceAll("\\{" + "broadcastRoundId" + "\\}", localVarApiClient.escapeString(broadcastRoundId.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/x-chess-pgn"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call broadcastRoundPgnValidateBeforeCall(String broadcastRoundId, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'broadcastRoundId' is set
        if (broadcastRoundId == null) {
            throw new ApiException("Missing the required parameter 'broadcastRoundId' when calling broadcastRoundPgn(Async)");
        }
        

        okhttp3.Call localVarCall = broadcastRoundPgnCall(broadcastRoundId, _callback);
        return localVarCall;

    }

    /**
     * Export one round as PGN
     * Download all games of a single round of a broadcast tournament in PGN format.  You *could* poll this endpoint to get updates about a tournament, but it would be slow, and very inneficient.  Instead, consider [streaming the tournament](#operation/broadcastStreamRoundPgn) to get a new PGN every time a game is updated, in real-time. 
     * @param broadcastRoundId The round ID (8 characters). (required)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the round. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public Object broadcastRoundPgn(String broadcastRoundId) throws ApiException {
        ApiResponse<Object> localVarResp = broadcastRoundPgnWithHttpInfo(broadcastRoundId);
        return localVarResp.getData();
    }

    /**
     * Export one round as PGN
     * Download all games of a single round of a broadcast tournament in PGN format.  You *could* poll this endpoint to get updates about a tournament, but it would be slow, and very inneficient.  Instead, consider [streaming the tournament](#operation/broadcastStreamRoundPgn) to get a new PGN every time a game is updated, in real-time. 
     * @param broadcastRoundId The round ID (8 characters). (required)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the round. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<Object> broadcastRoundPgnWithHttpInfo(String broadcastRoundId) throws ApiException {
        okhttp3.Call localVarCall = broadcastRoundPgnValidateBeforeCall(broadcastRoundId, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Export one round as PGN (asynchronously)
     * Download all games of a single round of a broadcast tournament in PGN format.  You *could* poll this endpoint to get updates about a tournament, but it would be slow, and very inneficient.  Instead, consider [streaming the tournament](#operation/broadcastStreamRoundPgn) to get a new PGN every time a game is updated, in real-time. 
     * @param broadcastRoundId The round ID (8 characters). (required)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the round. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastRoundPgnAsync(String broadcastRoundId, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = broadcastRoundPgnValidateBeforeCall(broadcastRoundId, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for broadcastRoundUpdate
     * @param broadcastRoundId The broadcast round ID (8 characters). (required)
     * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 10&#x60;  (required)
     * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  (optional)
     * @param startsAt Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: &#x60;1356998400070&#x60;  (optional)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast round was successfully edited. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The edition of the broadcast tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastRoundUpdateCall(String broadcastRoundId, String name, String syncUrl, Integer startsAt, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/broadcast/round/{broadcastRoundId}/edit"
            .replaceAll("\\{" + "broadcastRoundId" + "\\}", localVarApiClient.escapeString(broadcastRoundId.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (name != null) {
            localVarFormParams.put("name", name);
        }

        if (syncUrl != null) {
            localVarFormParams.put("syncUrl", syncUrl);
        }

        if (startsAt != null) {
            localVarFormParams.put("startsAt", startsAt);
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            "application/x-www-form-urlencoded"
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "POST", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call broadcastRoundUpdateValidateBeforeCall(String broadcastRoundId, String name, String syncUrl, Integer startsAt, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'broadcastRoundId' is set
        if (broadcastRoundId == null) {
            throw new ApiException("Missing the required parameter 'broadcastRoundId' when calling broadcastRoundUpdate(Async)");
        }
        
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling broadcastRoundUpdate(Async)");
        }
        

        okhttp3.Call localVarCall = broadcastRoundUpdateCall(broadcastRoundId, name, syncUrl, startsAt, _callback);
        return localVarCall;

    }

    /**
     * Update your broadcast round
     * Update information about a broadcast round that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. For instance, if you omit &#x60;startDate&#x60;, then any pre-existing start date will be removed. 
     * @param broadcastRoundId The broadcast round ID (8 characters). (required)
     * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 10&#x60;  (required)
     * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  (optional)
     * @param startsAt Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: &#x60;1356998400070&#x60;  (optional)
     * @return Ok
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast round was successfully edited. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The edition of the broadcast tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public Ok broadcastRoundUpdate(String broadcastRoundId, String name, String syncUrl, Integer startsAt) throws ApiException {
        ApiResponse<Ok> localVarResp = broadcastRoundUpdateWithHttpInfo(broadcastRoundId, name, syncUrl, startsAt);
        return localVarResp.getData();
    }

    /**
     * Update your broadcast round
     * Update information about a broadcast round that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. For instance, if you omit &#x60;startDate&#x60;, then any pre-existing start date will be removed. 
     * @param broadcastRoundId The broadcast round ID (8 characters). (required)
     * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 10&#x60;  (required)
     * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  (optional)
     * @param startsAt Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: &#x60;1356998400070&#x60;  (optional)
     * @return ApiResponse&lt;Ok&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast round was successfully edited. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The edition of the broadcast tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<Ok> broadcastRoundUpdateWithHttpInfo(String broadcastRoundId, String name, String syncUrl, Integer startsAt) throws ApiException {
        okhttp3.Call localVarCall = broadcastRoundUpdateValidateBeforeCall(broadcastRoundId, name, syncUrl, startsAt, null);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Update your broadcast round (asynchronously)
     * Update information about a broadcast round that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. For instance, if you omit &#x60;startDate&#x60;, then any pre-existing start date will be removed. 
     * @param broadcastRoundId The broadcast round ID (8 characters). (required)
     * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 10&#x60;  (required)
     * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  (optional)
     * @param startsAt Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: &#x60;1356998400070&#x60;  (optional)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast round was successfully edited. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The edition of the broadcast tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastRoundUpdateAsync(String broadcastRoundId, String name, String syncUrl, Integer startsAt, final ApiCallback<Ok> _callback) throws ApiException {

        okhttp3.Call localVarCall = broadcastRoundUpdateValidateBeforeCall(broadcastRoundId, name, syncUrl, startsAt, _callback);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for broadcastStreamRoundPgn
     * @param broadcastRoundId The broadcast round ID (8 characters). (required)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the tournament games, then the PGNs of games as they are updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastStreamRoundPgnCall(String broadcastRoundId, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/stream/broadcast/round/{broadcastRoundId}.pgn"
            .replaceAll("\\{" + "broadcastRoundId" + "\\}", localVarApiClient.escapeString(broadcastRoundId.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/x-chess-pgn"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call broadcastStreamRoundPgnValidateBeforeCall(String broadcastRoundId, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'broadcastRoundId' is set
        if (broadcastRoundId == null) {
            throw new ApiException("Missing the required parameter 'broadcastRoundId' when calling broadcastStreamRoundPgn(Async)");
        }
        

        okhttp3.Call localVarCall = broadcastStreamRoundPgnCall(broadcastRoundId, _callback);
        return localVarCall;

    }

    /**
     * Stream an ongoing broadcast tournament as PGN
     * This streaming endpoint first sends all games of a broadcast tournament in PGN format.  Then, it waits for new moves to be played. As soon as it happens, the entire PGN of the game is sent to the stream.  The stream will also send PGNs when games are added to the tournament.  This is the best way to get updates about an ongoing tournament. Streaming means no polling, and no pollings means no latency, and minimum impact on the server. 
     * @param broadcastRoundId The broadcast round ID (8 characters). (required)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the tournament games, then the PGNs of games as they are updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public Object broadcastStreamRoundPgn(String broadcastRoundId) throws ApiException {
        ApiResponse<Object> localVarResp = broadcastStreamRoundPgnWithHttpInfo(broadcastRoundId);
        return localVarResp.getData();
    }

    /**
     * Stream an ongoing broadcast tournament as PGN
     * This streaming endpoint first sends all games of a broadcast tournament in PGN format.  Then, it waits for new moves to be played. As soon as it happens, the entire PGN of the game is sent to the stream.  The stream will also send PGNs when games are added to the tournament.  This is the best way to get updates about an ongoing tournament. Streaming means no polling, and no pollings means no latency, and minimum impact on the server. 
     * @param broadcastRoundId The broadcast round ID (8 characters). (required)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the tournament games, then the PGNs of games as they are updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<Object> broadcastStreamRoundPgnWithHttpInfo(String broadcastRoundId) throws ApiException {
        okhttp3.Call localVarCall = broadcastStreamRoundPgnValidateBeforeCall(broadcastRoundId, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Stream an ongoing broadcast tournament as PGN (asynchronously)
     * This streaming endpoint first sends all games of a broadcast tournament in PGN format.  Then, it waits for new moves to be played. As soon as it happens, the entire PGN of the game is sent to the stream.  The stream will also send PGNs when games are added to the tournament.  This is the best way to get updates about an ongoing tournament. Streaming means no polling, and no pollings means no latency, and minimum impact on the server. 
     * @param broadcastRoundId The broadcast round ID (8 characters). (required)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the tournament games, then the PGNs of games as they are updated. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastStreamRoundPgnAsync(String broadcastRoundId, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = broadcastStreamRoundPgnValidateBeforeCall(broadcastRoundId, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for broadcastTourCreate
     * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  (required)
     * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  (required)
     * @param markup Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters. (optional)
     * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast tournament was successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the broadcast tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastTourCreateCall(String name, String description, String markup, Boolean official, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/broadcast/new";

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (name != null) {
            localVarFormParams.put("name", name);
        }

        if (description != null) {
            localVarFormParams.put("description", description);
        }

        if (markup != null) {
            localVarFormParams.put("markup", markup);
        }

        if (official != null) {
            localVarFormParams.put("official", official);
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            "application/x-www-form-urlencoded"
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "POST", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call broadcastTourCreateValidateBeforeCall(String name, String description, String markup, Boolean official, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling broadcastTourCreate(Async)");
        }
        
        // verify the required parameter 'description' is set
        if (description == null) {
            throw new ApiException("Missing the required parameter 'description' when calling broadcastTourCreate(Async)");
        }
        

        okhttp3.Call localVarCall = broadcastTourCreateCall(name, description, markup, official, _callback);
        return localVarCall;

    }

    /**
     * Create a broadcast tournament
     * Create a new broadcast tournament to relay external games. This endpoint accepts the same form data as the [web form](https://lichess.org/broadcast/new). 
     * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  (required)
     * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  (required)
     * @param markup Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters. (optional)
     * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast tournament was successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the broadcast tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public Object broadcastTourCreate(String name, String description, String markup, Boolean official) throws ApiException {
        ApiResponse<Object> localVarResp = broadcastTourCreateWithHttpInfo(name, description, markup, official);
        return localVarResp.getData();
    }

    /**
     * Create a broadcast tournament
     * Create a new broadcast tournament to relay external games. This endpoint accepts the same form data as the [web form](https://lichess.org/broadcast/new). 
     * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  (required)
     * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  (required)
     * @param markup Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters. (optional)
     * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast tournament was successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the broadcast tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<Object> broadcastTourCreateWithHttpInfo(String name, String description, String markup, Boolean official) throws ApiException {
        okhttp3.Call localVarCall = broadcastTourCreateValidateBeforeCall(name, description, markup, official, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Create a broadcast tournament (asynchronously)
     * Create a new broadcast tournament to relay external games. This endpoint accepts the same form data as the [web form](https://lichess.org/broadcast/new). 
     * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  (required)
     * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  (required)
     * @param markup Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters. (optional)
     * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast tournament was successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the broadcast tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastTourCreateAsync(String name, String description, String markup, Boolean official, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = broadcastTourCreateValidateBeforeCall(name, description, markup, official, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for broadcastTourGet
     * @param slug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastTournamentId&#x60; is actually used. (required)
     * @param broadcastTournamentId The broadcast tournament ID (8 characters). (required)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The information about the broadcast tournament. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastTourGetCall(String slug, String broadcastTournamentId, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/broadcast/{slug}/{broadcastTournamentId}"
            .replaceAll("\\{" + "slug" + "\\}", localVarApiClient.escapeString(slug.toString()))
            .replaceAll("\\{" + "broadcastTournamentId" + "\\}", localVarApiClient.escapeString(broadcastTournamentId.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call broadcastTourGetValidateBeforeCall(String slug, String broadcastTournamentId, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'slug' is set
        if (slug == null) {
            throw new ApiException("Missing the required parameter 'slug' when calling broadcastTourGet(Async)");
        }
        
        // verify the required parameter 'broadcastTournamentId' is set
        if (broadcastTournamentId == null) {
            throw new ApiException("Missing the required parameter 'broadcastTournamentId' when calling broadcastTourGet(Async)");
        }
        

        okhttp3.Call localVarCall = broadcastTourGetCall(slug, broadcastTournamentId, _callback);
        return localVarCall;

    }

    /**
     * Get your broadcast tournament
     * Get information about a broadcast tournament that you created. 
     * @param slug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastTournamentId&#x60; is actually used. (required)
     * @param broadcastTournamentId The broadcast tournament ID (8 characters). (required)
     * @return List&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The information about the broadcast tournament. </td><td>  -  </td></tr>
     </table>
     */
    public List<Object> broadcastTourGet(String slug, String broadcastTournamentId) throws ApiException {
        ApiResponse<List<Object>> localVarResp = broadcastTourGetWithHttpInfo(slug, broadcastTournamentId);
        return localVarResp.getData();
    }

    /**
     * Get your broadcast tournament
     * Get information about a broadcast tournament that you created. 
     * @param slug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastTournamentId&#x60; is actually used. (required)
     * @param broadcastTournamentId The broadcast tournament ID (8 characters). (required)
     * @return ApiResponse&lt;List&lt;Object&gt;&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The information about the broadcast tournament. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<List<Object>> broadcastTourGetWithHttpInfo(String slug, String broadcastTournamentId) throws ApiException {
        okhttp3.Call localVarCall = broadcastTourGetValidateBeforeCall(slug, broadcastTournamentId, null);
        Type localVarReturnType = new TypeToken<List<Object>>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Get your broadcast tournament (asynchronously)
     * Get information about a broadcast tournament that you created. 
     * @param slug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastTournamentId&#x60; is actually used. (required)
     * @param broadcastTournamentId The broadcast tournament ID (8 characters). (required)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The information about the broadcast tournament. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastTourGetAsync(String slug, String broadcastTournamentId, final ApiCallback<List<Object>> _callback) throws ApiException {

        okhttp3.Call localVarCall = broadcastTourGetValidateBeforeCall(slug, broadcastTournamentId, _callback);
        Type localVarReturnType = new TypeToken<List<Object>>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for broadcastTourUpdate
     * @param broadcastTournamentId The broadcast ID (8 characters). (required)
     * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  (required)
     * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  (required)
     * @param markup Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters. (optional)
     * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast tournament was successfully edited. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The edition of the broadcast tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastTourUpdateCall(String broadcastTournamentId, String name, String description, String markup, Boolean official, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/broadcast/{broadcastTournamentId}/edit"
            .replaceAll("\\{" + "broadcastTournamentId" + "\\}", localVarApiClient.escapeString(broadcastTournamentId.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (name != null) {
            localVarFormParams.put("name", name);
        }

        if (description != null) {
            localVarFormParams.put("description", description);
        }

        if (markup != null) {
            localVarFormParams.put("markup", markup);
        }

        if (official != null) {
            localVarFormParams.put("official", official);
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            "application/x-www-form-urlencoded"
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "POST", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call broadcastTourUpdateValidateBeforeCall(String broadcastTournamentId, String name, String description, String markup, Boolean official, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'broadcastTournamentId' is set
        if (broadcastTournamentId == null) {
            throw new ApiException("Missing the required parameter 'broadcastTournamentId' when calling broadcastTourUpdate(Async)");
        }
        
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling broadcastTourUpdate(Async)");
        }
        
        // verify the required parameter 'description' is set
        if (description == null) {
            throw new ApiException("Missing the required parameter 'description' when calling broadcastTourUpdate(Async)");
        }
        

        okhttp3.Call localVarCall = broadcastTourUpdateCall(broadcastTournamentId, name, description, markup, official, _callback);
        return localVarCall;

    }

    /**
     * Update your broadcast tournament
     * Update information about a broadcast tournament that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. 
     * @param broadcastTournamentId The broadcast ID (8 characters). (required)
     * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  (required)
     * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  (required)
     * @param markup Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters. (optional)
     * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
     * @return Ok
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast tournament was successfully edited. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The edition of the broadcast tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public Ok broadcastTourUpdate(String broadcastTournamentId, String name, String description, String markup, Boolean official) throws ApiException {
        ApiResponse<Ok> localVarResp = broadcastTourUpdateWithHttpInfo(broadcastTournamentId, name, description, markup, official);
        return localVarResp.getData();
    }

    /**
     * Update your broadcast tournament
     * Update information about a broadcast tournament that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. 
     * @param broadcastTournamentId The broadcast ID (8 characters). (required)
     * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  (required)
     * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  (required)
     * @param markup Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters. (optional)
     * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
     * @return ApiResponse&lt;Ok&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast tournament was successfully edited. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The edition of the broadcast tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<Ok> broadcastTourUpdateWithHttpInfo(String broadcastTournamentId, String name, String description, String markup, Boolean official) throws ApiException {
        okhttp3.Call localVarCall = broadcastTourUpdateValidateBeforeCall(broadcastTournamentId, name, description, markup, official, null);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Update your broadcast tournament (asynchronously)
     * Update information about a broadcast tournament that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. 
     * @param broadcastTournamentId The broadcast ID (8 characters). (required)
     * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  (required)
     * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  (required)
     * @param markup Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters. (optional)
     * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The broadcast tournament was successfully edited. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The edition of the broadcast tournament failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call broadcastTourUpdateAsync(String broadcastTournamentId, String name, String description, String markup, Boolean official, final ApiCallback<Ok> _callback) throws ApiException {

        okhttp3.Call localVarCall = broadcastTourUpdateValidateBeforeCall(broadcastTournamentId, name, description, markup, official, _callback);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
}
