/*
 * Lichess.org API reference
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */


package org.openapitools.client.api;

import org.openapitools.client.ApiCallback;
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.ApiResponse;
import org.openapitools.client.Configuration;
import org.openapitools.client.Pair;
import org.openapitools.client.ProgressRequestBody;
import org.openapitools.client.ProgressResponseBody;

import com.google.gson.reflect.TypeToken;

import java.io.IOException;


import java.math.BigDecimal;
import org.openapitools.client.model.Error;
import org.openapitools.client.model.NotFound;
import org.openapitools.client.model.Ok;
import org.openapitools.client.model.VariantKey;

import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class BulkPairingsApi {
    private ApiClient localVarApiClient;

    public BulkPairingsApi() {
        this(Configuration.getDefaultApiClient());
    }

    public BulkPairingsApi(ApiClient apiClient) {
        this.localVarApiClient = apiClient;
    }

    public ApiClient getApiClient() {
        return localVarApiClient;
    }

    public void setApiClient(ApiClient apiClient) {
        this.localVarApiClient = apiClient;
    }

    /**
     * Build call for bulkPairingCreate
     * @param players OAuth tokens of all the players to pair, with the syntax &#x60;tokenOfWhitePlayerInGame1:tokenOfBlackPlayerInGame1,tokenOfWhitePlayerInGame2:tokenOfBlackPlayerInGame2,...&#x60;.  The 2 tokens of the players of a game are separated with &#x60;:&#x60;. The first token gets the white pieces. Games are separated with &#x60;,&#x60;.  Up to 1000 tokens can be sent, for a max of 500 games.  Each token must be included at most once.  Example: &#x60;token1:token2,token3:token4,token5:token6&#x60;  (optional)
     * @param clockLimit Clock initial time in seconds. Example: &#x60;600&#x60;  (optional)
     * @param clockIncrement Clock increment in seconds. Example: &#x60;5&#x60;  (optional)
     * @param pairAt Date at which the games will be created. Up to 24h in the future. Omit, or set to current date and time, to start the games immediately. Example: &#x60;1612289869919&#x60;  (optional)
     * @param startClocksAt Date at which the clocks will be automatically started. Up to 24h in the future. Note that the clocks can start earlier than specified, if players start making moves in the game. If omitted, the clocks will not start automatically. Example: &#x60;1612289869919&#x60;  (optional)
     * @param rated Game is rated and impacts players ratings (optional)
     * @param variant  (optional, default to VariantKey.STANDARD)
     * @param message Message that will be sent to each player, when the game is created.  It is sent from your user account.  &#x60;{opponent}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder.  (optional, default to &quot;Your game with {opponent} is ready: {game}.&quot;)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The bulk pairings have been successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the bulk pairings failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call bulkPairingCreateCall(String players, BigDecimal clockLimit, Integer clockIncrement, Integer pairAt, Integer startClocksAt, Boolean rated, VariantKey variant, String message, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/bulk-pairing";

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (players != null) {
            localVarFormParams.put("players", players);
        }

        if (clockLimit != null) {
            localVarFormParams.put("clock.limit", clockLimit);
        }

        if (clockIncrement != null) {
            localVarFormParams.put("clock.increment", clockIncrement);
        }

        if (pairAt != null) {
            localVarFormParams.put("pairAt", pairAt);
        }

        if (startClocksAt != null) {
            localVarFormParams.put("startClocksAt", startClocksAt);
        }

        if (rated != null) {
            localVarFormParams.put("rated", rated);
        }

        if (variant != null) {
            localVarFormParams.put("variant", variant);
        }

        if (message != null) {
            localVarFormParams.put("message", message);
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            "application/x-www-form-urlencoded"
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "POST", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call bulkPairingCreateValidateBeforeCall(String players, BigDecimal clockLimit, Integer clockIncrement, Integer pairAt, Integer startClocksAt, Boolean rated, VariantKey variant, String message, final ApiCallback _callback) throws ApiException {
        

        okhttp3.Call localVarCall = bulkPairingCreateCall(players, clockLimit, clockIncrement, pairAt, startClocksAt, rated, variant, message, _callback);
        return localVarCall;

    }

    /**
     * Create a bulk pairing
     * Schedule many games at once, up to 24h in advance.  OAuth tokens are required for all paired players, with the &#x60;challenge:write&#x60; scope.  You can schedule up to 500 games every 10 minutes. [Contact us](mailto:contact@lichess.org) if you need higher limits.  The entire bulk is rejected if:   - a token is missing   - a token is present more than once   - a token lacks the &#x60;challenge:write&#x60; scope   - a player account is closed   - a player is paired more than once   - a bulk is already scheduled to start at the same time with the same player   - you have 10 scheduled bulks   - you have 1000 scheduled games  Partial bulks are never created. Either it all fails, or it all succeeds. When it fails, it does so with an error message explaining the issue. Failed bulks are not counted in the rate limiting, they are free. Fix the issues, manually or programmatically, then retry to schedule the bulk.  A successful bulk creation returns a JSON bulk document. Its ID can be used for further operations. 
     * @param players OAuth tokens of all the players to pair, with the syntax &#x60;tokenOfWhitePlayerInGame1:tokenOfBlackPlayerInGame1,tokenOfWhitePlayerInGame2:tokenOfBlackPlayerInGame2,...&#x60;.  The 2 tokens of the players of a game are separated with &#x60;:&#x60;. The first token gets the white pieces. Games are separated with &#x60;,&#x60;.  Up to 1000 tokens can be sent, for a max of 500 games.  Each token must be included at most once.  Example: &#x60;token1:token2,token3:token4,token5:token6&#x60;  (optional)
     * @param clockLimit Clock initial time in seconds. Example: &#x60;600&#x60;  (optional)
     * @param clockIncrement Clock increment in seconds. Example: &#x60;5&#x60;  (optional)
     * @param pairAt Date at which the games will be created. Up to 24h in the future. Omit, or set to current date and time, to start the games immediately. Example: &#x60;1612289869919&#x60;  (optional)
     * @param startClocksAt Date at which the clocks will be automatically started. Up to 24h in the future. Note that the clocks can start earlier than specified, if players start making moves in the game. If omitted, the clocks will not start automatically. Example: &#x60;1612289869919&#x60;  (optional)
     * @param rated Game is rated and impacts players ratings (optional)
     * @param variant  (optional, default to VariantKey.STANDARD)
     * @param message Message that will be sent to each player, when the game is created.  It is sent from your user account.  &#x60;{opponent}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder.  (optional, default to &quot;Your game with {opponent} is ready: {game}.&quot;)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The bulk pairings have been successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the bulk pairings failed. </td><td>  -  </td></tr>
     </table>
     */
    public Object bulkPairingCreate(String players, BigDecimal clockLimit, Integer clockIncrement, Integer pairAt, Integer startClocksAt, Boolean rated, VariantKey variant, String message) throws ApiException {
        ApiResponse<Object> localVarResp = bulkPairingCreateWithHttpInfo(players, clockLimit, clockIncrement, pairAt, startClocksAt, rated, variant, message);
        return localVarResp.getData();
    }

    /**
     * Create a bulk pairing
     * Schedule many games at once, up to 24h in advance.  OAuth tokens are required for all paired players, with the &#x60;challenge:write&#x60; scope.  You can schedule up to 500 games every 10 minutes. [Contact us](mailto:contact@lichess.org) if you need higher limits.  The entire bulk is rejected if:   - a token is missing   - a token is present more than once   - a token lacks the &#x60;challenge:write&#x60; scope   - a player account is closed   - a player is paired more than once   - a bulk is already scheduled to start at the same time with the same player   - you have 10 scheduled bulks   - you have 1000 scheduled games  Partial bulks are never created. Either it all fails, or it all succeeds. When it fails, it does so with an error message explaining the issue. Failed bulks are not counted in the rate limiting, they are free. Fix the issues, manually or programmatically, then retry to schedule the bulk.  A successful bulk creation returns a JSON bulk document. Its ID can be used for further operations. 
     * @param players OAuth tokens of all the players to pair, with the syntax &#x60;tokenOfWhitePlayerInGame1:tokenOfBlackPlayerInGame1,tokenOfWhitePlayerInGame2:tokenOfBlackPlayerInGame2,...&#x60;.  The 2 tokens of the players of a game are separated with &#x60;:&#x60;. The first token gets the white pieces. Games are separated with &#x60;,&#x60;.  Up to 1000 tokens can be sent, for a max of 500 games.  Each token must be included at most once.  Example: &#x60;token1:token2,token3:token4,token5:token6&#x60;  (optional)
     * @param clockLimit Clock initial time in seconds. Example: &#x60;600&#x60;  (optional)
     * @param clockIncrement Clock increment in seconds. Example: &#x60;5&#x60;  (optional)
     * @param pairAt Date at which the games will be created. Up to 24h in the future. Omit, or set to current date and time, to start the games immediately. Example: &#x60;1612289869919&#x60;  (optional)
     * @param startClocksAt Date at which the clocks will be automatically started. Up to 24h in the future. Note that the clocks can start earlier than specified, if players start making moves in the game. If omitted, the clocks will not start automatically. Example: &#x60;1612289869919&#x60;  (optional)
     * @param rated Game is rated and impacts players ratings (optional)
     * @param variant  (optional, default to VariantKey.STANDARD)
     * @param message Message that will be sent to each player, when the game is created.  It is sent from your user account.  &#x60;{opponent}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder.  (optional, default to &quot;Your game with {opponent} is ready: {game}.&quot;)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The bulk pairings have been successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the bulk pairings failed. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<Object> bulkPairingCreateWithHttpInfo(String players, BigDecimal clockLimit, Integer clockIncrement, Integer pairAt, Integer startClocksAt, Boolean rated, VariantKey variant, String message) throws ApiException {
        okhttp3.Call localVarCall = bulkPairingCreateValidateBeforeCall(players, clockLimit, clockIncrement, pairAt, startClocksAt, rated, variant, message, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Create a bulk pairing (asynchronously)
     * Schedule many games at once, up to 24h in advance.  OAuth tokens are required for all paired players, with the &#x60;challenge:write&#x60; scope.  You can schedule up to 500 games every 10 minutes. [Contact us](mailto:contact@lichess.org) if you need higher limits.  The entire bulk is rejected if:   - a token is missing   - a token is present more than once   - a token lacks the &#x60;challenge:write&#x60; scope   - a player account is closed   - a player is paired more than once   - a bulk is already scheduled to start at the same time with the same player   - you have 10 scheduled bulks   - you have 1000 scheduled games  Partial bulks are never created. Either it all fails, or it all succeeds. When it fails, it does so with an error message explaining the issue. Failed bulks are not counted in the rate limiting, they are free. Fix the issues, manually or programmatically, then retry to schedule the bulk.  A successful bulk creation returns a JSON bulk document. Its ID can be used for further operations. 
     * @param players OAuth tokens of all the players to pair, with the syntax &#x60;tokenOfWhitePlayerInGame1:tokenOfBlackPlayerInGame1,tokenOfWhitePlayerInGame2:tokenOfBlackPlayerInGame2,...&#x60;.  The 2 tokens of the players of a game are separated with &#x60;:&#x60;. The first token gets the white pieces. Games are separated with &#x60;,&#x60;.  Up to 1000 tokens can be sent, for a max of 500 games.  Each token must be included at most once.  Example: &#x60;token1:token2,token3:token4,token5:token6&#x60;  (optional)
     * @param clockLimit Clock initial time in seconds. Example: &#x60;600&#x60;  (optional)
     * @param clockIncrement Clock increment in seconds. Example: &#x60;5&#x60;  (optional)
     * @param pairAt Date at which the games will be created. Up to 24h in the future. Omit, or set to current date and time, to start the games immediately. Example: &#x60;1612289869919&#x60;  (optional)
     * @param startClocksAt Date at which the clocks will be automatically started. Up to 24h in the future. Note that the clocks can start earlier than specified, if players start making moves in the game. If omitted, the clocks will not start automatically. Example: &#x60;1612289869919&#x60;  (optional)
     * @param rated Game is rated and impacts players ratings (optional)
     * @param variant  (optional, default to VariantKey.STANDARD)
     * @param message Message that will be sent to each player, when the game is created.  It is sent from your user account.  &#x60;{opponent}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder.  (optional, default to &quot;Your game with {opponent} is ready: {game}.&quot;)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The bulk pairings have been successfully created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 400 </td><td> The creation of the bulk pairings failed. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call bulkPairingCreateAsync(String players, BigDecimal clockLimit, Integer clockIncrement, Integer pairAt, Integer startClocksAt, Boolean rated, VariantKey variant, String message, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = bulkPairingCreateValidateBeforeCall(players, clockLimit, clockIncrement, pairAt, startClocksAt, rated, variant, message, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for bulkPairingDelete
     * @param id  (required)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The bulk pairing was successfully deleted. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 404 </td><td> The bulk pairing to delete was not found. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call bulkPairingDeleteCall(String id, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/bulk-pairing/{id}"
            .replaceAll("\\{" + "id" + "\\}", localVarApiClient.escapeString(id.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "DELETE", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call bulkPairingDeleteValidateBeforeCall(String id, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'id' is set
        if (id == null) {
            throw new ApiException("Missing the required parameter 'id' when calling bulkPairingDelete(Async)");
        }
        

        okhttp3.Call localVarCall = bulkPairingDeleteCall(id, _callback);
        return localVarCall;

    }

    /**
     * Cancel a bulk pairing
     * Cancel and delete a bulk pairing that is scheduled in the future.  If the games have already been created, then this does nothing.  Canceling a bulk pairing does not refund the rate limit cost of that bulk pairing. 
     * @param id  (required)
     * @return Ok
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The bulk pairing was successfully deleted. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 404 </td><td> The bulk pairing to delete was not found. </td><td>  -  </td></tr>
     </table>
     */
    public Ok bulkPairingDelete(String id) throws ApiException {
        ApiResponse<Ok> localVarResp = bulkPairingDeleteWithHttpInfo(id);
        return localVarResp.getData();
    }

    /**
     * Cancel a bulk pairing
     * Cancel and delete a bulk pairing that is scheduled in the future.  If the games have already been created, then this does nothing.  Canceling a bulk pairing does not refund the rate limit cost of that bulk pairing. 
     * @param id  (required)
     * @return ApiResponse&lt;Ok&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The bulk pairing was successfully deleted. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 404 </td><td> The bulk pairing to delete was not found. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<Ok> bulkPairingDeleteWithHttpInfo(String id) throws ApiException {
        okhttp3.Call localVarCall = bulkPairingDeleteValidateBeforeCall(id, null);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Cancel a bulk pairing (asynchronously)
     * Cancel and delete a bulk pairing that is scheduled in the future.  If the games have already been created, then this does nothing.  Canceling a bulk pairing does not refund the rate limit cost of that bulk pairing. 
     * @param id  (required)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The bulk pairing was successfully deleted. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 404 </td><td> The bulk pairing to delete was not found. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call bulkPairingDeleteAsync(String id, final ApiCallback<Ok> _callback) throws ApiException {

        okhttp3.Call localVarCall = bulkPairingDeleteValidateBeforeCall(id, _callback);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for bulkPairingGet
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of upcoming bulk pairing the logged in user created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call bulkPairingGetCall(final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/bulk-pairing";

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call bulkPairingGetValidateBeforeCall(final ApiCallback _callback) throws ApiException {
        

        okhttp3.Call localVarCall = bulkPairingGetCall(_callback);
        return localVarCall;

    }

    /**
     * View upcoming bulk pairings
     * Get a list of upcoming bulk pairings you created.  Only bulk pairings that are scheduled in the future, or that have a clock start scheduled in the future, are listed.  Bulk pairings are deleted from the server after the pairings are done and the clocks have started. 
     * @return List&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of upcoming bulk pairing the logged in user created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public List<Object> bulkPairingGet() throws ApiException {
        ApiResponse<List<Object>> localVarResp = bulkPairingGetWithHttpInfo();
        return localVarResp.getData();
    }

    /**
     * View upcoming bulk pairings
     * Get a list of upcoming bulk pairings you created.  Only bulk pairings that are scheduled in the future, or that have a clock start scheduled in the future, are listed.  Bulk pairings are deleted from the server after the pairings are done and the clocks have started. 
     * @return ApiResponse&lt;List&lt;Object&gt;&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of upcoming bulk pairing the logged in user created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<List<Object>> bulkPairingGetWithHttpInfo() throws ApiException {
        okhttp3.Call localVarCall = bulkPairingGetValidateBeforeCall(null);
        Type localVarReturnType = new TypeToken<List<Object>>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * View upcoming bulk pairings (asynchronously)
     * Get a list of upcoming bulk pairings you created.  Only bulk pairings that are scheduled in the future, or that have a clock start scheduled in the future, are listed.  Bulk pairings are deleted from the server after the pairings are done and the clocks have started. 
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The list of upcoming bulk pairing the logged in user created. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call bulkPairingGetAsync(final ApiCallback<List<Object>> _callback) throws ApiException {

        okhttp3.Call localVarCall = bulkPairingGetValidateBeforeCall(_callback);
        Type localVarReturnType = new TypeToken<List<Object>>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for bulkPairingStartClocks
     * @param id  (required)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The clocks of the games of a bulk pairing were successfully started. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 404 </td><td> The bulk pairing was not found. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call bulkPairingStartClocksCall(String id, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/api/bulk-pairing/{id}/start-clocks"
            .replaceAll("\\{" + "id" + "\\}", localVarApiClient.escapeString(id.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] { "OAuth2" };
        return localVarApiClient.buildCall(localVarPath, "POST", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call bulkPairingStartClocksValidateBeforeCall(String id, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'id' is set
        if (id == null) {
            throw new ApiException("Missing the required parameter 'id' when calling bulkPairingStartClocks(Async)");
        }
        

        okhttp3.Call localVarCall = bulkPairingStartClocksCall(id, _callback);
        return localVarCall;

    }

    /**
     * Manually start clocks
     * Immediately start all clocks of the games of a bulk pairing.  This overrides the &#x60;startClocksAt&#x60; value of an existing bulk pairing.  If the games have not yet been created (&#x60;bulk.pairAt&#x60; is in the future), then this does nothing.  If the clocks have already started (&#x60;bulk.startClocksAt&#x60; is in the past), then this does nothing. 
     * @param id  (required)
     * @return Ok
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The clocks of the games of a bulk pairing were successfully started. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 404 </td><td> The bulk pairing was not found. </td><td>  -  </td></tr>
     </table>
     */
    public Ok bulkPairingStartClocks(String id) throws ApiException {
        ApiResponse<Ok> localVarResp = bulkPairingStartClocksWithHttpInfo(id);
        return localVarResp.getData();
    }

    /**
     * Manually start clocks
     * Immediately start all clocks of the games of a bulk pairing.  This overrides the &#x60;startClocksAt&#x60; value of an existing bulk pairing.  If the games have not yet been created (&#x60;bulk.pairAt&#x60; is in the future), then this does nothing.  If the clocks have already started (&#x60;bulk.startClocksAt&#x60; is in the past), then this does nothing. 
     * @param id  (required)
     * @return ApiResponse&lt;Ok&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The clocks of the games of a bulk pairing were successfully started. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 404 </td><td> The bulk pairing was not found. </td><td>  -  </td></tr>
     </table>
     */
    public ApiResponse<Ok> bulkPairingStartClocksWithHttpInfo(String id) throws ApiException {
        okhttp3.Call localVarCall = bulkPairingStartClocksValidateBeforeCall(id, null);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Manually start clocks (asynchronously)
     * Immediately start all clocks of the games of a bulk pairing.  This overrides the &#x60;startClocksAt&#x60; value of an existing bulk pairing.  If the games have not yet been created (&#x60;bulk.pairAt&#x60; is in the future), then this does nothing.  If the clocks have already started (&#x60;bulk.startClocksAt&#x60; is in the past), then this does nothing. 
     * @param id  (required)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The clocks of the games of a bulk pairing were successfully started. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
        <tr><td> 404 </td><td> The bulk pairing was not found. </td><td>  -  </td></tr>
     </table>
     */
    public okhttp3.Call bulkPairingStartClocksAsync(String id, final ApiCallback<Ok> _callback) throws ApiException {

        okhttp3.Call localVarCall = bulkPairingStartClocksValidateBeforeCall(id, _callback);
        Type localVarReturnType = new TypeToken<Ok>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
}
