/*
 * Lichess.org API reference
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */


package org.openapitools.client.api;

import org.openapitools.client.ApiCallback;
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.ApiResponse;
import org.openapitools.client.Configuration;
import org.openapitools.client.Pair;
import org.openapitools.client.ProgressRequestBody;
import org.openapitools.client.ProgressResponseBody;

import com.google.gson.reflect.TypeToken;

import java.io.IOException;


import java.math.BigDecimal;
import org.openapitools.client.model.Speed;
import org.openapitools.client.model.VariantKey;

import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class OpeningExplorerApi {
    private ApiClient localVarApiClient;

    public OpeningExplorerApi() {
        this(Configuration.getDefaultApiClient());
    }

    public OpeningExplorerApi(ApiClient apiClient) {
        this.localVarApiClient = apiClient;
    }

    public ApiClient getApiClient() {
        return localVarApiClient;
    }

    public void setApiClient(ApiClient apiClient) {
        this.localVarApiClient = apiClient;
    }

    /**
     * Build call for openingExplorerLichess
     * @param variant Variant (optional, default to standard)
     * @param fen FEN of the root position (optional)
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to )
     * @param speeds Comma separated list of game speeds to look for (optional)
     * @param ratings Comma separated list of rating groups, ranging from their value to the next higher group (optional)
     * @param since Include only games from this month or later (optional, default to 0000-01)
     * @param until Include only games from this month or earlier (optional, default to 3000-12)
     * @param moves Number of most common moves to display (optional, default to 12)
     * @param topGames Number of top games to display (optional, default to 4)
     * @param recentGames Number of recent games to display (optional, default to 4)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> Opening statistics and game references for the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call openingExplorerLichessCall(VariantKey variant, String fen, String play, List<Speed> speeds, List<BigDecimal> ratings, String since, String until, BigDecimal moves, BigDecimal topGames, BigDecimal recentGames, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/lichess";

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (variant != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("variant", variant));
        }

        if (fen != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("fen", fen));
        }

        if (play != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("play", play));
        }

        if (speeds != null) {
            localVarCollectionQueryParams.addAll(localVarApiClient.parameterToPairs("multi", "speeds", speeds));
        }

        if (ratings != null) {
            localVarCollectionQueryParams.addAll(localVarApiClient.parameterToPairs("multi", "ratings", ratings));
        }

        if (since != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("since", since));
        }

        if (until != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("until", until));
        }

        if (moves != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("moves", moves));
        }

        if (topGames != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("topGames", topGames));
        }

        if (recentGames != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("recentGames", recentGames));
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call openingExplorerLichessValidateBeforeCall(VariantKey variant, String fen, String play, List<Speed> speeds, List<BigDecimal> ratings, String since, String until, BigDecimal moves, BigDecimal topGames, BigDecimal recentGames, final ApiCallback _callback) throws ApiException {
        

        okhttp3.Call localVarCall = openingExplorerLichessCall(variant, fen, play, speeds, ratings, since, until, moves, topGames, recentGames, _callback);
        return localVarCall;

    }

    /**
     * Lichess games
     * **Endpoint: &lt;https://explorer.lichess.ovh/lichess&gt;**  Games sampled from all Lichess players.  Example: &#x60;curl https://explorer.lichess.ovh/lichess?variant&#x3D;standard&amp;speeds&#x3D;blitz,rapid,classical&amp;ratings&#x3D;2200,2500&amp;fen&#x3D;rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR%20w%20KQkq%20-%200%201&#x60; 
     * @param variant Variant (optional, default to standard)
     * @param fen FEN of the root position (optional)
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to )
     * @param speeds Comma separated list of game speeds to look for (optional)
     * @param ratings Comma separated list of rating groups, ranging from their value to the next higher group (optional)
     * @param since Include only games from this month or later (optional, default to 0000-01)
     * @param until Include only games from this month or earlier (optional, default to 3000-12)
     * @param moves Number of most common moves to display (optional, default to 12)
     * @param topGames Number of top games to display (optional, default to 4)
     * @param recentGames Number of recent games to display (optional, default to 4)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> Opening statistics and game references for the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public Object openingExplorerLichess(VariantKey variant, String fen, String play, List<Speed> speeds, List<BigDecimal> ratings, String since, String until, BigDecimal moves, BigDecimal topGames, BigDecimal recentGames) throws ApiException {
        ApiResponse<Object> localVarResp = openingExplorerLichessWithHttpInfo(variant, fen, play, speeds, ratings, since, until, moves, topGames, recentGames);
        return localVarResp.getData();
    }

    /**
     * Lichess games
     * **Endpoint: &lt;https://explorer.lichess.ovh/lichess&gt;**  Games sampled from all Lichess players.  Example: &#x60;curl https://explorer.lichess.ovh/lichess?variant&#x3D;standard&amp;speeds&#x3D;blitz,rapid,classical&amp;ratings&#x3D;2200,2500&amp;fen&#x3D;rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR%20w%20KQkq%20-%200%201&#x60; 
     * @param variant Variant (optional, default to standard)
     * @param fen FEN of the root position (optional)
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to )
     * @param speeds Comma separated list of game speeds to look for (optional)
     * @param ratings Comma separated list of rating groups, ranging from their value to the next higher group (optional)
     * @param since Include only games from this month or later (optional, default to 0000-01)
     * @param until Include only games from this month or earlier (optional, default to 3000-12)
     * @param moves Number of most common moves to display (optional, default to 12)
     * @param topGames Number of top games to display (optional, default to 4)
     * @param recentGames Number of recent games to display (optional, default to 4)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> Opening statistics and game references for the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<Object> openingExplorerLichessWithHttpInfo(VariantKey variant, String fen, String play, List<Speed> speeds, List<BigDecimal> ratings, String since, String until, BigDecimal moves, BigDecimal topGames, BigDecimal recentGames) throws ApiException {
        okhttp3.Call localVarCall = openingExplorerLichessValidateBeforeCall(variant, fen, play, speeds, ratings, since, until, moves, topGames, recentGames, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Lichess games (asynchronously)
     * **Endpoint: &lt;https://explorer.lichess.ovh/lichess&gt;**  Games sampled from all Lichess players.  Example: &#x60;curl https://explorer.lichess.ovh/lichess?variant&#x3D;standard&amp;speeds&#x3D;blitz,rapid,classical&amp;ratings&#x3D;2200,2500&amp;fen&#x3D;rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR%20w%20KQkq%20-%200%201&#x60; 
     * @param variant Variant (optional, default to standard)
     * @param fen FEN of the root position (optional)
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to )
     * @param speeds Comma separated list of game speeds to look for (optional)
     * @param ratings Comma separated list of rating groups, ranging from their value to the next higher group (optional)
     * @param since Include only games from this month or later (optional, default to 0000-01)
     * @param until Include only games from this month or earlier (optional, default to 3000-12)
     * @param moves Number of most common moves to display (optional, default to 12)
     * @param topGames Number of top games to display (optional, default to 4)
     * @param recentGames Number of recent games to display (optional, default to 4)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> Opening statistics and game references for the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call openingExplorerLichessAsync(VariantKey variant, String fen, String play, List<Speed> speeds, List<BigDecimal> ratings, String since, String until, BigDecimal moves, BigDecimal topGames, BigDecimal recentGames, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = openingExplorerLichessValidateBeforeCall(variant, fen, play, speeds, ratings, since, until, moves, topGames, recentGames, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for openingExplorerMaster
     * @param fen FEN of the root position (optional)
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to )
     * @param since Include only games from this year or later (optional, default to 1952)
     * @param until Include only games from thi year or earlier (optional)
     * @param moves Number of most common moves to display (optional, default to 12)
     * @param topGames Number of top games to display (optional, default to 15)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> Opening statistics and game references for the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call openingExplorerMasterCall(String fen, String play, BigDecimal since, BigDecimal until, BigDecimal moves, BigDecimal topGames, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/masters";

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (fen != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("fen", fen));
        }

        if (play != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("play", play));
        }

        if (since != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("since", since));
        }

        if (until != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("until", until));
        }

        if (moves != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("moves", moves));
        }

        if (topGames != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("topGames", topGames));
        }

        final String[] localVarAccepts = {
            "application/json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call openingExplorerMasterValidateBeforeCall(String fen, String play, BigDecimal since, BigDecimal until, BigDecimal moves, BigDecimal topGames, final ApiCallback _callback) throws ApiException {
        

        okhttp3.Call localVarCall = openingExplorerMasterCall(fen, play, since, until, moves, topGames, _callback);
        return localVarCall;

    }

    /**
     * Masters database
     * **Endpoint: &lt;https://explorer.lichess.ovh/masters&gt;**  Example: &#x60;curl https://explorer.lichess.ovh/masters?play&#x3D;d2d4,d7d5,c2c4,c7c6,c4d5&#x60; 
     * @param fen FEN of the root position (optional)
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to )
     * @param since Include only games from this year or later (optional, default to 1952)
     * @param until Include only games from thi year or earlier (optional)
     * @param moves Number of most common moves to display (optional, default to 12)
     * @param topGames Number of top games to display (optional, default to 15)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> Opening statistics and game references for the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public Object openingExplorerMaster(String fen, String play, BigDecimal since, BigDecimal until, BigDecimal moves, BigDecimal topGames) throws ApiException {
        ApiResponse<Object> localVarResp = openingExplorerMasterWithHttpInfo(fen, play, since, until, moves, topGames);
        return localVarResp.getData();
    }

    /**
     * Masters database
     * **Endpoint: &lt;https://explorer.lichess.ovh/masters&gt;**  Example: &#x60;curl https://explorer.lichess.ovh/masters?play&#x3D;d2d4,d7d5,c2c4,c7c6,c4d5&#x60; 
     * @param fen FEN of the root position (optional)
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to )
     * @param since Include only games from this year or later (optional, default to 1952)
     * @param until Include only games from thi year or earlier (optional)
     * @param moves Number of most common moves to display (optional, default to 12)
     * @param topGames Number of top games to display (optional, default to 15)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> Opening statistics and game references for the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<Object> openingExplorerMasterWithHttpInfo(String fen, String play, BigDecimal since, BigDecimal until, BigDecimal moves, BigDecimal topGames) throws ApiException {
        okhttp3.Call localVarCall = openingExplorerMasterValidateBeforeCall(fen, play, since, until, moves, topGames, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Masters database (asynchronously)
     * **Endpoint: &lt;https://explorer.lichess.ovh/masters&gt;**  Example: &#x60;curl https://explorer.lichess.ovh/masters?play&#x3D;d2d4,d7d5,c2c4,c7c6,c4d5&#x60; 
     * @param fen FEN of the root position (optional)
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to )
     * @param since Include only games from this year or later (optional, default to 1952)
     * @param until Include only games from thi year or earlier (optional)
     * @param moves Number of most common moves to display (optional, default to 12)
     * @param topGames Number of top games to display (optional, default to 15)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> Opening statistics and game references for the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call openingExplorerMasterAsync(String fen, String play, BigDecimal since, BigDecimal until, BigDecimal moves, BigDecimal topGames, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = openingExplorerMasterValidateBeforeCall(fen, play, since, until, moves, topGames, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for openingExplorerMasterGame
     * @param gameId  (required)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the game. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call openingExplorerMasterGameCall(String gameId, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/master/pgn/{gameId}"
            .replaceAll("\\{" + "gameId" + "\\}", localVarApiClient.escapeString(gameId.toString()));

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        final String[] localVarAccepts = {
            "application/x-chess-pgn"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call openingExplorerMasterGameValidateBeforeCall(String gameId, final ApiCallback _callback) throws ApiException {
        
        // verify the required parameter 'gameId' is set
        if (gameId == null) {
            throw new ApiException("Missing the required parameter 'gameId' when calling openingExplorerMasterGame(Async)");
        }
        

        okhttp3.Call localVarCall = openingExplorerMasterGameCall(gameId, _callback);
        return localVarCall;

    }

    /**
     * OTB master game
     * **Endpoint: &#x60;https://explorer.lichess.ovh/masters/pgn/{gameId}&#x60;**  Example: &#x60;curl https://explorer.lichess.ovh/masters/pgn/aAbqI4ey&#x60; 
     * @param gameId  (required)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the game. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public Object openingExplorerMasterGame(String gameId) throws ApiException {
        ApiResponse<Object> localVarResp = openingExplorerMasterGameWithHttpInfo(gameId);
        return localVarResp.getData();
    }

    /**
     * OTB master game
     * **Endpoint: &#x60;https://explorer.lichess.ovh/masters/pgn/{gameId}&#x60;**  Example: &#x60;curl https://explorer.lichess.ovh/masters/pgn/aAbqI4ey&#x60; 
     * @param gameId  (required)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the game. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<Object> openingExplorerMasterGameWithHttpInfo(String gameId) throws ApiException {
        okhttp3.Call localVarCall = openingExplorerMasterGameValidateBeforeCall(gameId, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * OTB master game (asynchronously)
     * **Endpoint: &#x60;https://explorer.lichess.ovh/masters/pgn/{gameId}&#x60;**  Example: &#x60;curl https://explorer.lichess.ovh/masters/pgn/aAbqI4ey&#x60; 
     * @param gameId  (required)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> The PGN representation of the game. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call openingExplorerMasterGameAsync(String gameId, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = openingExplorerMasterGameValidateBeforeCall(gameId, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
    /**
     * Build call for openingExplorerPlayer
     * @param variant Variant (optional, default to standard)
     * @param fen FEN of the root position (optional)
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to )
     * @param speeds Comma separated list of game speeds to look for (optional)
     * @param modes Comma separated list of modes (optional)
     * @param since Include only games from this month or later (optional, default to 0000-01)
     * @param until Include only games from this month or earlier (optional, default to 3000-12)
     * @param moves Number of most common moves to display (optional)
     * @param recentGames Number of recent games to display (optional, default to 4)
     * @param _callback Callback for upload/download progress
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> Opening statistics and game references for the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call openingExplorerPlayerCall(VariantKey variant, String fen, String play, List<Speed> speeds, List<String> modes, String since, String until, BigDecimal moves, BigDecimal recentGames, final ApiCallback _callback) throws ApiException {
        Object localVarPostBody = null;

        // create path and map variables
        String localVarPath = "/player?";

        List<Pair> localVarQueryParams = new ArrayList<Pair>();
        List<Pair> localVarCollectionQueryParams = new ArrayList<Pair>();
        Map<String, String> localVarHeaderParams = new HashMap<String, String>();
        Map<String, String> localVarCookieParams = new HashMap<String, String>();
        Map<String, Object> localVarFormParams = new HashMap<String, Object>();

        if (variant != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("variant", variant));
        }

        if (fen != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("fen", fen));
        }

        if (play != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("play", play));
        }

        if (speeds != null) {
            localVarCollectionQueryParams.addAll(localVarApiClient.parameterToPairs("multi", "speeds", speeds));
        }

        if (modes != null) {
            localVarCollectionQueryParams.addAll(localVarApiClient.parameterToPairs("multi", "modes", modes));
        }

        if (since != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("since", since));
        }

        if (until != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("until", until));
        }

        if (moves != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("moves", moves));
        }

        if (recentGames != null) {
            localVarQueryParams.addAll(localVarApiClient.parameterToPair("recentGames", recentGames));
        }

        final String[] localVarAccepts = {
            "application/nd-json"
        };
        final String localVarAccept = localVarApiClient.selectHeaderAccept(localVarAccepts);
        if (localVarAccept != null) {
            localVarHeaderParams.put("Accept", localVarAccept);
        }

        final String[] localVarContentTypes = {
            
        };
        final String localVarContentType = localVarApiClient.selectHeaderContentType(localVarContentTypes);
        localVarHeaderParams.put("Content-Type", localVarContentType);

        String[] localVarAuthNames = new String[] {  };
        return localVarApiClient.buildCall(localVarPath, "GET", localVarQueryParams, localVarCollectionQueryParams, localVarPostBody, localVarHeaderParams, localVarCookieParams, localVarFormParams, localVarAuthNames, _callback);
    }

    @SuppressWarnings("rawtypes")
    private okhttp3.Call openingExplorerPlayerValidateBeforeCall(VariantKey variant, String fen, String play, List<Speed> speeds, List<String> modes, String since, String until, BigDecimal moves, BigDecimal recentGames, final ApiCallback _callback) throws ApiException {
        

        okhttp3.Call localVarCall = openingExplorerPlayerCall(variant, fen, play, speeds, modes, since, until, moves, recentGames, _callback);
        return localVarCall;

    }

    /**
     * Player games
     * **Endpoint: &lt;https://explorer.lichess.ovh/player&gt;**  Games of a Lichess player.  Responds with a stream of newline delimited JSON. Will start indexing on demand, immediately respond with the current results, and stream more updates until indexing is complete. The stream is throttled and deduplicated. Empty lines may be sent to avoid timeouts.  Will index new games at most once per minute, and revisit previously ongoing games at most once every day.  Example: &#x60;curl https://explorer.lichess.ovh/player?player&#x3D;revoof&amp;color&#x3D;white&amp;play&#x3D;d2d4,d7d5&amp;recentGames&#x3D;1&#x60; 
     * @param variant Variant (optional, default to standard)
     * @param fen FEN of the root position (optional)
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to )
     * @param speeds Comma separated list of game speeds to look for (optional)
     * @param modes Comma separated list of modes (optional)
     * @param since Include only games from this month or later (optional, default to 0000-01)
     * @param until Include only games from this month or earlier (optional, default to 3000-12)
     * @param moves Number of most common moves to display (optional)
     * @param recentGames Number of recent games to display (optional, default to 4)
     * @return Object
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> Opening statistics and game references for the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public Object openingExplorerPlayer(VariantKey variant, String fen, String play, List<Speed> speeds, List<String> modes, String since, String until, BigDecimal moves, BigDecimal recentGames) throws ApiException {
        ApiResponse<Object> localVarResp = openingExplorerPlayerWithHttpInfo(variant, fen, play, speeds, modes, since, until, moves, recentGames);
        return localVarResp.getData();
    }

    /**
     * Player games
     * **Endpoint: &lt;https://explorer.lichess.ovh/player&gt;**  Games of a Lichess player.  Responds with a stream of newline delimited JSON. Will start indexing on demand, immediately respond with the current results, and stream more updates until indexing is complete. The stream is throttled and deduplicated. Empty lines may be sent to avoid timeouts.  Will index new games at most once per minute, and revisit previously ongoing games at most once every day.  Example: &#x60;curl https://explorer.lichess.ovh/player?player&#x3D;revoof&amp;color&#x3D;white&amp;play&#x3D;d2d4,d7d5&amp;recentGames&#x3D;1&#x60; 
     * @param variant Variant (optional, default to standard)
     * @param fen FEN of the root position (optional)
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to )
     * @param speeds Comma separated list of game speeds to look for (optional)
     * @param modes Comma separated list of modes (optional)
     * @param since Include only games from this month or later (optional, default to 0000-01)
     * @param until Include only games from this month or earlier (optional, default to 3000-12)
     * @param moves Number of most common moves to display (optional)
     * @param recentGames Number of recent games to display (optional, default to 4)
     * @return ApiResponse&lt;Object&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> Opening statistics and game references for the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public ApiResponse<Object> openingExplorerPlayerWithHttpInfo(VariantKey variant, String fen, String play, List<Speed> speeds, List<String> modes, String since, String until, BigDecimal moves, BigDecimal recentGames) throws ApiException {
        okhttp3.Call localVarCall = openingExplorerPlayerValidateBeforeCall(variant, fen, play, speeds, modes, since, until, moves, recentGames, null);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        return localVarApiClient.execute(localVarCall, localVarReturnType);
    }

    /**
     * Player games (asynchronously)
     * **Endpoint: &lt;https://explorer.lichess.ovh/player&gt;**  Games of a Lichess player.  Responds with a stream of newline delimited JSON. Will start indexing on demand, immediately respond with the current results, and stream more updates until indexing is complete. The stream is throttled and deduplicated. Empty lines may be sent to avoid timeouts.  Will index new games at most once per minute, and revisit previously ongoing games at most once every day.  Example: &#x60;curl https://explorer.lichess.ovh/player?player&#x3D;revoof&amp;color&#x3D;white&amp;play&#x3D;d2d4,d7d5&amp;recentGames&#x3D;1&#x60; 
     * @param variant Variant (optional, default to standard)
     * @param fen FEN of the root position (optional)
     * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to )
     * @param speeds Comma separated list of game speeds to look for (optional)
     * @param modes Comma separated list of modes (optional)
     * @param since Include only games from this month or later (optional, default to 0000-01)
     * @param until Include only games from this month or earlier (optional, default to 3000-12)
     * @param moves Number of most common moves to display (optional)
     * @param recentGames Number of recent games to display (optional, default to 4)
     * @param _callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     * @http.response.details
     <table summary="Response Details" border="1">
        <tr><td> Status Code </td><td> Description </td><td> Response Headers </td></tr>
        <tr><td> 200 </td><td> Opening statistics and game references for the position. </td><td>  * Access-Control-Allow-Origin -  <br>  </td></tr>
     </table>
     */
    public okhttp3.Call openingExplorerPlayerAsync(VariantKey variant, String fen, String play, List<Speed> speeds, List<String> modes, String since, String until, BigDecimal moves, BigDecimal recentGames, final ApiCallback<Object> _callback) throws ApiException {

        okhttp3.Call localVarCall = openingExplorerPlayerValidateBeforeCall(variant, fen, play, speeds, modes, since, until, moves, recentGames, _callback);
        Type localVarReturnType = new TypeToken<Object>(){}.getType();
        localVarApiClient.executeAsync(localVarCall, localVarReturnType, _callback);
        return localVarCall;
    }
}
