/*
 * Lichess.org API reference
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */


package org.openapitools.client.api;

import org.openapitools.client.ApiException;
import org.openapitools.client.model.ApiStreamEvent;
import java.math.BigDecimal;
import org.openapitools.client.model.Error;
import org.openapitools.client.model.GameStreamEvent;
import org.openapitools.client.model.NotFound;
import org.openapitools.client.model.Ok;
import org.openapitools.client.model.VariantKey;
import org.junit.Test;
import org.junit.Ignore;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * API tests for BoardApi
 */
@Ignore
public class BoardApiTest {

    private final BoardApi api = new BoardApi();

    
    /**
     * Create a seek
     *
     *    Create a public seek, to start a game with a random player.    ### Real-time seek    Specify the &#x60;time&#x60; and &#x60;increment&#x60; clock values.  The response is streamed but doesn&#39;t contain any information.    **Keep the connection open to keep the seek active**.    If the client closes the connection, the seek is canceled. This way, if the client terminates, the user won&#39;t be paired in a game they wouldn&#39;t play.   When the seek is accepted, or expires, the server closes the connection.    **Make sure to also have an [Event stream](#operation/apiStreamEvent) open**, to be notified when a game starts.   We recommend opening the [Event stream](#operation/apiStreamEvent) first, then the seek stream. This way,   you won&#39;t miss the game event if the seek is accepted immediately.    ### Correspondence seek    Specify the &#x60;days&#x60; per turn value.  The response is not streamed, it immediately completes with the seek ID. The seek remains active on the server until it is joined by someone.
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void apiBoardSeekTest() throws ApiException {
        Boolean rated = null;
        BigDecimal time = null;
        Integer increment = null;
        Integer days = null;
        VariantKey variant = null;
        String color = null;
        String ratingRange = null;
                api.apiBoardSeek(rated, time, increment, days, variant, color, ratingRange);
        // TODO: test validations
    }
    
    /**
     * Stream incoming events
     *
     *    Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameStart&#x60; Start of a game   - &#x60;gameFinish&#x60; Completion of a game   - &#x60;challenge&#x60; A player sends you a challenge   - &#x60;challengeCanceled&#x60; A player cancels their challenge to you   - &#x60;challengeDeclined&#x60; The opponent declines your challenge     When the stream opens, all current challenges and games are sent.
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void apiStreamEventTest() throws ApiException {
                ApiStreamEvent response = api.apiStreamEvent();
        // TODO: test validations
    }
    
    /**
     * Abort a game
     *
     * Abort a game being played with the Board API. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void boardGameAbortTest() throws ApiException {
        String gameId = null;
                Ok response = api.boardGameAbort(gameId);
        // TODO: test validations
    }
    
    /**
     * Fetch the game chat
     *
     * Get the messages posted in the game chat 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void boardGameChatGetTest() throws ApiException {
        String gameId = null;
                Object response = api.boardGameChatGet(gameId);
        // TODO: test validations
    }
    
    /**
     * Write in the chat
     *
     * Post a message to the player or spectator chat, in a game being played with the Board API. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void boardGameChatPostTest() throws ApiException {
        String gameId = null;
        String room = null;
        String text = null;
                Ok response = api.boardGameChatPost(gameId, room, text);
        // TODO: test validations
    }
    
    /**
     * Claim victory of a game
     *
     * Claim victory when the opponent has left the game for a while. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void boardGameClaimVictoryTest() throws ApiException {
        String gameId = null;
                Ok response = api.boardGameClaimVictory(gameId);
        // TODO: test validations
    }
    
    /**
     * Handle draw offers
     *
     * Create/accept/decline draw offers. - &#x60;yes&#x60;: Offer a draw, or accept the opponent&#39;s draw offer. - &#x60;no&#x60;: Decline a draw offer from the opponent. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void boardGameDrawTest() throws ApiException {
        String gameId = null;
        Boolean accept = null;
                Ok response = api.boardGameDraw(gameId, accept);
        // TODO: test validations
    }
    
    /**
     * Make a Board move
     *
     * Make a move in a game being played with the Board API.  The move can also contain a draw offer/agreement. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void boardGameMoveTest() throws ApiException {
        String gameId = null;
        String move = null;
        Boolean offeringDraw = null;
                Ok response = api.boardGameMove(gameId, move, offeringDraw);
        // TODO: test validations
    }
    
    /**
     * Resign a game
     *
     * Resign a game being played with the Board API. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void boardGameResignTest() throws ApiException {
        String gameId = null;
                Ok response = api.boardGameResign(gameId);
        // TODO: test validations
    }
    
    /**
     * Stream Board game state
     *
     *  Stream the state of a game being played with the Board API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameFull&#x60; Full game data. All values are immutable, except for the &#x60;state&#x60; field.   - &#x60;gameState&#x60; Current state of the game. Immutable values not included. Sent when a move is played, a draw is offered, or when the game ends.   - &#x60;chatLine&#x60; Chat message sent by a user in the &#x60;room&#x60; \&quot;player\&quot; or \&quot;spectator\&quot;.    The first line is always of type &#x60;gameFull&#x60;.
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void boardGameStreamTest() throws ApiException {
        String gameId = null;
                GameStreamEvent response = api.boardGameStream(gameId);
        // TODO: test validations
    }
    
    /**
     * Handle takeback offers
     *
     * Create/accept/decline takebacks. - &#x60;yes&#x60;: Propose a takeback, or accept the opponent&#39;s takeback offer. - &#x60;no&#x60;: Decline a takeback offer from the opponent. 
     *
     * @throws ApiException
     *          if the Api call fails
     */
    @Test
    public void boardGameTakebackTest() throws ApiException {
        String gameId = null;
        Boolean accept = null;
                Ok response = api.boardGameTakeback(gameId, accept);
        // TODO: test validations
    }
    
}
